/* -*- mode: C++; tab-width: 4 -*- */
/* ===================================================================== *\
	Copyright (c) 1998-2001 Palm, Inc. or its subsidiaries.
	All rights reserved.

	This file is part of the Palm OS Emulator.

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
\* ===================================================================== */

#pragma once

#include <LDocApplication.h>
#include <LPeriodical.h>
#include <LCleanupTask.h>

#include "EmApplication.h"

#if (UNIVERSAL_INTERFACES_VERSION >= 0x0340)
	#include <Carbon.h>			// EventHandlerCallRef, EventRef
#endif


// Globals.

class EmApplicationMac;
class EmDocumentMac;
class EmApplication;
class EmDocument;

extern EmApplicationMac*	gHostApplication;


/*
	LApplication handles the following commands:

		cmd_About			-> ShowAboutBox
		cmd_Quit			-> SendAEQuit		-> DoQuit
		cmd_Preferences		-> DoPreferences
		synthetic commands

	LApplication handles the following Apple events:

		ae_OpenApp			-> StartUp
		ae_ReopenApp		-> DoReopenApp
		ae_Preferences		-> DoPreferences
		ae_Quit				-> DoQuit
		object model stuff

	LDocApplication handles the following commands:

		cmd_New			-> SendAECreateDocument	-> MakeNewDocument
		cmd_Open		-> ChooseDocument
		cmd_PageSetup	-> SetupPage

	LDocApplication handles the following Apple events:

		ae_OpenDoc		-> DoAEOpenOrPrintDoc	-> OpenOrPrintDocList	-> OpenDocument
		ae_PrintDoc		-> DoAEOpenOrPrintDoc	-> OpenOrPrintDocList	-> PrintDocument

	Therefore, in order to integrate our command managing model with
	PowerPlant's, we need to override:
	
		ShowAboutBox
		DoQuit
		DoPreferences
		StartUp
		DoReopenApp
		MakeNewDocument
		ChooseDocument
		(SetupPage)
		OpenDocument
		(PrintDocument)
*/

// Class declarations.

class EmApplicationMac :	public LDocApplication,
							public LPeriodical,
							public LCleanupTask,
							public EmApplication
{
	public:

								EmApplicationMac	(void);
		virtual					~EmApplicationMac	(void);

	public:		// LDocApplication overrides

		virtual void			OpenOrPrintDocList	(const AEDescList&, SInt32);
		virtual	void			OpenDocument		(FSSpec*);
		virtual LModelObject*	MakeNewDocument		(void);
		virtual	void			ChooseDocument		(void);

	public:		// LApplication overrides

		virtual void			ShowAboutBox		(void);
		virtual void			DoQuit				(SInt32 inSaveOption = kAEAsk);

	protected:

		virtual void			StartUp				(void);
		virtual void			DoReopenApp			(void);
		virtual void			DoPreferences		(void);
		virtual void			MakeMenuBar			(void);

	public:		// LCommander overrides

		virtual	Boolean			ObeyCommand			(CommandT, void*);
		virtual	void			FindCommandStatus	(CommandT, Boolean&, Boolean&, UInt16&, Str255);

	public:		// LEventDispatcher overrides

		virtual void			UpdateMenus			(void);

	protected:

		virtual void			ClickMenuBar		(const EventRecord& inMacEvent);

	public:		// LPeriodical overrides

		virtual	void			SpendTime			(const EventRecord& inMacEvent);

	protected:	// LCleanupTask overrides

		virtual void			DoCleanup			(void);

	public:		// EmApplication overrides

		virtual Bool			Startup				(int argc, char** argv);
		virtual void			Shutdown			(void);
		virtual void			SetTimeToQuit		(Bool q);

	public:		// EmApplicationMac methods

		void					BringToFront		(void);

	private:

#if (UNIVERSAL_INTERFACES_VERSION >= 0x0340)
		static pascal OSStatus	PreferencesCmdEventHandler (
													EventHandlerCallRef inHandlerCallRef,
													EventRef inEvent, void* inUserData);
#endif

	private:
		ProcessSerialNumber		fPSN;
		Bool					fPalmUIInitialized;
};
