/* -*- mode: C++; tab-width: 4 -*- */
/* ===================================================================== *\
	Copyright (c) 1998-2001 Palm, Inc. or its subsidiaries.
	All rights reserved.

	This file is part of the Palm OS Emulator.

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
\* ===================================================================== */

#ifndef EmClassic_h
#define EmClassic_h

/*
	This file allows us to make non-Carbon calls while still being a
	Carbon application.
	
	Poser uses the PPC Toolbox, Communications Toolbox, Serial Manager,
	and Driver Manager.  As well, it manipulates Memory Manager zones.
	None of these facilities are available to Carbon applications.
	However, while running on Mac OS 8 or 9, we would like to make use
	of them.
	
	The solution is to merely call GetSharedLibrary ("InterfaceLib")
	and get pointers to the functions we want with FindSymbol.  The
	result is a function pointer that we can use to access the desired
	functionality.  To make things easier, we wrap up the function
	pointer in a function with the same name as the non-Carbon function.
	
	Originally, this module was self-initializing.  The first time
	a wrapper function was called, it would look up the function
	pointer and cache it for all subsequent uses.  However, this
	approach fails while in the middle of a PPC Toolbox callback
	function.  Poser will call PPCReadASync in a callback function.
	But the first time PPCReadAsync is called, the attempt to look up
	the function pointer fails.
	
	Therefore, we now fetch and store all function pointers all at
	once in a call to EmClassicInit.  This pre-flight approach has
	the added benefit of allowing us to find out up front if all
	functions pointers can be fetched.
*/

void	EmClassicInit (void);

Bool	EmClassicHasPPCToolbox (void);
Bool	EmClassicHasSerialManager (void);
Bool	EmClassicHasZones (void);

#if PRAGMA_STRUCT_ALIGN
    #pragma options align=mac68k
#elif PRAGMA_STRUCT_PACKPUSH
    #pragma pack(push, 2)
#elif PRAGMA_STRUCT_PACK
    #pragma pack(2)
#endif

// From CRMSerialDevices.h

enum {
                                        /*    for the crmDeviceType field of the CRMRec data structure  */
  crmSerialDevice               = 1,    /*    version of the CRMSerialRecord below   */
  curCRMSerRecVers              = 1
};

struct CRMIconRecord {
  long                oldIcon[32];            /* ICN#   */
  long                oldMask[32];
  Handle              theSuite;               /* Handle to an IconSuite */
  long                reserved;
};
typedef struct CRMIconRecord            CRMIconRecord;
typedef CRMIconRecord *                 CRMIconPtr;
typedef CRMIconPtr *                    CRMIconHandle;

struct CRMSerialRecord {
  short               version;
  StringHandle        inputDriverName;
  StringHandle        outputDriverName;
  StringHandle        name;
  CRMIconHandle       deviceIcon;
  long                ratedSpeed;
  long                maxSpeed;
  long                reserved;
};
typedef struct CRMSerialRecord          CRMSerialRecord;
typedef CRMSerialRecord *               CRMSerialPtr;

// From CommResources.h

/* data structures general to the use of the Communications Resource Manager */
typedef OSErr                           CRMErr;
struct CRMRec {
  QElemPtr            qLink;                  /*reserved*/
  short               qType;                  /*queue type -- ORD(crmType) = 9*/
  short               crmVersion;             /*version of queue element data structure*/
  long                crmPrivate;             /*reserved*/
  short               crmReserved;            /*reserved*/
  long                crmDeviceType;          /*type of device, assigned by DTS*/
  long                crmDeviceID;            /*device ID; assigned when CRMInstall is called*/
  long                crmAttributes;          /*pointer to attribute block*/
  long                crmStatus;              /*status variable - device specific*/
  long                crmRefCon;              /*for device private use*/
};
typedef struct CRMRec                   CRMRec;
typedef CRMRec *                        CRMRecPtr;

#if PRAGMA_STRUCT_ALIGN
    #pragma options align=reset
#elif PRAGMA_STRUCT_PACKPUSH
    #pragma pack(pop)
#elif PRAGMA_STRUCT_PACK
    #pragma pack()
#endif


EXTERN_API( UniversalProcPtr )
NewRoutineDescriptor            (ProcPtr                theProc,
                                 ProcInfoType           theProcInfo,
                                 ISAType                theISA);
EXTERN_API( THz )
ApplicationZone                 (void);
EXTERN_API( void )
SetZone                         (THz                    hz);
EXTERN_API( THz )
GetZone                         (void);

EXTERN_API( OSErr )
PPCInit							(void);
EXTERN_API( OSErr )
PPCOpenSync						(PPCOpenPBPtr 			pb);
EXTERN_API( OSErr )
PPCInformAsync					(PPCInformPBPtr 		pb);
EXTERN_API( OSErr )
PPCStartSync					(PPCStartPBPtr 			pb);
EXTERN_API( OSErr )
PPCWriteAsync					(PPCWritePBPtr 			pb);
EXTERN_API( OSErr )
PPCReadAsync					(PPCReadPBPtr 			pb);
EXTERN_API( OSErr )
PPCEndSync						(PPCEndPBPtr 			pb);
EXTERN_API( OSErr )
PPCEndAsync						(PPCEndPBPtr 			pb);
EXTERN_API( OSErr )
PPCCloseSync					(PPCClosePBPtr 			pb);
EXTERN_API(PPCCompUPP)
NewPPCCompUPP					(PPCCompProcPtr			userRoutine);

EXTERN_API( CRMErr )
InitCRM                         (void);
EXTERN_API( CRMRecPtr )
CRMSearch                       (CRMRecPtr              crmReqPtr);

EXTERN_API( OSErr )
SerReset                        (short                  refNum,
                                 short                  serConfig);
EXTERN_API( OSErr )
SerSetBuf                       (short                  refNum,
                                 Ptr                    serBPtr,
                                 short                  serBLen);
EXTERN_API( OSErr )
SerGetBuf                       (short                  refNum,
                                 long *                 count);

#define MacOpenDriver OpenDriver
#define MacCloseDriver CloseDriver
EXTERN_API( OSErr )
MacOpenDriver                   (ConstStr255Param       name,
                                 short *                drvrRefNum);
EXTERN_API( OSErr )
MacCloseDriver                  (short                  refNum);

EXTERN_API( OSErr )
Control                         (short                  refNum,
                                 short                  csCode,
                                 const void *           csParamPtr);
EXTERN_API( OSErr )
Status                          (short                  refNum,
                                 short                  csCode,
                                 void *                 csParamPtr);

#endif	// EmClassic_h
