/* -*- mode: C++; tab-width: 4 -*- */
/* ===================================================================== *\
	Copyright (c) 1999-2001 Palm, Inc. or its subsidiaries.
	All rights reserved.

	This file is part of the Palm OS Emulator.

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
\* ===================================================================== */

#ifndef EmDlgMac_h
#define EmDlgMac_h

#include "EmDlg.h"

#include <LAttachment.h>		// LAttachment
#include <LDialogBox.h>			// LDialogBox
#include <LPeriodical.h>		// LPeriodical
#include <UModalDialogs.h>		// StDialogHandler


void 	GetListFontAndSize		(short* font, short* size);
void 	GetDialogFontAndSize	(short* font, short* size);
short	GetListCellHeight		(void);


const int	kDialogIDBase				= 2000;
const int	kDialogItemIDBase			= 5000;
const int	kDialogItemIDDblClickBase	= 15000;

inline ResIDT			PrvFromDlgID (EmDlgID id)
{
	if (id == 0)
		return ResIDT (id);

	return ResIDT (id + kDialogIDBase);
}

inline EmDlgID			PrvToDlgID (ResIDT id)
{
	if (id == 0)
		return EmDlgID (id);

	return EmDlgID (id - kDialogIDBase);
}

inline PaneIDT			PrvFromDlgItemID (EmDlgItemID id)
{
	if (id == 0)
		return PaneIDT (id);

	return PaneIDT (id + kDialogItemIDBase);
}

inline EmDlgItemID		PrvToDlgItemID (PaneIDT id)
{
	if (id == 0)
		return EmDlgItemID (id);

	return EmDlgItemID (id - kDialogItemIDBase);
}



template <typename T>
inline void FindPane (LWindow* w, PaneIDT id, T*& result)
{
	LPane*	pane = w->FindPaneByID (id);
	if (pane == NULL)
	{
		result = NULL;
		return;
	}

	result = dynamic_cast<T*> (pane);
	EmAssert (result);
}


template <typename T>
inline void FindPane (EmDlgRef dlg, EmDlgItemID id, T*& result)
{
	result = NULL;

	EmDialogBox*	dialog = static_cast <EmDialogBox*> (dlg);
	EmAssert (dialog);
	if (!dialog)
		return;

	::FindPane (dialog, ::PrvFromDlgItemID (id), result);
}


//
// A version of StDialogHandler that masks out high-level events.  This
// prevents us from getting things like 'odoc' events while displaying an
// error message during startup.
//

class EmDialogHandler : public StDialogHandler {
public:
						EmDialogHandler(
								ResIDT			inDialogResID,
								LCommander*		inSuper);

						EmDialogHandler(
								LWindow*		inWindow,
								LCommander*		inSuper);

	virtual				~EmDialogHandler();

	virtual MessageT	DoDialog();
};


class LCmdCAttachment : public LAttachment
{
	public:
								LCmdCAttachment	(LListener*,
												 EmDlgItemID paneID,
												 Boolean inExecuteHost = true);

	protected:
		virtual void			ExecuteSelf		(MessageT inMessage, void* ioParam);

	private:
		LListener*				fListener;
		EmDlgItemID				fPaneID;
};


//
// EmDialogBox is more-or-less standalone dialog box, used for both modal
// and modeless dialogs.  It is set up to listen to all of its subpanes,
// handling clicks on them in ListenToMessage.  In ListenToMessage, the
// cross-platform dialog handler callback is called to actually handle
// the click.
//
// The dialog is a periodical, so it can idle itself.  This is done in
// HostStartIdling and HostStopIdling.
//
// AttemptClose is overridden so that modeless dialogs can be closed as
// normal, while modal dialogs send a message back to the StDialogHandler,
// telling its DoDialog method to return with msg_Cancel.
//
// EmDialogBox's destructor takes care to call EmDlgContext::Destroy ().
//

class EmDialogBox : public LDialogBox, public LPeriodical
{
	public:
								EmDialogBox		(void);
								EmDialogBox		(LStream*);
		virtual					~EmDialogBox	(void);

		EmDlgContext&			GetContext		(void) { return fContext; }
		void					SetHandler		(EmDialogHandler* h) { fHandler = h; }

	public:		// LListener override.

		virtual void			ListenToMessage	(MessageT, void*);

	protected:	// LPeriodical override.

		virtual	void			SpendTime		(const EventRecord&);

	public:		// LWindow override.

		virtual void			AttemptClose	(void);

	private:

		EmDlgContext			fContext;
		EmDialogHandler*		fHandler;
};

class StStopListening
{
	public:
		StStopListening (LListener* listener) :
			fListener (listener)
		{
			if (fListener)
			{
				fWasListening = fListener->IsListening ();
				fListener->StopListening ();
			}
		}

		~StStopListening (void)
		{
			if (fListener && fWasListening)
			{
				fListener->StartListening ();
			}
		}

	private:
		LListener*	fListener;
		Boolean		fWasListening;
};

class CAboutDialog : public StDialogHandler
{
	public:
	
		static	void		DoAboutBox( LCommander *inSuper );
		
							CAboutDialog( ResIDT, LCommander *);
				virtual		~CAboutDialog();
		
	
	
	protected:
		void				InstallPanel (SInt16 inPanelID);

		virtual	void		ListenToMessage( MessageT	inMessage,
											void*		ioParam );

		LView*				fCurrentPanel;		//	The currently installed project panel
	
};

#endif	/* EmDlgMac_h */
