/* -*- mode: C++; tab-width: 4 -*- */
/* ===================================================================== *\
	Copyright (c) 1998-2001 Palm, Inc. or its subsidiaries.
	All rights reserved.

	This file is part of the Palm OS Emulator.

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
\* ===================================================================== */

#pragma once

#include <LSingleDoc.h>

#include "EmDocument.h"
#include "EmException.h"		// EmExceptionReset

/*
	Important LDocument methods

	*	Close
			Called from AttemptClose if save was needed and worked.
			Called from DoAEClose if save was needed and worked.
			Deletes self if SuperCommander says it's OK.

		*	No problem...let it be...it's fine as is.

	*	AskSaveAs
			Called from ObeyCommand for cmd_SaveAs (or unspecified cmd_Save).
			Asks name for file.  Does AE recording.
			Calls DoSave if replacing and already uses the specified file.
			Calls DoAESave if creating.
			Returns if attempt was made to save document.  However,
				neither DoSave nor DoAESave return a success value.

		*	We override this method to forward the operation to EmDocument.

	*	AttemptClose
			Called from ObeyCommand for cmd_Close.
			Called from LSingleDoc::AllowSubRemoval.
			If modified, asks if changes should be made before closing/quitting.
			If already saved, calls DoSave.
			If not already saved, calls AskSaveAs.
			If save worked or user did not cancel, calls SendAEClose, then Close.
			Return true/false

		*	We override this method to forward the operation to EmDocument.

	*	AttemptQuitSelf
			Called from LCommander::AttemptQuit > LApplication::DoQuit > ae_Quit/SendAEQuit > cmd_Quit
			Passed a save option from an Apple event (save changes?)
			If modified or AE doesn't say to discard changes:
				If AE says to ask, then ask.
				If need to save and specified, call DoSave
				If need to save and new, call AskSaveAs
			If quit attempt worked, delete self.
			Return true/false

		*	We override this method to forward the operation to EmDocument.

	*	AskSaveChanges
			Called from AttemptClose if modified.
			Called from AttemptQuitSelf if modified and save option == ask.
			Called from DoAEClose if modified and save option == ask.
			Asks to save changes for <doc name> if closing/quitting.

		*	We override this method to call the common implementation.

	*	DoAEClose
			Called from HandleAppleEvent for ae_Close.
			Responds to close Apple event
			Calls AskSaveChanges if need be.
			If file in event, call DoAESave
			If specified, call DoSave
			Else, call AskSaveAs.
			If save worked, call Close.
			
		*	It doesn't make sense to replace this method.  However, since it relies
			on AskSaveChanges, DoAESave, and DoSave, we should be OK as long as we
			provide sensible implementations for those.

	*	HandleAESave
			Called from HandleAppleEvent for ae_Save.
			Responds to save Apple event.
			If file in event, call DoAESave
			If specified, call DoSave
			Else, call AskSaveAs.
			
		*	It doesn't make sense to replace this method.  However, since it relies
			on AskSaveAs, DoAESave, and DoSave, we should be OK as long as we
			provide sensible implementations for those.

	*	DoAESave
			Called from AskSaveAs if creating new document.
			Called from DoAEClose, HandleAESave if saving to AE-specified name.
			Empty
			Subclasses should override this function to save a file and
				should set mIsSpecified to true

		*	We implement this method to call the common implementation.

	*	DoSave
			Called from ObeyCommand for cmd_Save.
			Called from AskSaveAs if already saved and replacing.
			Called from AttemptClose if already saved.
			Called from AttemptQuitSelf if already saved.
			Called from DoAEClose if already saved.
			Called from HandleAESave if already saved.
			Empty
			Subclasses should override to save a Document to an existing file.

		*	We implement this method to call the common implementation.

	Important LSingleDoc methods:

	*	AllowSubRemoval
			If window is closing, calls AttemptClose and returns false
			(to indicate to the window not to close -- probably because
			LDocument::AttemptClose closed it already).

		*	We override AttemptClose to provide a common implementation.
*/

class LCommander;
class EmDocument;
struct Configuration;

class EmDocumentMac :	public LSingleDoc,
						public EmDocument
{
	public:
								EmDocumentMac		(void);
		virtual					~EmDocumentMac		(void);

	public:		// LSingleDoc overrides

		virtual Boolean			UsesFileSpec		(const FSSpec&) const;

	public:		// LDocument overrides

		virtual Boolean			AskSaveAs			(FSSpec&, Boolean);
		virtual Boolean			IsModified			(void);
		virtual StringPtr		GetDescriptor		(Str255 outDescriptor) const;
		virtual SInt16			AskSaveChanges		(bool inQuitting);
		virtual void			DoAESave			(FSSpec&, OSType);
		virtual void			DoSave				(void);

	public:		// LCommander overrides

		virtual	Boolean			ObeyCommand			(CommandT iCommand, void* iParameters);
		virtual	void			FindCommandStatus	(CommandT iCommand, Boolean& oEnabled, Boolean& oUsesMark, UInt16& oMark, Str255 oName);
		virtual Boolean			HandleKeyPress		(const EventRecord& iKeyEvent);
		virtual void			AttemptClose		(Boolean inRecordIt);

	protected:

		virtual Boolean			AttemptQuitSelf		(SInt32 inSaveOption);

	public:		// EmDocument overrides

		virtual void			HandleIdle			(void);
		virtual void			HostSaveScreen		(const EmFileRef&);

	public:		// EmDocumentMac methods

		void					SetPendingException	(const EmExceptionReset&);

	private:
		Bool					fHavePendingException;
		EmExceptionReset		fPendingException;
};

extern EmDocumentMac*	gHostDocument;
