/* -*- mode: C++; tab-width: 4 -*- */
/* ===================================================================== *\
	Copyright (c) 2001 Palm, Inc. or its subsidiaries.
	All rights reserved.

	This file is part of the Palm OS Emulator.

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
\* ===================================================================== */

#pragma once

#include "EmWindow.h"

#include <LDragAndDrop.h>
#include <LWindow.h>

class EmWindow;
class EmScreenUpdateInfo;


// LDragAndDrop subclass that handles files dropped onto the LCD.

class EmDragAndDrop : public LDragAndDrop
{
	public:
								EmDragAndDrop			(WindowPtr	inMacWindow,
														 LPane*		inPane);
		virtual					~EmDragAndDrop			(void);

	protected:
		virtual Boolean			ItemIsAcceptable		(DragReference	inDragRef,
														 ItemReference	inItemRef);
		virtual void			DoDragReceive			(DragReference	inDragRef);
		Bool					GetSpecFromItem			(DragReference	inDragRef,
														 ItemReference	inItemRef,
														 FSSpec&		outSpec);
};


// Host window object to display our device and its skin.

class EmWindowMac : public LWindow, public EmWindow
{
	public:
								EmWindowMac				(LCommander*	inSuperCommander);
		virtual					~EmWindowMac			(void);

		static WindowRef		CreateMacWindow			(void);
		static pascal long		WDEF					(short		varCode,
														 WindowRef	window,
														 short		message,
														 long		param);

	private:
		virtual void			DrawSelf				(void);
		virtual void			ClickSelf				(const SMouseDownEvent&);
		virtual void			EventMouseUp			(const EventRecord&);

		virtual void			ActivateSelf			(void);
		virtual void			DeactivateSelf			(void);

		void					MouseCommon				(const EventRecord&, Bool down);
		void					PopupMenu				(const Point&);

	public:
		void					SetLastEvent			(const EventRecord&);
		EventRecord				GetLastEvent			(void);

		void					CacheFlush				(void);
		GWorldPtr				GetSkin					(void);
		PaletteHandle			GetSystemPalette		(const EmScreenUpdateInfo&);

	private:
		Bool					DirectDevices			(void);

	private:
		virtual void			HostWindowReset		(void);

		virtual void			HostDrawingBegin	(void);

		virtual void			HostPaletteSet		(const EmScreenUpdateInfo&);

		virtual void			HostWindowMoveBy	(const EmPoint&);
		virtual void			HostWindowMoveTo	(const EmPoint&);
		virtual EmRect			HostWindowBoundsGet	(void);
		virtual void			HostWindowCenter	(void);
		virtual void			HostWindowShow		(void);
		virtual void			HostWindowDrag		(void);

		virtual void			HostRectFrame		(const EmRect&, const EmPoint&, const RGBType&);
		virtual void			HostOvalPaint		(const EmRect&, const RGBType&);

		virtual void			HostPaintCase		(const EmScreenUpdateInfo&);
		virtual void			HostPaintLCD		(const EmScreenUpdateInfo& info,
													 const EmRect& srcRect,
													 const EmRect& destRect,
													 Bool scaled);

		virtual void			HostGetDefaultSkin	(EmPixMap&, int scale);
		virtual EmPoint			HostGetCurrentMouse	(void);

	private:
		EmDragAndDrop			fDragAndDrop;
		EventRecord 			fLastEvent;
		GWorldPtr				fCachedSkin;
};

extern EmWindowMac*	gHostWindow;
