/* -*- mode: C++; tab-width: 4 -*- */
/* ===================================================================== *\
	Copyright (c) 1998-2001 Palm, Inc. or its subsidiaries.
	All rights reserved.

	This file is part of the Palm OS Emulator.

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
\* ===================================================================== */

#pragma once

#include <PPCToolbox.h>		// PPCParamBlockRec, PPCPortRec
#include <Processes.h>		// ProcessSerialNumber

#ifdef __cplusplus
extern "C" {
#endif

typedef enum PPCState
{
	// States that a PPC port can be in.

	kPPC_Closed,
	kPPC_Opened,
	kPPC_Connecting,
	kPPC_Connected,
	kPPC_Reading,
	kPPC_Writing
} PPCState;


typedef enum PPCError
{
	kPPC_ErrBadState = -23456
} PPCError;


typedef struct PortBundle
{
	PPCPortRec				fOurPortName;
	PPCPortRec				fHisPortName;

	PPCParamBlockRec		fPB;

	Ptr						fBuffer;
	long					fBufferSize;

	PPCState				fState;
	int						fDataWaiting;
	int						fForReading;

	ProcessSerialNumber		fPSN;
	THz						fZone;

	PPCCompUPP				fInformCompletionProc;
	PPCCompUPP				fReadCompletionProc;
	PPCCompUPP				fWriteCompletionProc;
	PPCCompUPP				fEndCompletionProc;
} PortBundle;

extern PortBundle		gSendPort;
extern PortBundle		gReceivePort;

extern const unsigned char*	kEmulatorPortName;
extern const unsigned char*	kDebuggerPortName;
extern const unsigned char*	kToEmulatorPortType;
extern const unsigned char*	kFromEmulatorPortType;


OSErr		PPCOpenPorts		(const unsigned char* ourPortName,
								 const unsigned char* hisPortName,
								 const unsigned char* sendPortType,
								 const unsigned char* receivePortType);
OSErr		PPCOpenAPort		(PortBundle*,
								 const unsigned char* ourPortName,
								 const unsigned char* ourPortType);
OSErr		PPCConnectAPort		(PortBundle*,
								 const unsigned char* hisPortName,
								 const unsigned char* hisPortType);
OSErr		PPCListenForConnect	(PortBundle*);					// Asynchronous
void		PPCSetReadBuffer	(void* buffer, long size);
void		PPCSetWriteBuffer	(void* buffer, long size);
OSErr		PPCListenForData	(PortBundle*);					// Asynchronous
OSErr		PPCSendData			(const void* data, long size);	// Asynchronous
int			PPCDataWaiting		(void);
long		PPCReceiveData		(void* data, long size);	// Clears "data waiting" flag
OSErr		PPCClosePorts		(void);
OSErr		PPCDisconnectAPort	(PortBundle*);
OSErr		PPCCloseAPort		(PortBundle*);

int			PPCPortClosed		(PortBundle*);
int			PPCPortOpened		(PortBundle*);
int			PPCPortConnecting	(PortBundle*);
int			PPCPortConnected	(PortBundle*);
int			PPCPortReading		(PortBundle*);
int			PPCPortWriting		(PortBundle*);

static pascal void		PPCInformCompletionProc(PPCParamBlockPtr pb);
static pascal void		PPCReadCompletionProc(PPCParamBlockPtr pb);
static pascal void		PPCWriteCompletionProc(PPCParamBlockPtr pb);
static pascal void		PPCEndCompletionProc(PPCParamBlockPtr pb);

#ifdef __cplusplus
}
#endif
