/* -*- mode: C++; tab-width: 4 -*- */
/* ===================================================================== *\
	Copyright (c) 1998-2001 Palm, Inc. or its subsidiaries.
	All rights reserved.

	This file is part of the Palm OS Emulator.

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
\* ===================================================================== */

#include "EmCommon.h"
#include "RegisterClasses.h"

#include <URegistrar.h>			// RegisterClass_

#include "CURLPushButton.h"
#include "EmDlgMac.h"			// LNotifierDialogBox
#include "ErrorHandling.h"		// Errors::ThrowIfError

#include <LCheckbox.h>
#include <LDialogBox.h>
#include <LEditText.h>
#include <LIconControl.h>
#include <LPopupButton.h>
#include <LProgressBar.h>
#include <LPushButton.h>
#include <LRadioButton.h>
#include <LRadioGroupView.h>
#include <LScrollBar.h>
#include <LScrollerView.h>
#include <LSeparatorLine.h>
#include <LStaticText.h>
#include <LTabGroup.h>
#include <LTabsControl.h>
#include <LTextColumn.h>
#include <LTextEditView.h>
#include <LTextGroupBox.h>
#include <LView.h>
#include <LWindow.h>

#include <LAMControlImp.h>
#include <LAMEditTextImp.h>
#include <LAMPopupButtonImp.h>
#include <LAMPushButtonImp.h>
#include <LAMStaticTextImp.h>
#include <LAMTrackActionImp.h>


Bool ValidateObjectStream(
	LStream		&ioStream,
	ClassIDT	&outBadClassID );
Bool ValidateOnePPob (ResIDT inPPobID);
void ValidateAllPPobs();


void RegisterClasses (void)
{
	// Register the core PowerPlant classes.

	RegisterClass_(LCheckBox);
//	RegisterClass_(LDialogBox);
	RegisterClass_(EmDialogBox);
	RegisterClass_(LEditText);
	RegisterClass_(LIconControl);
	RegisterClass_(LPopupButton);
	RegisterClass_(LProgressBar);
	RegisterClass_(LPushButton);
	RegisterClass_(LRadioButton);
	RegisterClass_(LRadioGroupView);
	RegisterClass_(LScrollBar);
	RegisterClass_(LScrollerView);
	RegisterClass_(LSeparatorLine);
	RegisterClass_(LStaticText);
	RegisterClass_(LTabGroup);
	RegisterClass_(LTabsControl);
	RegisterClass_(LTextColumn);
	RegisterClass_(LTextEditView);
	RegisterClass_(LTextGroupBox);
	RegisterClass_(LView);
	RegisterClass_(LWindow);

	RegisterClass_(LWindowThemeAttachment);

	// Make us always use the Appearance Manager, even if
	// the user has turned off "System-wide platiunum appearance"
	// in the Appearance Control Panel.

	::RegisterAppearanceClient();

	// Register the Appearance Manager implementation classes.

	RegisterClassID_(LAMControlImp,			LCheckBox::imp_class_ID);
	RegisterClassID_(LAMEditTextImp,		LEditText::imp_class_ID);
	RegisterClassID_(LAMControlImp,			LIconControl::imp_class_ID);
	RegisterClassID_(LAMPopupButtonImp,		LPopupButton::imp_class_ID);
	RegisterClassID_(LAMTrackActionImp,		LProgressBar::imp_class_ID);
	RegisterClassID_(LAMPushButtonImp,		LPushButton::imp_class_ID);
	RegisterClassID_(LAMControlImp,			LRadioButton::imp_class_ID);
	RegisterClassID_(LAMTrackActionImp, 	LScrollBar::imp_class_ID);
	RegisterClassID_(LAMControlImp,			LSeparatorLine::imp_class_ID);
	RegisterClassID_(LAMStaticTextImp,		LStaticText::imp_class_ID);
	RegisterClassID_(LAMControlImp,			LTabsControl::imp_class_ID);
	RegisterClassID_(LAMControlImp,			LTextGroupBox::imp_class_ID);

	// Register the application classes.

	RegisterClass_(CURLPushButton);

#if defined (_DEBUG)
	ValidateAllPPobs ();
#endif
}


#include <TArray.h>

// 
//	 ValidateAllPPobs
// 
//	Validates every PPob resource that it can find (within the first
//	resource file in the resource chain).

void ValidateAllPPobs()
{
	// check all the PPob's we can find.
	
	SInt16 ppobCount = ::Count1Resources('PPob');
	for (SInt16 index = 1; index <= ppobCount; ++index)
	{
		ResIDT	ppobID;
		ResType resType;
		Str255 resName;

		// see if we can get a resource, and get it's info.
		
		{
			StResource	resH;
			resH.GetIndResource('PPob', index, true, true );

			::GetResInfo((Handle)resH, &ppobID, &resType, resName);
			Errors::ThrowIfError (::ResError());
		}
		
		// validate it.
		
		ValidateOnePPob(ppobID);
	}
}


// 
//	 ValidateOnePPob
// 
//	Performs a validation on the given PPob. Takes a reference to an
//	array into which the bad class ID's are stored. The above method stops
//	at the first bad ID it finds. This will find them all.

Bool ValidateOnePPob (ResIDT inPPobID)
{
	Bool isValid = true;

	try {
		StResource objectRes('PPob', inPPobID);
		::HLockHi(objectRes.mResourceH);
		
		LDataStream objectStream(*objectRes.mResourceH, ::GetHandleSize(objectRes.mResourceH));
										
		SInt16 ppobVersion;
		objectStream.ReadData(&ppobVersion, sizeof(SInt16));
		Assert_(ppobVersion == 2);

		ClassIDT theBadClassID = 0;
		
		Bool tempValid = isValid;
		
		while ( objectStream.GetMarker() < objectStream.GetLength() ) {
		
			tempValid = ValidateObjectStream(objectStream, theBadClassID);
		
			if ( tempValid == false ) {
				isValid = false;
				Assert_(false);
				continue;
			}
		}

	} catch (const LException& iErr) {
		isValid = false;
		Assert_(false);
	}

	return (isValid);
}


// typedefs and constants borrowed from UReanimator
typedef	SInt32	TagID;

enum
{
	tag_ObjectData		= 'objd',
	tag_BeginSubs		= 'begs',
	tag_EndSubs			= 'ends',
	tag_Include			= 'incl',
	tag_UserObject		= 'user',
	tag_ClassAlias		= 'dopl',
	tag_Comment			= 'comm',
	tag_End				= 'end.',
	object_Null			= 'null'
};



// 
//	 ValidateObjectStream					[static, public]
// 
//	Performs the actual validation of the PPob stream

Bool ValidateObjectStream(
	LStream		&ioStream,
	ClassIDT	&outBadClassID )
{
	Bool isValid = true;

	Bool readingTags = true;
	ClassIDT aliasClassID = 'null';
	const TArray<SClassTableEntry> &classTable = *URegistrar::GetClassTable();

	if ( URegistrar::GetClassTable() == nil ) {	// rare circumstance, but it can happen!
		isValid = true;	// make true to short circuit the search.
		ioStream.SetMarker(0, streamFrom_End);	// short-circut the search.
		outBadClassID = '????';
		SignalPStr_( "\pNo class table! Nothing to validate" );
		return isValid;
	}
	
	do {
		TagID theTag = tag_End;
		ioStream.ReadData(&theTag, sizeof(TagID));
		
		switch (theTag)
		{
			case tag_ObjectData:
			{
				SInt32 dataLength;
				ioStream.ReadData(&dataLength, sizeof(SInt32));
				SInt32 dataStart = ioStream.GetMarker();
				ClassIDT classID;
				ioStream.ReadData(&classID, sizeof(ClassIDT));
				
				if (aliasClassID != 'null') {
					classID = aliasClassID;
				}

				SClassTableEntry entry = {classID, NULL};
				ArrayIndexT entryIndex = classTable.FetchIndexOf(entry);
				if (entryIndex == LArray::index_Bad) {
					outBadClassID = classID;
					isValid = false;
					EmAssert(false);
				}
				
				ioStream.SetMarker(dataStart + dataLength, streamFrom_Start);
				aliasClassID = 'null';
				break;
			}
				
			case tag_BeginSubs:
				isValid = ValidateObjectStream(ioStream, outBadClassID);
				break;
				
			case tag_EndSubs:
			case tag_End:
				readingTags = false;
				break;
				
			case tag_UserObject:
				Assert_(false);
				break;
				
			case tag_ClassAlias:
				ioStream.ReadData(&aliasClassID, sizeof(ClassIDT));
				break;
				
			case tag_Comment:
			{			
				SInt32 commentLength;
				ioStream.ReadData(&commentLength, sizeof(commentLength));
				ioStream.SetMarker(commentLength, streamFrom_Marker);
				break;
			}
				
			default:
				 // Unrecognized Tag
				Assert_(false);
				readingTags = false;
				break;
		}			
	} while (readingTags && isValid);

	return (isValid);
}


