/* -*- mode: C++; tab-width: 4 -*- */
/* ===================================================================== *\
	Copyright (c) 1998-2001 Palm, Inc. or its subsidiaries.
	All rights reserved.

	This file is part of the Palm OS Emulator.

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
\* ===================================================================== */

//	1000 - 1999:		Message Templates
//		1000 - 1199:		Error messages
//		1200 - 1399:		Other messages
//		1400 - 1499:		Menu strings
//	2000 - 2999:		Template Parts
//		2000 - 2199:		Misc parts
//		2200 - 2399:		Operations descriptions
//		2400 - 2599:		Error descriptions
//			2400 - 2499:		OS Errors (e.g., "the file was not found")
//			2500 - 2599:		User/app errors (e.g., "I don't understand that file")
//		2600 - 2799:		Recovery strings (e.g., "Reboot and try again")
//		2900 - 2964:		Exception descriptions (e.g., "bus error")
//		3000 - 4999:		Palm OS system function names
//		5000 - 6999:		Palm OS Library function names
//		7000 - xxxx:		Palm OS Error descriptions

#include "Strings.r.h"	// kStr_ values



/* This file is generated from SrcShared/Strings.txt */

#include <map>

static std::map<int, const char*> _ResStrMap;

struct item
{
	int key;
	const char* value;
};

#pragma mpwc_newline on

static const struct item _ResStrTable[] = {

// --------------------------------------------------------------------------------
//	Message Templates -- Error messages
// --------------------------------------------------------------------------------

	{ kStr_OpError, "Could not %operation because %reason." },
	{ kStr_OpErrorRecover, "Could not %operation because %reason. %recovery." },

// Hardware Exceptions

	{ kStr_ErrBusError, "%App just %op memory location %mem, causing a bus error.\n\nA bus error means that the application accessed a memory location that is not in RAM or ROM, nor corresponds to a memory-mapped hardware register." },
	{ kStr_ErrAddressError, "%App just %op memory location %mem, causing an address error.\n\nAn address error means that the application accessed a 2- or 4-byte value at an odd (i.e., not even) memory address." },
	{ kStr_ErrIllegalInstruction, "%App just executed an illegal or unknown machine language instruction. The opcode executed was %ins." },
	{ kStr_ErrDivideByZero, "%App just divided an integer by zero." },
	{ kStr_ErrCHKInstruction, "%App just executed a CHK machine language instruction that failed. Invoking this instruction is not supported in Palm OS applications." },
	{ kStr_ErrTRAPVInstruction, "%App just executed a TRAPV machine language instruction that failed. Invoking this instruction is not supported in Palm OS applications." },
	{ kStr_ErrPrivilegeViolation, "%App just executed opcode %ins, a privileged machine language instruction.\n\nA privileged machine language instruction is one reserved for use by the operating system. Invoking such instructions is not supported in Palm OS applications." },
	{ kStr_ErrTrace, "%App just executed an instruction with the CPUs trace mode enabled. Normally, this mode is enabled by a debugger for the purpose of single-stepping through an application. However, no debugger is currently connected to handle trace mode." },
	{ kStr_ErrATrap, "%App just executed an illegal or unknown machine language instruction. The opcode executed was %ins." },
	{ kStr_ErrFTrap, "%App just executed an illegal or unknown machine language instruction. The opcode executed was %ins." },
	{ kStr_ErrTRAPx, "%App just executed a TRAP #%num machine language instruction. Invoking such instructions is not supported in Palm OS applications." },

// Special cases to hardware exceptions

	{ kStr_ErrStorageHeap, "%App just %op memory location %mem, which is in the storage heap. In order to protect the integrity of the users data, such direct access is not allowed. Instead, applications should use special Palm OS functions for this purpose." },
	{ kStr_ErrNoDrawWindow, "%App just %op memory location %mem. This access usually indicates that the application is calling a Window Manager function without first establishing a valid DrawWindow." },
	{ kStr_ErrNoGlobals, "%App just %op memory location %mem. This access usually means that the application accessed a global variable after PilotMain was called with a launch code that does not support globals. The last launch code sent to the application was %launch_code." },
	{ kStr_ErrSANE, "%App just performed a floating point operation using a calling sequence specific to the Mac OS. This indicates that the application was compiled with the incorrect Floating Point option in the development environment that created it." },
	{ kStr_ErrTRAP0, "%App just executed a TRAP #0 machine language instruction. This instruction is often used by debuggers to set breakpoints. However, no debugger is currently connected to handle the breakpoint." },
	{ kStr_ErrTRAP8, "%App just executed a TRAP #8 machine language instruction. This instruction is generated when calling the DbgBreak function as a method for breaking into an external debugger. However, no debugger is currently connected." },

// Fatal Poser-detected errors

	{ kStr_ErrStackOverflow, "%App has overflowed the stack. The functions currently using the stack are: %sc." },
	{ kStr_ErrUnimplementedTrap, "%App called Palm OS routine #%trap_num (%trap_name). This routine does not exist in this version of the Palm OS." },
	{ kStr_ErrInvalidRefNum, "%App called a function in a shared library using a reference number of %ref_num. This reference number does not correspond to any currently installed library and is invalid." },
	{ kStr_ErrCorruptedHeap, "During a regular checkup, Palm OS Emulator determined that the dynamic heap chunk with header address %mem got corrupted. %corruption_type." },
	{ kStr_ErrInvalidPC1, "%App just changed the emulated program counter to %mem. This address is invalid because %reason." },
	{ kStr_ErrInvalidPC2, "%App just changed the emulated program counter to %mem. This address is invalid because %reason. The program counter was changed when %when." },

// Non-fatal Poser-detected errors

	{ kStr_ErrLowMemory, "%App just %op memory location %mem, which is in low memory.\n\nLow memory is defined as the first 256 bytes of memory. It should not be directly accessed by applications under any circumstances." },
	{ kStr_ErrSystemGlobals, "%App just %op memory location %mem, which is in the Palm OS global variables.\n\nPalm OS global variables are memory locations reserved for the private use of the Palm OS. They should not be directly accessed by applications under any circumstances." },
	{ kStr_ErrScreen, "%App just %op memory location %mem, which is in screen memory.\n\nScreen memory is the area of RAM containing the pixels appearing on the LCD display. It should not be directly accessed by applications under any circumstances. Instead, they should use the Window Manager functions for altering the contents of the display." },
	{ kStr_ErrHardwareRegisters, "%App just %op memory location %mem, which is in the memory-mapped hardware registers.\n\nMemory-mapped hardware registers are memory locations that control the operation of your handheld devices hardware. They should not be directly accessed by applications under any circumstances." },
	{ kStr_ErrROM, "%App just %op memory location %mem, which is in the ROM.\n\nSuch an access has no effect, and usually indicates an error in the application." },
	{ kStr_ErrMemMgrStructures, "%App just %op memory location %mem, which is in Memory Manager data structures.\n\nThese data structures include things like the headers preceding each block in a heap, as well as the heap header itself. Such an access usually means that an application allocated a buffer (possibly with MemPtrNew) that wasnt large enough for its purpose. When the application then tries to write data to the buffer, it writes off the end of the buffer, accessing the start of the buffer following it in memory." },
	{ kStr_ErrMemMgrSemaphore, "The Memory Manager semaphore has been held for longer than 1 minute. Palm recommends that applications not acquire the Memory Manager semaphore at all, but that if they do, they should not hold the semaphore any longer than that." },
	{ kStr_ErrFreeChunk, "%App just %op memory location %mem, which is in an unallocated chunk of memory.\n\nAn unallocated chunk of memory is a chunk of memory that has not been reserved for use by the application through calling MemPtrNew or MemHandleNew. It should not be accessed by applications under any circumstances. Such an access usually means that an application is accessing a chunk that used to be allocated to the application but has since been returned with MemPtrFree or MemHandleFree." },
	{ kStr_ErrUnlockedChunk, "%App just %op memory location %mem, which is in an unlocked chunk of memory.\n\nAn unlocked chunk of memory is one that has been allocated with MemHandleNew but that has not been locked with MemHandleLock. Such an access usually means that an application allocated a buffer with MemHandleNew, locked it with MemHandleLock, unlocked it with MemHandleUnlock, and then used the pointer that was returned by MemHandleLock." },
	{ kStr_ErrLowStack, "%App just %op memory location %mem, which is in the unused portion of the stack. The stack range is %stack_low - %stack_high, and the stack pointer is %stack_pointer.\n\nThe stack is the area of RAM used to contain function parameters and local variables. The used portion of the stack is indicated by the stack pointer. Applications may access the area of the stack above the stack pointer, but not below it." },
	{ kStr_ErrStackFull, "%App is close to overflowing the stack. The functions currently using the stack are: %sc." },
	{ kStr_ErrSizelessObject, "Form object ID #%obj_id (left = %left, top = %top, right = %right, bottom = %bottom) from %app has a height or width of zero. Applications should hide objects by calling FrmHideObject instead of setting their dimensions to zero.\n\nAnother way to get this error message is to call FrmCopyTitle or FrmCopyLabel to change a title or label to a string larger than what was specified in the form resource. Doing this often corrupts other objects on the form." },
	{ kStr_ErrOffscreenObject, "Form object ID #%obj_id (left = %left, top = %top, right = %right, bottom = %bottom) from %app is completely offscreen. Applications should hide objects by calling FrmHideObject instead of placing them completely offscreen.\n\nAnother way to get this error message is to call FrmCopyTitle or FrmCopyLabel to change a title or label to a string larger than what was specified in the form resource. Doing this often corrupts other objects on the form." },
	{ kStr_ErrFormAccess, "%App just %op memory location %mem, which is in the %field field of the form starting at %form.\n\nThe data at this memory location is owned by the Form Manager. Applications should not access the data directly. Instead, they should make the appropriate Form Manager calls." },
	{ kStr_ErrFormObjectListAccess, "%App just %op memory location %mem, which is in the %field field of the form object list entry with index #%index, which belongs to the form starting at %form.\n\nThe data at this memory location is owned by the Form Manager. Applications should not access the data directly. Instead, they should make the appropriate Form Manager calls." },
	{ kStr_ErrFormObjectAccess, "%App just %op memory location %mem, which is in the %field field of the %type starting at %object, which belongs to the form starting at %form.\n\nThe data at this memory location is owned by the Form Manager. Applications should not access the data directly. Instead, they should make the appropriate Form Manager calls." },
	{ kStr_ErrWindowAccess, "%App just %op memory location %mem, which is in the %field field of the window starting at %window.\n\nThe data at this memory location is owned by the Window Manager. Applications should not access the data directly. Instead, they should make the appropriate Window Manager calls." },
	{ kStr_ErrBitmapAccess, "%App just %op memory location %mem, which is in the %field field of the bitmap starting at %bitmap.\n\nThe data at this memory location is owned by the Palm OS. Applications should not access the data directly. Instead, they should make the appropriate Palm OS calls." },
	{ kStr_ErrProscribedFunction, "%App just called Palm OS routine %function_name.\n\nApplications should not call this function because %reason." },
	{ kStr_ErrStepSpy, "%App just %op memory location %mem, changing it from %old_value to %new_value." },
	{ kStr_ErrWatchpoint, "%App just %op memory location %mem, which is in the range from %watch_start to %watch_end specified in the Breakpoint dialog box." },
	{ kStr_ErrMemoryLeak, "Found %num_leaks memory leak for %app. Information concerning the leak can be found in the log file." },
	{ kStr_ErrMemoryLeaks, "Found %num_leaks memory leaks for %app. Information concerning the leaks can be found in the log file." },

// Palm OS-detected errors

	{ kStr_ErrSysFatalAlert, "%App called SysFatalAlert with the message: %message." },
	{ kStr_ErrDbgMessage, "%App called DbgMessage with the message: %message." },

// Other errors

	{ kStr_BadChecksum, "The ROM youve chosen has an invalid checksum.\n\nThe most common reason for an invalid checksum has been from the use of utility programs that modify the contents of the ROM without also updating its internal checksum.\n\nPalm, Inc. does not support the use of this ROM. Use it with caution." },
	{ kStr_UnknownDeviceWarning, "Unable to determine an appropriate device to emulate for this ROM file.\n\nPalm, Inc. does not support the use of this ROM. Use it with caution, as the operation of a ROM with an incorrect device emulation will certainly cause the ROM to crash, and may crash the Palm OS Emulator." },
	{ kStr_UnknownDeviceError, "This ROM is for a device not supported by this version of the emulator.\n\nPalm, Inc. does not support the use of this ROM." },
	{ kStr_MissingSkins, "Palm OS Emulator needs skin files in order to correctly display the hardware devices it emulates. The Emulator looks for these skins in a directory called Skins. However, that directory was not found.\n\nPrevious versions of the Emulator would look for any directory starting with the word Skins and search that directory for skin files. With the current Emulator, the directory must be named exactly Skins.\n\nIf you dont have any skin files at all, you can download them from the Emulator download Web page:\n\n     <http://www.palmos.com/dev/tech/tools/emulator>\n\nFollow the instructions included with that archive for installing the files." },
	{ kStr_InconsistentDatabaseDates, "The creation date (%cr_date) in the database header inside %database_name is more recent than the modification date (%mod_date).\n\nThe Emulator does not consider this to be a problem, and neither does the Palm OS. However, some versions of HotSync will test for this condition and report an error, so you may wish to fix the database before trying to install it on a device." },
	{ kStr_NULLDatabaseDate, "The creation date in the database header inside %database_name is zero.\n\nThe Emulator does not consider this to be a problem, and neither does the Palm OS. However, some versions of HotSync will test for this condition and report an error, so you may wish to fix the database before trying to install it on a device." },
	{ kStr_NeedHostFS, "In order to make use of the information specified in this dialog, you need to have installed HostFS.prc. You can download this file from the Palm OS Emulator download Web page:\n\n     <http://www.palmos.com/dev/tech/tools/emulator/>" },
	{ kStr_InvalidAddressNotEven, "The address \"%s\" is invalid because it is not even." },
	{ kStr_InvalidAddressNotInROMOrRAM, "The address \"%s\" is invalid because it is not in ROM or RAM." },
	{ kStr_CannotParseCondition, "Can't parse the condition \"%s\"." },
	{ kStr_UserNameTooLong, "The name entered into the HotSync User Name field is too long. It needs to be 40 characters or less." },

// --------------------------------------------------------------------------------
//	Message Templates -- Other messages
// --------------------------------------------------------------------------------

	{ kStr_SaveSessionAs, "Save session as:" },
	{ kStr_LoadSession, "Load session:" },
	{ kStr_LoadSessionForReplay, "Load session for replay:" },
	{ kStr_LoadSessionForMinimize, "Load session for minimize:" },
	{ kStr_SaveScreenAs, "Save screen as:" },
	{ kStr_ImportFile, "Import file:" },
	{ kStr_SaveBeforeClosing, "Save changes to the %AppName document %DocName before closing?" },
	{ kStr_SaveBeforeQuitting, "Save changes to the %AppName document %DocName before quitting?" },

	{ kStr_GremlinNumber, "Gremlin #%gremlin_number" },
	{ kStr_GremlinXofYEvents, "Event %current_event of %last_event" },
	{ kStr_GremlinXEvents, "Event %current_event" },
	{ kStr_GremlinElapsedTime, "Elapsed Time: %elapsed_time" },

	{ kStr_MinimizePassNumber, "Pass #%pass_number" },
	{ kStr_MinimizeXofYEvents, "Event %current_event of %last_event" },
	{ kStr_MinimizeElapsedTime, "Elapsed Time: %elapsed_time" },
	{ kStr_MinimizeRange, "Excluding range %first_event to %last_event" },
	{ kStr_MinimizeDiscarded, "Discarded %num_discarded_events of %num_total_events events" },

	{ kStr_AppAndVers, "%application %version" },
	{ kStr_XofYFiles, "%d of %d files" },
	{ kStr_GremlinStarted, "Gremlin #%d started, %ld steps.\n" },
	{ kStr_GremlinEnded, "Gremlin #%d stopped at event %ld of %ld after %ld milliseconds.\n" },
	{ kStr_EntireDevice, "Entire Palm OS device" },
	{ kStr_ErrDisplayMessage, "%s, Line: %d, %s" },
	{ kStr_UnknownFatalError, "Unknown fatal error occurred!" },
	{ kStr_EmulatorOff, "The emulator is not ready to %s at this time.\n(Perhaps it is turned off?)" },
	{ kStr_LogFileSize, "===========================================================\nThis file contains only the last %ldK of generated text.\n===========================================================\n\n" },
	{ kStr_InternalErrorException, "Hardware exception #%d occurred while the emulator was calling the Palm OS function %s." },
	{ kStr_InternalErrorMessage, "%s\n\nThe error occurred while the emulator was calling the Palm OS function %s." },
	{ kStr_WillNowReset, " The emulator is now in an unstable state and will reset." },
	{ kStr_CommPortError, "The emulator could not open port %transport. Please make sure that it is not in use by another application, and that the emulated IR and Serial ports are not mapped to the same physical port, then reconfirm your port selection in Preferences." },
	{ kStr_SocketsError, "The emulator could not open a sockets connection to %transport. Please check your TCP settings, and then reconfirm your host selection in Preferences." },
	{ kStr_MustTurnOnLogging, "In order to utilize error handling options that don't display messages in a dialog box, the corresponding logging options must be turned on. Should those options be turned on now?" },
	{ kStr_MustTurnOnShowDialog, "In order to safely turn off logging options for errors and warnings, the corresponding error handling options must be set to \"Show in dialog\". Should those options be set now?" },

	{ kStr_ROMTransferInstructions+0, "1.  You should find a file named ROM Transfer.prc included\n     with the Palm OS Emulator. This is a Palm OS application\n     you should install on your Palm OS device before continuing.\n\n" },
	{ kStr_ROMTransferInstructions+1, "2.  Choose an appropriate serial port and speed from the menus\n     below. Faster speeds do not always work correctly. Choose\n     a slower speed if you experience problems.\n\n" },
	{ kStr_ROMTransferInstructions+2, "3.  Place your Palm OS device in its cradle and run the ROM\n     Transfer application.\n\n" },
	{ kStr_ROMTransferInstructions+3, "4.  Select the same speed from the menu in ROM Transfer as\n     you chose below.\n\n" },
	{ kStr_ROMTransferInstructions+4, "5.  Disable HotSync or any other application that may be using\n     the selected serial port.\n\n" },
	{ kStr_ROMTransferInstructions+5, "6.  Tap the Begin Transfer button in the ROM Transfer\n     application on the Palm device.\n\n" },
	{ kStr_ROMTransferInstructions+6, "7.  Click the Begin button in this dialog. The Palm OS\n     Emulator will wait for your Palm device to respond.\n\n" },
	{ kStr_ROMTransferInstructions+7, "8.  The transfer will take several minutes, so please be patient.\n     If an error occurs during the transfer, the application may\n     be unresponsive or may appear to hang. If this happens,\n     wait for a few minutes to give the application a chance to\n     time-out. It should then resume normal operation.\n\n" },
	{ kStr_ROMTransferInstructions+8, "9.  After the ROM has been transferred to your desktop computer,\n     you will be asked to save it to a file. Save it with an\n     appropriate name (for example, Palm III.rom). Then\n     create a a new emulator session using that ROM." },

// --------------------------------------------------------------------------------
//	Message Templates -- Menu strings
// --------------------------------------------------------------------------------

	{ kStr_MenuSessionNew, "&New\tN" },
	{ kStr_MenuSessionOpenOther, "&Other\tO" },
	{ kStr_MenuSessionClose, "&Close\tW" },
	{ kStr_MenuSessionSave, "&Save\tS" },
	{ kStr_MenuSessionSaveAs, "Save &As" },
	{ kStr_MenuSessionBound, "Save &Bound Emulator" },
	{ kStr_MenuScreenSave, "Sa&ve Screen\tM" },
	{ kStr_MenuSessionInfo, "Session Info" },
	{ kStr_MenuImportOther, "&Other\tI" },
	{ kStr_MenuExport, "Export &Database" },
	{ kStr_MenuHotSync, "&HotSync\tH" },
	{ kStr_MenuReset, "&Reset\tR" },
	{ kStr_MenuDownloadROM, "&Transfer ROM\tD" },
	{ kStr_MenuUndo, "&Undo\tZ" },
	{ kStr_MenuCut, "Cu&t\tX" },
	{ kStr_MenuCopy, "&Copy\tC" },
	{ kStr_MenuPaste, "&Paste\tV" },
	{ kStr_MenuClear, "Clea&r" },
#if PLATFORM_WINDOWS

	{ kStr_MenuPreferences, "&Properties\t/" },
#else

	{ kStr_MenuPreferences, "&Preferences\t/" },
#endif

	{ kStr_MenuLogging, "&Logging\tL" },
	{ kStr_MenuDebugging, "&Debugging\t\\" },
	{ kStr_MenuErrorHandling, "&Error Handling\tE" },
	{ kStr_MenuTracing, "&Tracing\tT" },
	{ kStr_MenuSkins, "&Skins\tK" },
	{ kStr_MenuHostFS, "&HostFS" },
	{ kStr_MenuBreakpoints, "&Breakpoints\tB" },
	{ kStr_MenuGremlinsNew, "&New\tG" },
	{ kStr_MenuGremlinsStep, "&Step" },
	{ kStr_MenuGremlinsResume, "&Resume" },
	{ kStr_MenuGremlinsStop, "Sto&p" },
	{ kStr_MenuEventReplay, "Repla&y" },
	{ kStr_MenuEventMinimize, "&Minimize" },
#if HAS_PROFILING

	{ kStr_MenuProfileStart, "&Start\t[" },
	{ kStr_MenuProfileStop, "Sto&p\t]" },
	{ kStr_MenuProfileDump, "&Dump" },
#endif

	{ kStr_MenuAbout, "About Palm OS Emulator" },
#if PLATFORM_WINDOWS

	{ kStr_MenuQuit, "E&xit\tQ" },
#else

	{ kStr_MenuQuit, "&Quit\tQ" },
#endif

	{ kStr_MenuFile, "File" },
	{ kStr_MenuEdit, "Edit" },
	{ kStr_MenuGremlins, "Gremlins" },
	{ kStr_MenuProfile, "Profile" },
	{ kStr_MenuOpen, "&Open" },
	{ kStr_MenuImport, "&Install Application/Database" },
	{ kStr_MenuSettings, "S&ettings" },
	{ kStr_MenuEmpty, "(empty)" },
	{ kStr_MenuBlank, " " },

// --------------------------------------------------------------------------------
//	Template Parts -- Misc parts
// --------------------------------------------------------------------------------

	{ kStr_AppName, "Palm OS Emulator" },
	{ kStr_Untitled, "untitled" },
	{ kStr_DefaultROMName, "Palm.ROM" },
	{ kStr_ProfileResults, "Profile Results" },
	{ kStr_Autoload, "Autoload" },
	{ kStr_Autorun, "Autorun" },
	{ kStr_AutorunAndQuit, "AutorunAndQuit" },
	{ kStr_ReadFrom, "read from" },
	{ kStr_WroteTo, "wrote to" },
	{ kStr_WrittenTo, "written directly to" },

	{ kStr_CurrentAppUC, "The current application" },
	{ kStr_CurrentAppLC, "the current application" },
	{ kStr_UnknownVersion, "unknown version" },

	{ kStr_OK, "OK" },
	{ kStr_Cancel, "Cancel" },
	{ kStr_Yes, "Yes" },
	{ kStr_No, "No" },
	{ kStr_Continue, "Continue" },
	{ kStr_Debug, "Debug" },
	{ kStr_Reset, "Reset" },

	{ kStr_Browse, "Browse" },
	{ kStr_EmptyMRU, "(empty)" },
	{ kStr_OtherMRU, "Other" },

	{ kStr_ProfPartial, "partial" },
	{ kStr_ProfFunctions, "functions" },
	{ kStr_ProfInterrupts, "interrupts" },
	{ kStr_ProfOverflow, "overflow" },
	{ kStr_ProfInterruptX, "interrupt $%02lX" },
	{ kStr_ProfTrapNameAddress, "%s  $%04lX.t" },
	{ kStr_ProfROMNameAddress, "%s  $%08lX.m" },
	{ kStr_ProfDebugNameAddress, "  $%08lX.d" },
	{ kStr_ProfUnknownName, "unknown  $%08lX" },

	{ kStr_UnknownTrapNumber, "unknown trap number" },
	{ kStr_UnknownErrorCode, "unknown error code" },

	{ kStr_NoPort, "None" },

	{ kStr_ChunkNotInHeap, "The chunk was not within the heap it was supposed to be" },
	{ kStr_ChunkTooLarge, "The size of the chunk (%chunk_size) was larger than the currently accepted maximum (%chunk_max)" },
	{ kStr_InvalidFlags, "Some unused flags were set to 1" },
	{ kStr_HOffsetNotInMPT, "The hOffset field of the chunk header did not reference a memory location within a master pointer block" },
	{ kStr_HOffsetNotBackPointing, "The master pointer referenced by the hOffset field in the chunk header didnt point back to the chunk" },
	{ kStr_InvalidLockCount, "The lock count for a fixed block was not 15" },

	{ kStr_UnmappedAddress, "its in neither ROM nor RAM" },
	{ kStr_NotInCodeSegment, "its not in a valid memory chunk" },
	{ kStr_OddAddress, "its not even" },

	{ kStr_Waiting, "Waiting" },
	{ kStr_Transferring, "Transferring" },
// Reasons for why the PC was changed


	{ kStr_WhenRTS, "returning from a subroutine to the routine that called it, indicating that the return address on the stack was corrupted by a previous operation (possibly by writing past the end of an array local to the subroutine)." },
	{ kStr_WhenRTE, "returning processing an interrupt, indicating that the return address on the stack was corrupted by a previous operation (possibly by writing past the end of an array local to the interrupt service routine)." },
	{ kStr_WhenJSR, "attempting to perform an indirect jump operation, indicating that the function pointer being used is invalid." },
	{ kStr_WhenException, "processing a hardware exception, indicating that the exception vector table has been overwritten." },
	{ kStr_WhenSysCall, "invoking a Palm OS System function, indicating that the system dispatch table has been overwritten." },

	{ kStr_ShowInDialog, "Show in dialog" },
	{ kStr_AutomaticallyContinue, "Automatically continue" },
	{ kStr_AutomaticallyQuit, "Automatically quit Emulator" },
	{ kStr_NextGremlin, "Switch to next Gremlin" },

// --------------------------------------------------------------------------------
//	Template Parts -- Operations descriptions
// --------------------------------------------------------------------------------

	{ kStr_GenericOperation, "complete the operation" },

	{ kStr_CmdAbout, "show the About box" },

	{ kStr_CmdNew, "create a new session" },
	{ kStr_CmdOpen, "open the file %filename" },
	{ kStr_CmdClose, "close the window" },
	{ kStr_CmdSave, "save the file %filename" },
	{ kStr_CmdSaveBound, "save a bound emulator" },
	{ kStr_CmdSaveScreen, "save the screen" },
	{ kStr_CmdSessionInfo, "display session info" },
	{ kStr_CmdInstall, "install the Palm OS file %filename" },
	{ kStr_CmdInstallMany, "install the Palm OS files" },
	{ kStr_CmdExportDatabase, "export the database" },
	{ kStr_CmdHotSync, "start the HotSync" },
	{ kStr_CmdReset, "reset the device" },
	{ kStr_CmdTransferROM, "transfer the ROM" },
	{ kStr_CmdQuit, "quit the application" },

	{ kStr_CmdPreferences, "open the Preferences dialog box" },
	{ kStr_CmdLoggingOptions, "open the Logging Options dialog box" },
	{ kStr_CmdDebugOptions, "open the Debug Options dialog box" },
	{ kStr_CmdErrorHandling, "open the Error Handling dialog box" },
	{ kStr_CmdTracingOptions, "open the Trace Options dialog box" },
	{ kStr_CmdSkins, "open the Skins dialog box" },
	{ kStr_CmdBreakpoints, "open the Breakpoints dialog box" },

	{ kStr_CmdGremlinNew, "start the gremlin" },
	{ kStr_CmdGremlinSuspend, "suspend the gremlin" },
	{ kStr_CmdGremlinStep, "step the gremlin" },
	{ kStr_CmdGremlinResume, "resume the gremlin" },
	{ kStr_CmdGremlinStop, "stop the gremlin" },
	{ kStr_CmdEventReplay, "replay event file" },
	{ kStr_CmdEventMinimize, "start event Minimization" },

#if HAS_PROFILING
	{ kStr_CmdProfileStart, "start profiling" },
	{ kStr_CmdProfileStop, "stop profiling" },
	{ kStr_CmdProfileDump, "dump the profiling results" },
#endif


	{ kStr_CmdTracingSuspend, "suspend sending trace" },
	{ kStr_CmdTracingResume, "send trace again" },
	{ kStr_CmdTracingReconnect, "reconnect to Palm Reporter" },

	{ kStr_ResizeWindow, "resize the window" },
	{ kStr_EnterKey, "enter the key" },
	{ kStr_EnterPen, "enter the pen stroke" },
	{ kStr_PressButton, "press the hardware button" },
	{ kStr_OpenFiles, "open the selected files" },
	{ kStr_LoadPreferences, "load the application preferences" },
	{ kStr_OpenTheSerialPort, "open the serial port" },


// --------------------------------------------------------------------------------
//	Template Parts -- Error descriptions -- OS Errors
// --------------------------------------------------------------------------------

	{ kStr_GenericError, "error %error occurred" },
	{ kStr_UserCancel, "the user cancelled" },
	{ kStr_TimeoutError, "the operation timed out" },

// Disk errors
	{ kStr_DirectoryFull, "the directory is full" },
	{ kStr_DiskFull, "the disk is full" },
	{ kStr_DiskMissing, "the disk is not present" },
	{ kStr_IOError, "of a random I/O error" },
	{ kStr_BadFileName, "the file name is badly formed" },
	{ kStr_TooManyFilesOpen, "too many files are open" },
	{ kStr_FileNotFound, "the file wasnt found" },
	{ kStr_DiskWriteProtected, "the disk is write protected" },
	{ kStr_FileLocked, "the file is locked" },
	{ kStr_DiskLocked, "the disk is locked" },
	{ kStr_FileBusy, "it is being used by another application" },
	{ kStr_DuplicateFileName, "a file with that name already exists" },

// Memory errors
	{ kStr_MemFull, "the application ran out of memory" },

// Communications errors
	{ kStr_SerialPortBusy, "it is being used by another application" },

// PPC Toolbox errors

// Apple event errors

// Palm OS Errors

	{ kStr_GenericPalmError, "Palm OS error %error (%error_desc) occurred" },
	{ kStr_DmErrDatabaseOpen, "the database is currently open" },
	{ kStr_MemErrNotEnoughSpace, "the device is out of memory" },


// --------------------------------------------------------------------------------
//	Template Parts -- Error descriptions -- User/app errors
// --------------------------------------------------------------------------------

	{ kStr_OnlySameType, "you can only drag files of the same type onto the Emulator window" },
	{ kStr_OnlyOnePSF, "you can only drag one Palm Session File onto the Emulator window at a time" },
	{ kStr_OnlyOneROM, "you can only drag one Palm ROM File onto the Emulator window at a time" },
	{ kStr_UnknownType, "the Emulator doesnt support the file you just dragged onto its window" },

// PSF file errors
	{ kStr_OldFormat, "the file appears to be in an old format" },
	{ kStr_WrongROMForType, "the chosen ROM file cannot be used with the specified hardware device" },

// ROM file errors
	{ kStr_BadROM, "it doesnt appear to be a valid ROM file" },
	{ kStr_UnsupportedROM, "this Debug 2.0 ROM is not supported" },
	{ kStr_InvalidDevice, "this version of the Palm OS Emulator does not support the device required by this session file" },
	{ kStr_InvalidSession, "the session file doesn't have the minimum information required to create a new session" },
	{ kStr_InvalidConfiguration, "the given configuration information is not supported by this version of the Palm OS Emulator" },

// PRC, PDB, PQA file errors
	{ kStr_NameNotNULLTerminated, "the database name (%database_name) is too long" },
	{ kStr_NameNotPrintable, "the database name (%database_name) contains invalid characters. Only standard printable ASCII characters (that is, characters with values in the range 0x20 - 0x7E) are allowed.\n\nIf you need to display a name in the Launcher with additional characters, you can specify that name in the applications 'tAIN' resource. You can set this in the Application Icon Name field in the Project Settings section of Constructor for Palm OS, or in the APPLICATIONICONNAME field of pilrc" },
	{ kStr_FileTooSmall, "the file is too small to contain all the information it claims to have" },
	{ kStr_nextRecordListIDNonZero, "the internal header field nextRecordListID is non-zero" },
	{ kStr_ResourceTooSmall, "the size of resource '%res_type'(%res_id) is zero or negative" },
	{ kStr_RecordTooSmall, "the size of record #%record_number is negative" },
	{ kStr_ResourceOutOfRange, "the entry for resource '%res_type'(%res_id) indicates that the data for the resource is outside the range of the file" },
	{ kStr_RecordOutOfRange, "the entry for record #%record_number indicates that the data for the resource is outside the range of the file" },
	{ kStr_OverlappingResource, "the resource '%res_type'(%res_id) overlaps another resource" },
	{ kStr_OverlappingRecord, "record #%record_number overlaps another record" },
	{ kStr_ResourceMemError, "an out of memory error occurred while installing resource '%res_type'(%res_id). Its possible that the reason for this error is because the size of this resource (%res_size) is larger than the currently allowed maximum of 65505" },
	{ kStr_RecordMemError, "an out of memory error occurred while installing record #%record_number. Its possible that the reason for this error is because the size of this record (%res_size) is larger than the currently allowed maximum of 65505" },
	{ kStr_AppInfoMemError, "an out of memory error occurred while installing the app info block. Its possible that the size of this record (%res_size) is larger than the currently allowed maximum of 65505" },
	{ kStr_DuplicateResource, "a duplicate '%res_type'(%res_id) resource was found" },

	{ kStr_SystemUseOnly, "it is reserved for system use only" },
	{ kStr_Obsolete, "it is obsolete and will be removed from a future version of the Palm OS" },

// --------------------------------------------------------------------------------
//	Template Parts -- Recovery strings
// --------------------------------------------------------------------------------

	{ kStr_DeleteSomeFiles, "Delete some files and try again, or try saving to a different disk" },
	{ kStr_UnlockTheDisk, "Unlock the disk and try again" },
	{ kStr_UnlockTheFile, "Unlock the file and try again" },

	{ kStr_NeedMoreRAM, "Please give the application more memory" },

	{ kStr_TransferAROM, "To download the ROM from your Palm device, choose Transfer ROM from the File menu" },
	{ kStr_DownloadAROM, "Please download the latest from http://www.palm.com" },


// --------------------------------------------------------------------------------
//	Template Parts -- Exception descriptions
// --------------------------------------------------------------------------------

	{ kStr_ExceptionBase + 0, "<Nothing>" },
	{ kStr_ExceptionBase + 1, "<Nothing>" },
	{ kStr_ExceptionBase + 2, "bus error" },
	{ kStr_ExceptionBase + 3, "address error" },
	{ kStr_ExceptionBase + 4, "illegal instruction" },
	{ kStr_ExceptionBase + 5, "divide by zero" },
	{ kStr_ExceptionBase + 6, "CHK instruction" },
	{ kStr_ExceptionBase + 7, "TRAP instruction" },
	{ kStr_ExceptionBase + 8, "privilege violation" },
	{ kStr_ExceptionBase + 9, "trace" },
	{ kStr_ExceptionBase + 10, "line 1010 instruction" },
	{ kStr_ExceptionBase + 11, "line 1111 instruction" },
	{ kStr_ExceptionBase + 12, "reserved - 12" },
	{ kStr_ExceptionBase + 13, "coprocessor error" },
	{ kStr_ExceptionBase + 14, "format error" },
	{ kStr_ExceptionBase + 15, "uninitialized interrupt" },
	{ kStr_ExceptionBase + 16, "reserved - 0" },
	{ kStr_ExceptionBase + 17, "reserved - 1" },
	{ kStr_ExceptionBase + 18, "reserved - 2" },
	{ kStr_ExceptionBase + 19, "reserved - 3" },
	{ kStr_ExceptionBase + 20, "reserved - 4" },
	{ kStr_ExceptionBase + 21, "reserved - 5" },
	{ kStr_ExceptionBase + 22, "reserved - 6" },
	{ kStr_ExceptionBase + 23, "reserved - 7" },
	{ kStr_ExceptionBase + 24, "spurious interrupt" },
	{ kStr_ExceptionBase + 25, "interrupt - 1" },
	{ kStr_ExceptionBase + 26, "interrupt - 2" },
	{ kStr_ExceptionBase + 27, "interrupt - 3" },
	{ kStr_ExceptionBase + 28, "interrupt - 4" },
	{ kStr_ExceptionBase + 29, "interrupt - 5" },
	{ kStr_ExceptionBase + 30, "interrupt - 6" },
	{ kStr_ExceptionBase + 31, "interrupt - 7" },
	{ kStr_ExceptionBase + 32, "TRAP $0" },
	{ kStr_ExceptionBase + 33, "TRAP $1" },
	{ kStr_ExceptionBase + 34, "TRAP $2" },
	{ kStr_ExceptionBase + 35, "TRAP $3" },
	{ kStr_ExceptionBase + 36, "TRAP $4" },
	{ kStr_ExceptionBase + 37, "TRAP $5" },
	{ kStr_ExceptionBase + 38, "TRAP $6" },
	{ kStr_ExceptionBase + 39, "TRAP $7" },
	{ kStr_ExceptionBase + 40, "TRAP $8" },
	{ kStr_ExceptionBase + 41, "TRAP $9" },
	{ kStr_ExceptionBase + 42, "TRAP $A" },
	{ kStr_ExceptionBase + 43, "TRAP $B" },
	{ kStr_ExceptionBase + 44, "TRAP $C" },
	{ kStr_ExceptionBase + 45, "TRAP $D" },
	{ kStr_ExceptionBase + 46, "TRAP $E" },
	{ kStr_ExceptionBase + 47, "TRAP $F" },
	{ kStr_ExceptionBase + 48, "unassigned - 0" },
	{ kStr_ExceptionBase + 49, "unassigned - 1" },
	{ kStr_ExceptionBase + 50, "unassigned - 2" },
	{ kStr_ExceptionBase + 51, "unassigned - 3" },
	{ kStr_ExceptionBase + 52, "unassigned - 4" },
	{ kStr_ExceptionBase + 53, "unassigned - 5" },
	{ kStr_ExceptionBase + 54, "unassigned - 6" },
	{ kStr_ExceptionBase + 55, "unassigned - 7" },
	{ kStr_ExceptionBase + 56, "unassigned - 8" },
	{ kStr_ExceptionBase + 57, "unassigned - 9" },
	{ kStr_ExceptionBase + 58, "unassigned - 10" },
	{ kStr_ExceptionBase + 59, "unassigned - 11" },
	{ kStr_ExceptionBase + 60, "unassigned - 12" },
	{ kStr_ExceptionBase + 61, "unassigned - 13" },
	{ kStr_ExceptionBase + 62, "unassigned - 14" },
	{ kStr_ExceptionBase + 63, "unassigned - 15" },

// --------------------------------------------------------------------------------
//	Template Parts -- System function names
// --------------------------------------------------------------------------------

/*
	The following strings were generated with the following MPW script:

		#######################################################################
		# Setup Variables
		#######################################################################
		set TrapNum 1
		set Space '[ t]+'
		
		Set Src "Phantom:Palm:Projects:Palm:Viewer:dev:4.0:primary:Incs:Core:CoreTraps.h"
		set Dest "{DesktopFolder}SystemTrapNames"
		
		#######################################################################
		# Copy the System Header File to a temporary file
		#######################################################################
		duplicate -y -d "{Src}" "{Dest}"
		setfile -a l "{Dest}"
		open "{Dest}"
		Target "{Dest}"
		
		#######################################################################
		# Delete everything except the trap table enumerated type
		#######################################################################
		replace  :/sysTrapBase/ ""
		replace /#define[ t]+sysTrapLastTrapNumber/: ""
		
		#######################################################################
		# Get rid of Comments
		#######################################################################
		find 
		replace -c  //// ""
		
		#######################################################################
		# Go through and replace each line with a debugger script command
		#######################################################################
		Set Exit 0
		Set TrapNum 0
		Find 
		Loop
			replace /#define[ t]+sysTrap([a-zA-Z0-9]+)1Ű/  "ID=kStr_SysTrapBase+{TrapNum}nENGLISH=1n"
			Break If {Status} != 0
			Set TrapNum `Evaluate {TrapNum}+1`
		End
		
		#######################################################################
		# Strip trailing spaces.  Collapse multiple blank lines.
		#######################################################################
		Find 
		Replace -c  /[tf ]+/ ""
		
		Find 
		Replace -c  /n[n]+/ "nn"
		
		Close -y "{Dest}"
*/

	{ kStr_SysTrapBase+0, "MemInit" },
	{ kStr_SysTrapBase+1, "MemInitHeapTable" },
	{ kStr_SysTrapBase+2, "MemStoreInit" },
	{ kStr_SysTrapBase+3, "MemCardFormat" },
	{ kStr_SysTrapBase+4, "MemCardInfo" },
	{ kStr_SysTrapBase+5, "MemStoreInfo" },
	{ kStr_SysTrapBase+6, "MemStoreSetInfo" },
	{ kStr_SysTrapBase+7, "MemNumHeaps" },
	{ kStr_SysTrapBase+8, "MemNumRAMHeaps" },
	{ kStr_SysTrapBase+9, "MemHeapID" },
	{ kStr_SysTrapBase+10, "MemHeapPtr" },
	{ kStr_SysTrapBase+11, "MemHeapFreeBytes" },
	{ kStr_SysTrapBase+12, "MemHeapSize" },
	{ kStr_SysTrapBase+13, "MemHeapFlags" },
	{ kStr_SysTrapBase+14, "MemHeapCompact" },
	{ kStr_SysTrapBase+15, "MemHeapInit" },
	{ kStr_SysTrapBase+16, "MemHeapFreeByOwnerID" },
	{ kStr_SysTrapBase+17, "MemChunkNew" },
	{ kStr_SysTrapBase+18, "MemChunkFree" },
	{ kStr_SysTrapBase+19, "MemPtrNew" },
	{ kStr_SysTrapBase+20, "MemPtrRecoverHandle" },
	{ kStr_SysTrapBase+21, "MemPtrFlags" },
	{ kStr_SysTrapBase+22, "MemPtrSize" },
	{ kStr_SysTrapBase+23, "MemPtrOwner" },
	{ kStr_SysTrapBase+24, "MemPtrHeapID" },
	{ kStr_SysTrapBase+25, "MemPtrCardNo" },
	{ kStr_SysTrapBase+26, "MemPtrToLocalID" },
	{ kStr_SysTrapBase+27, "MemPtrSetOwner" },
	{ kStr_SysTrapBase+28, "MemPtrResize" },
	{ kStr_SysTrapBase+29, "MemPtrResetLock" },
	{ kStr_SysTrapBase+30, "MemHandleNew" },
	{ kStr_SysTrapBase+31, "MemHandleLockCount" },
	{ kStr_SysTrapBase+32, "MemHandleToLocalID" },
	{ kStr_SysTrapBase+33, "MemHandleLock" },
	{ kStr_SysTrapBase+34, "MemHandleUnlock" },
	{ kStr_SysTrapBase+35, "MemLocalIDToGlobal" },
	{ kStr_SysTrapBase+36, "MemLocalIDKind" },
	{ kStr_SysTrapBase+37, "MemLocalIDToPtr" },
	{ kStr_SysTrapBase+38, "MemMove" },
	{ kStr_SysTrapBase+39, "MemSet" },
	{ kStr_SysTrapBase+40, "MemStoreSearch" },
	{ kStr_SysTrapBase+41, "SysReserved10Trap1" },
	{ kStr_SysTrapBase+42, "MemKernelInit" },
	{ kStr_SysTrapBase+43, "MemHandleFree" },
	{ kStr_SysTrapBase+44, "MemHandleFlags" },
	{ kStr_SysTrapBase+45, "MemHandleSize" },
	{ kStr_SysTrapBase+46, "MemHandleOwner" },
	{ kStr_SysTrapBase+47, "MemHandleHeapID" },
	{ kStr_SysTrapBase+48, "MemHandleDataStorage" },
	{ kStr_SysTrapBase+49, "MemHandleCardNo" },
	{ kStr_SysTrapBase+50, "MemHandleSetOwner" },
	{ kStr_SysTrapBase+51, "MemHandleResize" },
	{ kStr_SysTrapBase+52, "MemHandleResetLock" },
	{ kStr_SysTrapBase+53, "MemPtrUnlock" },
	{ kStr_SysTrapBase+54, "MemLocalIDToLockedPtr" },
	{ kStr_SysTrapBase+55, "MemSetDebugMode" },
	{ kStr_SysTrapBase+56, "MemHeapScramble" },
	{ kStr_SysTrapBase+57, "MemHeapCheck" },
	{ kStr_SysTrapBase+58, "MemNumCards" },
	{ kStr_SysTrapBase+59, "MemDebugMode" },
	{ kStr_SysTrapBase+60, "MemSemaphoreReserve" },
	{ kStr_SysTrapBase+61, "MemSemaphoreRelease" },
	{ kStr_SysTrapBase+62, "MemHeapDynamic" },
	{ kStr_SysTrapBase+63, "MemNVParams" },
	{ kStr_SysTrapBase+64, "DmInit" },
	{ kStr_SysTrapBase+65, "DmCreateDatabase" },
	{ kStr_SysTrapBase+66, "DmDeleteDatabase" },
	{ kStr_SysTrapBase+67, "DmNumDatabases" },
	{ kStr_SysTrapBase+68, "DmGetDatabase" },
	{ kStr_SysTrapBase+69, "DmFindDatabase" },
	{ kStr_SysTrapBase+70, "DmDatabaseInfo" },
	{ kStr_SysTrapBase+71, "DmSetDatabaseInfo" },
	{ kStr_SysTrapBase+72, "DmDatabaseSize" },
	{ kStr_SysTrapBase+73, "DmOpenDatabase" },
	{ kStr_SysTrapBase+74, "DmCloseDatabase" },
	{ kStr_SysTrapBase+75, "DmNextOpenDatabase" },
	{ kStr_SysTrapBase+76, "DmOpenDatabaseInfo" },
	{ kStr_SysTrapBase+77, "DmResetRecordStates" },
	{ kStr_SysTrapBase+78, "DmGetLastErr" },
	{ kStr_SysTrapBase+79, "DmNumRecords" },
	{ kStr_SysTrapBase+80, "DmRecordInfo" },
	{ kStr_SysTrapBase+81, "DmSetRecordInfo" },
	{ kStr_SysTrapBase+82, "DmAttachRecord" },
	{ kStr_SysTrapBase+83, "DmDetachRecord" },
	{ kStr_SysTrapBase+84, "DmMoveRecord" },
	{ kStr_SysTrapBase+85, "DmNewRecord" },
	{ kStr_SysTrapBase+86, "DmRemoveRecord" },
	{ kStr_SysTrapBase+87, "DmDeleteRecord" },
	{ kStr_SysTrapBase+88, "DmArchiveRecord" },
	{ kStr_SysTrapBase+89, "DmNewHandle" },
	{ kStr_SysTrapBase+90, "DmRemoveSecretRecords" },
	{ kStr_SysTrapBase+91, "DmQueryRecord" },
	{ kStr_SysTrapBase+92, "DmGetRecord" },
	{ kStr_SysTrapBase+93, "DmResizeRecord" },
	{ kStr_SysTrapBase+94, "DmReleaseRecord" },
	{ kStr_SysTrapBase+95, "DmGetResource" },
	{ kStr_SysTrapBase+96, "DmGet1Resource" },
	{ kStr_SysTrapBase+97, "DmReleaseResource" },
	{ kStr_SysTrapBase+98, "DmResizeResource" },
	{ kStr_SysTrapBase+99, "DmNextOpenResDatabase" },
	{ kStr_SysTrapBase+100, "DmFindResourceType" },
	{ kStr_SysTrapBase+101, "DmFindResource" },
	{ kStr_SysTrapBase+102, "DmSearchResource" },
	{ kStr_SysTrapBase+103, "DmNumResources" },
	{ kStr_SysTrapBase+104, "DmResourceInfo" },
	{ kStr_SysTrapBase+105, "DmSetResourceInfo" },
	{ kStr_SysTrapBase+106, "DmAttachResource" },
	{ kStr_SysTrapBase+107, "DmDetachResource" },
	{ kStr_SysTrapBase+108, "DmNewResource" },
	{ kStr_SysTrapBase+109, "DmRemoveResource" },
	{ kStr_SysTrapBase+110, "DmGetResourceIndex" },
	{ kStr_SysTrapBase+111, "DmQuickSort" },
	{ kStr_SysTrapBase+112, "DmQueryNextInCategory" },
	{ kStr_SysTrapBase+113, "DmNumRecordsInCategory" },
	{ kStr_SysTrapBase+114, "DmPositionInCategory" },
	{ kStr_SysTrapBase+115, "DmSeekRecordInCategory" },
	{ kStr_SysTrapBase+116, "DmMoveCategory" },
	{ kStr_SysTrapBase+117, "DmOpenDatabaseByTypeCreator" },
	{ kStr_SysTrapBase+118, "DmWrite" },
	{ kStr_SysTrapBase+119, "DmStrCopy" },
	{ kStr_SysTrapBase+120, "DmGetNextDatabaseByTypeCreator" },
	{ kStr_SysTrapBase+121, "DmWriteCheck" },
	{ kStr_SysTrapBase+122, "DmMoveOpenDBContext" },
	{ kStr_SysTrapBase+123, "DmFindRecordByID" },
	{ kStr_SysTrapBase+124, "DmGetAppInfoID" },
	{ kStr_SysTrapBase+125, "DmFindSortPositionV10" },
	{ kStr_SysTrapBase+126, "DmSet" },
	{ kStr_SysTrapBase+127, "DmCreateDatabaseFromImage" },
	{ kStr_SysTrapBase+128, "DbgSrcMessage" },
	{ kStr_SysTrapBase+129, "DbgMessage" },
	{ kStr_SysTrapBase+130, "DbgGetMessage" },
	{ kStr_SysTrapBase+131, "DbgCommSettings" },
	{ kStr_SysTrapBase+132, "ErrDisplayFileLineMsg" },
	{ kStr_SysTrapBase+133, "ErrSetJump" },
	{ kStr_SysTrapBase+134, "ErrLongJump" },
	{ kStr_SysTrapBase+135, "ErrThrow" },
	{ kStr_SysTrapBase+136, "ErrExceptionList" },
	{ kStr_SysTrapBase+137, "SysBroadcastActionCode" },
	{ kStr_SysTrapBase+138, "SysUnimplemented" },
	{ kStr_SysTrapBase+139, "SysColdBoot" },
	{ kStr_SysTrapBase+140, "SysReset" },
	{ kStr_SysTrapBase+141, "SysDoze" },
	{ kStr_SysTrapBase+142, "SysAppLaunch" },
	{ kStr_SysTrapBase+143, "SysAppStartup" },
	{ kStr_SysTrapBase+144, "SysAppExit" },
	{ kStr_SysTrapBase+145, "SysSetA5" },
	{ kStr_SysTrapBase+146, "SysSetTrapAddress" },
	{ kStr_SysTrapBase+147, "SysGetTrapAddress" },
	{ kStr_SysTrapBase+148, "SysTranslateKernelErr" },
	{ kStr_SysTrapBase+149, "SysSemaphoreCreate" },
	{ kStr_SysTrapBase+150, "SysSemaphoreDelete" },
	{ kStr_SysTrapBase+151, "SysSemaphoreWait" },
	{ kStr_SysTrapBase+152, "SysSemaphoreSignal" },
	{ kStr_SysTrapBase+153, "SysTimerCreate" },
	{ kStr_SysTrapBase+154, "SysTimerWrite" },
	{ kStr_SysTrapBase+155, "SysTaskCreate" },
	{ kStr_SysTrapBase+156, "SysTaskDelete" },
	{ kStr_SysTrapBase+157, "SysTaskTrigger" },
	{ kStr_SysTrapBase+158, "SysTaskID" },
	{ kStr_SysTrapBase+159, "SysTaskUserInfoPtr" },
	{ kStr_SysTrapBase+160, "SysTaskDelay" },
	{ kStr_SysTrapBase+161, "SysTaskSetTermProc" },
	{ kStr_SysTrapBase+162, "SysUILaunch" },
	{ kStr_SysTrapBase+163, "SysNewOwnerID" },
	{ kStr_SysTrapBase+164, "SysSemaphoreSet" },
	{ kStr_SysTrapBase+165, "SysDisableInts" },
	{ kStr_SysTrapBase+166, "SysRestoreStatus" },
	{ kStr_SysTrapBase+167, "SysUIAppSwitch" },
	{ kStr_SysTrapBase+168, "SysCurAppInfoPV20" },
	{ kStr_SysTrapBase+169, "SysHandleEvent" },
	{ kStr_SysTrapBase+170, "SysInit" },
	{ kStr_SysTrapBase+171, "SysQSort" },
	{ kStr_SysTrapBase+172, "SysCurAppDatabase" },
	{ kStr_SysTrapBase+173, "SysFatalAlert" },
	{ kStr_SysTrapBase+174, "SysResSemaphoreCreate" },
	{ kStr_SysTrapBase+175, "SysResSemaphoreDelete" },
	{ kStr_SysTrapBase+176, "SysResSemaphoreReserve" },
	{ kStr_SysTrapBase+177, "SysResSemaphoreRelease" },
	{ kStr_SysTrapBase+178, "SysSleep" },
	{ kStr_SysTrapBase+179, "SysKeyboardDialogV10" },
	{ kStr_SysTrapBase+180, "SysAppLauncherDialog" },
	{ kStr_SysTrapBase+181, "SysSetPerformance" },
	{ kStr_SysTrapBase+182, "SysBatteryInfoV20" },
	{ kStr_SysTrapBase+183, "SysLibInstall" },
	{ kStr_SysTrapBase+184, "SysLibRemove" },
	{ kStr_SysTrapBase+185, "SysLibTblEntry" },
	{ kStr_SysTrapBase+186, "SysLibFind" },
	{ kStr_SysTrapBase+187, "SysBatteryDialog" },
	{ kStr_SysTrapBase+188, "SysCopyStringResource" },
	{ kStr_SysTrapBase+189, "SysKernelInfo" },
	{ kStr_SysTrapBase+190, "SysLaunchConsole" },
	{ kStr_SysTrapBase+191, "SysTimerDelete" },
	{ kStr_SysTrapBase+192, "SysSetAutoOffTime" },
	{ kStr_SysTrapBase+193, "SysFormPointerArrayToStrings" },
	{ kStr_SysTrapBase+194, "SysRandom" },
	{ kStr_SysTrapBase+195, "SysTaskSwitching" },
	{ kStr_SysTrapBase+196, "SysTimerRead" },
	{ kStr_SysTrapBase+197, "StrCopy" },
	{ kStr_SysTrapBase+198, "StrCat" },
	{ kStr_SysTrapBase+199, "StrLen" },
	{ kStr_SysTrapBase+200, "StrCompare" },
	{ kStr_SysTrapBase+201, "StrIToA" },
	{ kStr_SysTrapBase+202, "StrCaselessCompare" },
	{ kStr_SysTrapBase+203, "StrIToH" },
	{ kStr_SysTrapBase+204, "StrChr" },
	{ kStr_SysTrapBase+205, "StrStr" },
	{ kStr_SysTrapBase+206, "StrAToI" },
	{ kStr_SysTrapBase+207, "StrToLower" },
	{ kStr_SysTrapBase+208, "SerReceiveISP" },
	{ kStr_SysTrapBase+209, "SlkOpen" },
	{ kStr_SysTrapBase+210, "SlkClose" },
	{ kStr_SysTrapBase+211, "SlkOpenSocket" },
	{ kStr_SysTrapBase+212, "SlkCloseSocket" },
	{ kStr_SysTrapBase+213, "SlkSocketRefNum" },
	{ kStr_SysTrapBase+214, "SlkSocketSetTimeout" },
	{ kStr_SysTrapBase+215, "SlkFlushSocket" },
	{ kStr_SysTrapBase+216, "SlkSetSocketListener" },
	{ kStr_SysTrapBase+217, "SlkSendPacket" },
	{ kStr_SysTrapBase+218, "SlkReceivePacket" },
	{ kStr_SysTrapBase+219, "SlkSysPktDefaultResponse" },
	{ kStr_SysTrapBase+220, "SlkProcessRPC" },
	{ kStr_SysTrapBase+221, "ConPutS" },
	{ kStr_SysTrapBase+222, "ConGetS" },
	{ kStr_SysTrapBase+223, "FplInit" },
	{ kStr_SysTrapBase+224, "FplFree" },
	{ kStr_SysTrapBase+225, "FplFToA" },
	{ kStr_SysTrapBase+226, "FplAToF" },
	{ kStr_SysTrapBase+227, "FplBase10Info" },
	{ kStr_SysTrapBase+228, "FplLongToFloat" },
	{ kStr_SysTrapBase+229, "FplFloatToLong" },
	{ kStr_SysTrapBase+230, "FplFloatToULong" },
	{ kStr_SysTrapBase+231, "FplMul" },
	{ kStr_SysTrapBase+232, "FplAdd" },
	{ kStr_SysTrapBase+233, "FplSub" },
	{ kStr_SysTrapBase+234, "FplDiv" },
	{ kStr_SysTrapBase+235, "WinScreenInit" },
	{ kStr_SysTrapBase+236, "ScrCopyRectangle" },
	{ kStr_SysTrapBase+237, "ScrDrawChars" },
	{ kStr_SysTrapBase+238, "ScrLineRoutine" },
	{ kStr_SysTrapBase+239, "ScrRectangleRoutine" },
	{ kStr_SysTrapBase+240, "ScrScreenInfo" },
	{ kStr_SysTrapBase+241, "ScrDrawNotify" },
	{ kStr_SysTrapBase+242, "ScrSendUpdateArea" },
	{ kStr_SysTrapBase+243, "ScrCompressScanLine" },
	{ kStr_SysTrapBase+244, "ScrDeCompressScanLine" },
	{ kStr_SysTrapBase+245, "TimGetSeconds" },
	{ kStr_SysTrapBase+246, "TimSetSeconds" },
	{ kStr_SysTrapBase+247, "TimGetTicks" },
	{ kStr_SysTrapBase+248, "TimInit" },
	{ kStr_SysTrapBase+249, "TimSetAlarm" },
	{ kStr_SysTrapBase+250, "TimGetAlarm" },
	{ kStr_SysTrapBase+251, "TimHandleInterrupt" },
	{ kStr_SysTrapBase+252, "TimSecondsToDateTime" },
	{ kStr_SysTrapBase+253, "TimDateTimeToSeconds" },
	{ kStr_SysTrapBase+254, "TimAdjust" },
	{ kStr_SysTrapBase+255, "TimSleep" },
	{ kStr_SysTrapBase+256, "TimWake" },
	{ kStr_SysTrapBase+257, "CategoryCreateListV10" },
	{ kStr_SysTrapBase+258, "CategoryFreeListV10" },
	{ kStr_SysTrapBase+259, "CategoryFind" },
	{ kStr_SysTrapBase+260, "CategoryGetName" },
	{ kStr_SysTrapBase+261, "CategoryEditV10" },
	{ kStr_SysTrapBase+262, "CategorySelectV10" },
	{ kStr_SysTrapBase+263, "CategoryGetNext" },
	{ kStr_SysTrapBase+264, "CategorySetTriggerLabel" },
	{ kStr_SysTrapBase+265, "CategoryTruncateName" },
	{ kStr_SysTrapBase+266, "ClipboardAddItem" },
	{ kStr_SysTrapBase+267, "ClipboardCheckIfItemExist" },
	{ kStr_SysTrapBase+268, "ClipboardGetItem" },
	{ kStr_SysTrapBase+269, "CtlDrawControl" },
	{ kStr_SysTrapBase+270, "CtlEraseControl" },
	{ kStr_SysTrapBase+271, "CtlHideControl" },
	{ kStr_SysTrapBase+272, "CtlShowControl" },
	{ kStr_SysTrapBase+273, "CtlGetValue" },
	{ kStr_SysTrapBase+274, "CtlSetValue" },
	{ kStr_SysTrapBase+275, "CtlGetLabel" },
	{ kStr_SysTrapBase+276, "CtlSetLabel" },
	{ kStr_SysTrapBase+277, "CtlHandleEvent" },
	{ kStr_SysTrapBase+278, "CtlHitControl" },
	{ kStr_SysTrapBase+279, "CtlSetEnabled" },
	{ kStr_SysTrapBase+280, "CtlSetUsable" },
	{ kStr_SysTrapBase+281, "CtlEnabled" },
	{ kStr_SysTrapBase+282, "EvtInitialize" },
	{ kStr_SysTrapBase+283, "EvtAddEventToQueue" },
	{ kStr_SysTrapBase+284, "EvtCopyEvent" },
	{ kStr_SysTrapBase+285, "EvtGetEvent" },
	{ kStr_SysTrapBase+286, "EvtGetPen" },
	{ kStr_SysTrapBase+287, "EvtSysInit" },
	{ kStr_SysTrapBase+288, "EvtGetSysEvent" },
	{ kStr_SysTrapBase+289, "EvtProcessSoftKeyStroke" },
	{ kStr_SysTrapBase+290, "EvtGetPenBtnList" },
	{ kStr_SysTrapBase+291, "EvtSetPenQueuePtr" },
	{ kStr_SysTrapBase+292, "EvtPenQueueSize" },
	{ kStr_SysTrapBase+293, "EvtFlushPenQueue" },
	{ kStr_SysTrapBase+294, "EvtEnqueuePenPoint" },
	{ kStr_SysTrapBase+295, "EvtDequeuePenStrokeInfo" },
	{ kStr_SysTrapBase+296, "EvtDequeuePenPoint" },
	{ kStr_SysTrapBase+297, "EvtFlushNextPenStroke" },
	{ kStr_SysTrapBase+298, "EvtSetKeyQueuePtr" },
	{ kStr_SysTrapBase+299, "EvtKeyQueueSize" },
	{ kStr_SysTrapBase+300, "EvtFlushKeyQueue" },
	{ kStr_SysTrapBase+301, "EvtEnqueueKey" },
	{ kStr_SysTrapBase+302, "EvtDequeueKeyEvent" },
	{ kStr_SysTrapBase+303, "EvtWakeup" },
	{ kStr_SysTrapBase+304, "EvtResetAutoOffTimer" },
	{ kStr_SysTrapBase+305, "EvtKeyQueueEmpty" },
	{ kStr_SysTrapBase+306, "EvtEnableGraffiti" },
	{ kStr_SysTrapBase+307, "FldCopy" },
	{ kStr_SysTrapBase+308, "FldCut" },
	{ kStr_SysTrapBase+309, "FldDrawField" },
	{ kStr_SysTrapBase+310, "FldEraseField" },
	{ kStr_SysTrapBase+311, "FldFreeMemory" },
	{ kStr_SysTrapBase+312, "FldGetBounds" },
	{ kStr_SysTrapBase+313, "FldGetTextPtr" },
	{ kStr_SysTrapBase+314, "FldGetSelection" },
	{ kStr_SysTrapBase+315, "FldHandleEvent" },
	{ kStr_SysTrapBase+316, "FldPaste" },
	{ kStr_SysTrapBase+317, "FldRecalculateField" },
	{ kStr_SysTrapBase+318, "FldSetBounds" },
	{ kStr_SysTrapBase+319, "FldSetText" },
	{ kStr_SysTrapBase+320, "FldGetFont" },
	{ kStr_SysTrapBase+321, "FldSetFont" },
	{ kStr_SysTrapBase+322, "FldSetSelection" },
	{ kStr_SysTrapBase+323, "FldGrabFocus" },
	{ kStr_SysTrapBase+324, "FldReleaseFocus" },
	{ kStr_SysTrapBase+325, "FldGetInsPtPosition" },
	{ kStr_SysTrapBase+326, "FldSetInsPtPosition" },
	{ kStr_SysTrapBase+327, "FldSetScrollPosition" },
	{ kStr_SysTrapBase+328, "FldGetScrollPosition" },
	{ kStr_SysTrapBase+329, "FldGetTextHeight" },
	{ kStr_SysTrapBase+330, "FldGetTextAllocatedSize" },
	{ kStr_SysTrapBase+331, "FldGetTextLength" },
	{ kStr_SysTrapBase+332, "FldScrollField" },
	{ kStr_SysTrapBase+333, "FldScrollable" },
	{ kStr_SysTrapBase+334, "FldGetVisibleLines" },
	{ kStr_SysTrapBase+335, "FldGetAttributes" },
	{ kStr_SysTrapBase+336, "FldSetAttributes" },
	{ kStr_SysTrapBase+337, "FldSendChangeNotification" },
	{ kStr_SysTrapBase+338, "FldCalcFieldHeight" },
	{ kStr_SysTrapBase+339, "FldGetTextHandle" },
	{ kStr_SysTrapBase+340, "FldCompactText" },
	{ kStr_SysTrapBase+341, "FldDirty" },
	{ kStr_SysTrapBase+342, "FldWordWrap" },
	{ kStr_SysTrapBase+343, "FldSetTextAllocatedSize" },
	{ kStr_SysTrapBase+344, "FldSetTextHandle" },
	{ kStr_SysTrapBase+345, "FldSetTextPtr" },
	{ kStr_SysTrapBase+346, "FldGetMaxChars" },
	{ kStr_SysTrapBase+347, "FldSetMaxChars" },
	{ kStr_SysTrapBase+348, "FldSetUsable" },
	{ kStr_SysTrapBase+349, "FldInsert" },
	{ kStr_SysTrapBase+350, "FldDelete" },
	{ kStr_SysTrapBase+351, "FldUndo" },
	{ kStr_SysTrapBase+352, "FldSetDirty" },
	{ kStr_SysTrapBase+353, "FldSendHeightChangeNotification" },
	{ kStr_SysTrapBase+354, "FldMakeFullyVisible" },
	{ kStr_SysTrapBase+355, "FntGetFont" },
	{ kStr_SysTrapBase+356, "FntSetFont" },
	{ kStr_SysTrapBase+357, "FntGetFontPtr" },
	{ kStr_SysTrapBase+358, "FntBaseLine" },
	{ kStr_SysTrapBase+359, "FntCharHeight" },
	{ kStr_SysTrapBase+360, "FntLineHeight" },
	{ kStr_SysTrapBase+361, "FntAverageCharWidth" },
	{ kStr_SysTrapBase+362, "FntCharWidth" },
	{ kStr_SysTrapBase+363, "FntCharsWidth" },
	{ kStr_SysTrapBase+364, "FntDescenderHeight" },
	{ kStr_SysTrapBase+365, "FntCharsInWidth" },
	{ kStr_SysTrapBase+366, "FntLineWidth" },
	{ kStr_SysTrapBase+367, "FrmInitForm" },
	{ kStr_SysTrapBase+368, "FrmDeleteForm" },
	{ kStr_SysTrapBase+369, "FrmDrawForm" },
	{ kStr_SysTrapBase+370, "FrmEraseForm" },
	{ kStr_SysTrapBase+371, "FrmGetActiveForm" },
	{ kStr_SysTrapBase+372, "FrmSetActiveForm" },
	{ kStr_SysTrapBase+373, "FrmGetActiveFormID" },
	{ kStr_SysTrapBase+374, "FrmGetUserModifiedState" },
	{ kStr_SysTrapBase+375, "FrmSetNotUserModified" },
	{ kStr_SysTrapBase+376, "FrmGetFocus" },
	{ kStr_SysTrapBase+377, "FrmSetFocus" },
	{ kStr_SysTrapBase+378, "FrmHandleEvent" },
	{ kStr_SysTrapBase+379, "FrmGetFormBounds" },
	{ kStr_SysTrapBase+380, "FrmGetWindowHandle" },
	{ kStr_SysTrapBase+381, "FrmGetFormId" },
	{ kStr_SysTrapBase+382, "FrmGetFormPtr" },
	{ kStr_SysTrapBase+383, "FrmGetNumberOfObjects" },
	{ kStr_SysTrapBase+384, "FrmGetObjectIndex" },
	{ kStr_SysTrapBase+385, "FrmGetObjectId" },
	{ kStr_SysTrapBase+386, "FrmGetObjectType" },
	{ kStr_SysTrapBase+387, "FrmGetObjectPtr" },
	{ kStr_SysTrapBase+388, "FrmHideObject" },
	{ kStr_SysTrapBase+389, "FrmShowObject" },
	{ kStr_SysTrapBase+390, "FrmGetObjectPosition" },
	{ kStr_SysTrapBase+391, "FrmSetObjectPosition" },
	{ kStr_SysTrapBase+392, "FrmGetControlValue" },
	{ kStr_SysTrapBase+393, "FrmSetControlValue" },
	{ kStr_SysTrapBase+394, "FrmGetControlGroupSelection" },
	{ kStr_SysTrapBase+395, "FrmSetControlGroupSelection" },
	{ kStr_SysTrapBase+396, "FrmCopyLabel" },
	{ kStr_SysTrapBase+397, "FrmSetLabel" },
	{ kStr_SysTrapBase+398, "FrmGetLabel" },
	{ kStr_SysTrapBase+399, "FrmSetCategoryLabel" },
	{ kStr_SysTrapBase+400, "FrmGetTitle" },
	{ kStr_SysTrapBase+401, "FrmSetTitle" },
	{ kStr_SysTrapBase+402, "FrmAlert" },
	{ kStr_SysTrapBase+403, "FrmDoDialog" },
	{ kStr_SysTrapBase+404, "FrmCustomAlert" },
	{ kStr_SysTrapBase+405, "FrmHelp" },
	{ kStr_SysTrapBase+406, "FrmUpdateScrollers" },
	{ kStr_SysTrapBase+407, "FrmGetFirstForm" },
	{ kStr_SysTrapBase+408, "FrmVisible" },
	{ kStr_SysTrapBase+409, "FrmGetObjectBounds" },
	{ kStr_SysTrapBase+410, "FrmCopyTitle" },
	{ kStr_SysTrapBase+411, "FrmGotoForm" },
	{ kStr_SysTrapBase+412, "FrmPopupForm" },
	{ kStr_SysTrapBase+413, "FrmUpdateForm" },
	{ kStr_SysTrapBase+414, "FrmReturnToForm" },
	{ kStr_SysTrapBase+415, "FrmSetEventHandler" },
	{ kStr_SysTrapBase+416, "FrmDispatchEvent" },
	{ kStr_SysTrapBase+417, "FrmCloseAllForms" },
	{ kStr_SysTrapBase+418, "FrmSaveAllForms" },
	{ kStr_SysTrapBase+419, "FrmGetGadgetData" },
	{ kStr_SysTrapBase+420, "FrmSetGadgetData" },
	{ kStr_SysTrapBase+421, "FrmSetCategoryTrigger" },
	{ kStr_SysTrapBase+422, "UIInitialize" },
	{ kStr_SysTrapBase+423, "UIReset" },
	{ kStr_SysTrapBase+424, "InsPtInitialize" },
	{ kStr_SysTrapBase+425, "InsPtSetLocation" },
	{ kStr_SysTrapBase+426, "InsPtGetLocation" },
	{ kStr_SysTrapBase+427, "InsPtEnable" },
	{ kStr_SysTrapBase+428, "InsPtEnabled" },
	{ kStr_SysTrapBase+429, "InsPtSetHeight" },
	{ kStr_SysTrapBase+430, "InsPtGetHeight" },
	{ kStr_SysTrapBase+431, "InsPtCheckBlink" },
	{ kStr_SysTrapBase+432, "LstSetDrawFunction" },
	{ kStr_SysTrapBase+433, "LstDrawList" },
	{ kStr_SysTrapBase+434, "LstEraseList" },
	{ kStr_SysTrapBase+435, "LstGetSelection" },
	{ kStr_SysTrapBase+436, "LstGetSelectionText" },
	{ kStr_SysTrapBase+437, "LstHandleEvent" },
	{ kStr_SysTrapBase+438, "LstSetHeight" },
	{ kStr_SysTrapBase+439, "LstSetSelection" },
	{ kStr_SysTrapBase+440, "LstSetListChoices" },
	{ kStr_SysTrapBase+441, "LstMakeItemVisible" },
	{ kStr_SysTrapBase+442, "LstGetNumberOfItems" },
	{ kStr_SysTrapBase+443, "LstPopupList" },
	{ kStr_SysTrapBase+444, "LstSetPosition" },
	{ kStr_SysTrapBase+445, "MenuInit" },
	{ kStr_SysTrapBase+446, "MenuDispose" },
	{ kStr_SysTrapBase+447, "MenuHandleEvent" },
	{ kStr_SysTrapBase+448, "MenuDrawMenu" },
	{ kStr_SysTrapBase+449, "MenuEraseStatus" },
	{ kStr_SysTrapBase+450, "MenuGetActiveMenu" },
	{ kStr_SysTrapBase+451, "MenuSetActiveMenu" },
	{ kStr_SysTrapBase+452, "RctSetRectangle" },
	{ kStr_SysTrapBase+453, "RctCopyRectangle" },
	{ kStr_SysTrapBase+454, "RctInsetRectangle" },
	{ kStr_SysTrapBase+455, "RctOffsetRectangle" },
	{ kStr_SysTrapBase+456, "RctPtInRectangle" },
	{ kStr_SysTrapBase+457, "RctGetIntersection" },
	{ kStr_SysTrapBase+458, "TblDrawTable" },
	{ kStr_SysTrapBase+459, "TblEraseTable" },
	{ kStr_SysTrapBase+460, "TblHandleEvent" },
	{ kStr_SysTrapBase+461, "TblGetItemBounds" },
	{ kStr_SysTrapBase+462, "TblSelectItem" },
	{ kStr_SysTrapBase+463, "TblGetItemInt" },
	{ kStr_SysTrapBase+464, "TblSetItemInt" },
	{ kStr_SysTrapBase+465, "TblSetItemStyle" },
	{ kStr_SysTrapBase+466, "TblUnhighlightSelection" },
	{ kStr_SysTrapBase+467, "TblSetRowUsable" },
	{ kStr_SysTrapBase+468, "TblGetNumberOfRows" },
	{ kStr_SysTrapBase+469, "TblSetCustomDrawProcedure" },
	{ kStr_SysTrapBase+470, "TblSetRowSelectable" },
	{ kStr_SysTrapBase+471, "TblRowSelectable" },
	{ kStr_SysTrapBase+472, "TblSetLoadDataProcedure" },
	{ kStr_SysTrapBase+473, "TblSetSaveDataProcedure" },
	{ kStr_SysTrapBase+474, "TblGetBounds" },
	{ kStr_SysTrapBase+475, "TblSetRowHeight" },
	{ kStr_SysTrapBase+476, "TblGetColumnWidth" },
	{ kStr_SysTrapBase+477, "TblGetRowID" },
	{ kStr_SysTrapBase+478, "TblSetRowID" },
	{ kStr_SysTrapBase+479, "TblMarkRowInvalid" },
	{ kStr_SysTrapBase+480, "TblMarkTableInvalid" },
	{ kStr_SysTrapBase+481, "TblGetSelection" },
	{ kStr_SysTrapBase+482, "TblInsertRow" },
	{ kStr_SysTrapBase+483, "TblRemoveRow" },
	{ kStr_SysTrapBase+484, "TblRowInvalid" },
	{ kStr_SysTrapBase+485, "TblRedrawTable" },
	{ kStr_SysTrapBase+486, "TblRowUsable" },
	{ kStr_SysTrapBase+487, "TblReleaseFocus" },
	{ kStr_SysTrapBase+488, "TblEditing" },
	{ kStr_SysTrapBase+489, "TblGetCurrentField" },
	{ kStr_SysTrapBase+490, "TblSetColumnUsable" },
	{ kStr_SysTrapBase+491, "TblGetRowHeight" },
	{ kStr_SysTrapBase+492, "TblSetColumnWidth" },
	{ kStr_SysTrapBase+493, "TblGrabFocus" },
	{ kStr_SysTrapBase+494, "TblSetItemPtr" },
	{ kStr_SysTrapBase+495, "TblFindRowID" },
	{ kStr_SysTrapBase+496, "TblGetLastUsableRow" },
	{ kStr_SysTrapBase+497, "TblGetColumnSpacing" },
	{ kStr_SysTrapBase+498, "TblFindRowData" },
	{ kStr_SysTrapBase+499, "TblGetRowData" },
	{ kStr_SysTrapBase+500, "TblSetRowData" },
	{ kStr_SysTrapBase+501, "TblSetColumnSpacing" },
	{ kStr_SysTrapBase+502, "WinCreateWindow" },
	{ kStr_SysTrapBase+503, "WinCreateOffscreenWindow" },
	{ kStr_SysTrapBase+504, "WinDeleteWindow" },
	{ kStr_SysTrapBase+505, "WinInitializeWindow" },
	{ kStr_SysTrapBase+506, "WinAddWindow" },
	{ kStr_SysTrapBase+507, "WinRemoveWindow" },
	{ kStr_SysTrapBase+508, "WinSetActiveWindow" },
	{ kStr_SysTrapBase+509, "WinSetDrawWindow" },
	{ kStr_SysTrapBase+510, "WinGetDrawWindow" },
	{ kStr_SysTrapBase+511, "WinGetActiveWindow" },
	{ kStr_SysTrapBase+512, "WinGetDisplayWindow" },
	{ kStr_SysTrapBase+513, "WinGetFirstWindow" },
	{ kStr_SysTrapBase+514, "WinEnableWindow" },
	{ kStr_SysTrapBase+515, "WinDisableWindow" },
	{ kStr_SysTrapBase+516, "WinGetWindowFrameRect" },
	{ kStr_SysTrapBase+517, "WinDrawWindowFrame" },
	{ kStr_SysTrapBase+518, "WinEraseWindow" },
	{ kStr_SysTrapBase+519, "WinSaveBits" },
	{ kStr_SysTrapBase+520, "WinRestoreBits" },
	{ kStr_SysTrapBase+521, "WinCopyRectangle" },
	{ kStr_SysTrapBase+522, "WinScrollRectangle" },
	{ kStr_SysTrapBase+523, "WinGetDisplayExtent" },
	{ kStr_SysTrapBase+524, "WinGetWindowExtent" },
	{ kStr_SysTrapBase+525, "WinDisplayToWindowPt" },
	{ kStr_SysTrapBase+526, "WinWindowToDisplayPt" },
	{ kStr_SysTrapBase+527, "WinGetClip" },
	{ kStr_SysTrapBase+528, "WinSetClip" },
	{ kStr_SysTrapBase+529, "WinResetClip" },
	{ kStr_SysTrapBase+530, "WinClipRectangle" },
	{ kStr_SysTrapBase+531, "WinDrawLine" },
	{ kStr_SysTrapBase+532, "WinDrawGrayLine" },
	{ kStr_SysTrapBase+533, "WinEraseLine" },
	{ kStr_SysTrapBase+534, "WinInvertLine" },
	{ kStr_SysTrapBase+535, "WinFillLine" },
	{ kStr_SysTrapBase+536, "WinDrawRectangle" },
	{ kStr_SysTrapBase+537, "WinEraseRectangle" },
	{ kStr_SysTrapBase+538, "WinInvertRectangle" },
	{ kStr_SysTrapBase+539, "WinDrawRectangleFrame" },
	{ kStr_SysTrapBase+540, "WinDrawGrayRectangleFrame" },
	{ kStr_SysTrapBase+541, "WinEraseRectangleFrame" },
	{ kStr_SysTrapBase+542, "WinInvertRectangleFrame" },
	{ kStr_SysTrapBase+543, "WinGetFramesRectangle" },
	{ kStr_SysTrapBase+544, "WinDrawChars" },
	{ kStr_SysTrapBase+545, "WinEraseChars" },
	{ kStr_SysTrapBase+546, "WinInvertChars" },
	{ kStr_SysTrapBase+547, "WinGetPattern" },
	{ kStr_SysTrapBase+548, "WinSetPattern" },
	{ kStr_SysTrapBase+549, "WinSetUnderlineMode" },
	{ kStr_SysTrapBase+550, "WinDrawBitmap" },
	{ kStr_SysTrapBase+551, "WinModal" },
	{ kStr_SysTrapBase+552, "WinGetDrawWindowBounds" },
	{ kStr_SysTrapBase+553, "WinFillRectangle" },
	{ kStr_SysTrapBase+554, "WinDrawInvertedChars" },
	{ kStr_SysTrapBase+555, "PrefOpenPreferenceDBV10" },
	{ kStr_SysTrapBase+556, "PrefGetPreferences" },
	{ kStr_SysTrapBase+557, "PrefSetPreferences" },
	{ kStr_SysTrapBase+558, "PrefGetAppPreferencesV10" },
	{ kStr_SysTrapBase+559, "PrefSetAppPreferencesV10" },
	{ kStr_SysTrapBase+560, "SndInit" },
	{ kStr_SysTrapBase+561, "SndSetDefaultVolume" },
	{ kStr_SysTrapBase+562, "SndGetDefaultVolume" },
	{ kStr_SysTrapBase+563, "SndDoCmd" },
	{ kStr_SysTrapBase+564, "SndPlaySystemSound" },
	{ kStr_SysTrapBase+565, "AlmInit" },
	{ kStr_SysTrapBase+566, "AlmCancelAll" },
	{ kStr_SysTrapBase+567, "AlmAlarmCallback" },
	{ kStr_SysTrapBase+568, "AlmSetAlarm" },
	{ kStr_SysTrapBase+569, "AlmGetAlarm" },
	{ kStr_SysTrapBase+570, "AlmDisplayAlarm" },
	{ kStr_SysTrapBase+571, "AlmEnableNotification" },
	{ kStr_SysTrapBase+572, "HwrGetRAMMapping" },
	{ kStr_SysTrapBase+573, "HwrMemWritable" },
	{ kStr_SysTrapBase+574, "HwrMemReadable" },
	{ kStr_SysTrapBase+575, "HwrDoze" },
	{ kStr_SysTrapBase+576, "HwrSleep" },
	{ kStr_SysTrapBase+577, "HwrWake" },
	{ kStr_SysTrapBase+578, "HwrSetSystemClock" },
	{ kStr_SysTrapBase+579, "HwrSetCPUDutyCycle" },
	{ kStr_SysTrapBase+580, "HwrDisplayInit" },
	{ kStr_SysTrapBase+581, "HwrDisplaySleep" },
	{ kStr_SysTrapBase+582, "HwrTimerInit" },
	{ kStr_SysTrapBase+583, "HwrCursorV33" },
	{ kStr_SysTrapBase+584, "HwrBatteryLevel" },
	{ kStr_SysTrapBase+585, "HwrDelay" },
	{ kStr_SysTrapBase+586, "HwrEnableDataWrites" },
	{ kStr_SysTrapBase+587, "HwrDisableDataWrites" },
	{ kStr_SysTrapBase+588, "HwrLCDBaseAddrV33" },
	{ kStr_SysTrapBase+589, "HwrDisplayDrawBootScreen" },
	{ kStr_SysTrapBase+590, "HwrTimerSleep" },
	{ kStr_SysTrapBase+591, "HwrTimerWake" },
	{ kStr_SysTrapBase+592, "HwrDisplayWake" },
	{ kStr_SysTrapBase+593, "HwrIRQ1Handler" },
	{ kStr_SysTrapBase+594, "HwrIRQ2Handler" },
	{ kStr_SysTrapBase+595, "HwrIRQ3Handler" },
	{ kStr_SysTrapBase+596, "HwrIRQ4Handler" },
	{ kStr_SysTrapBase+597, "HwrIRQ5Handler" },
	{ kStr_SysTrapBase+598, "HwrIRQ6Handler" },
	{ kStr_SysTrapBase+599, "HwrDockSignals" },
	{ kStr_SysTrapBase+600, "HwrPluggedIn" },
	{ kStr_SysTrapBase+601, "Crc16CalcBlock" },
	{ kStr_SysTrapBase+602, "SelectDayV10" },
	{ kStr_SysTrapBase+603, "SelectTimeV33" },
	{ kStr_SysTrapBase+604, "DayDrawDaySelector" },
	{ kStr_SysTrapBase+605, "DayHandleEvent" },
	{ kStr_SysTrapBase+606, "DayDrawDays" },
	{ kStr_SysTrapBase+607, "DayOfWeek" },
	{ kStr_SysTrapBase+608, "DaysInMonth" },
	{ kStr_SysTrapBase+609, "DayOfMonth" },
	{ kStr_SysTrapBase+610, "DateDaysToDate" },
	{ kStr_SysTrapBase+611, "DateToDays" },
	{ kStr_SysTrapBase+612, "DateAdjust" },
	{ kStr_SysTrapBase+613, "DateSecondsToDate" },
	{ kStr_SysTrapBase+614, "DateToAscii" },
	{ kStr_SysTrapBase+615, "DateToDOWDMFormat" },
	{ kStr_SysTrapBase+616, "TimeToAscii" },
	{ kStr_SysTrapBase+617, "Find" },
	{ kStr_SysTrapBase+618, "FindStrInStr" },
	{ kStr_SysTrapBase+619, "FindSaveMatch" },
	{ kStr_SysTrapBase+620, "FindGetLineBounds" },
	{ kStr_SysTrapBase+621, "FindDrawHeader" },
	{ kStr_SysTrapBase+622, "PenOpen" },
	{ kStr_SysTrapBase+623, "PenClose" },
	{ kStr_SysTrapBase+624, "PenGetRawPen" },
	{ kStr_SysTrapBase+625, "PenCalibrate" },
	{ kStr_SysTrapBase+626, "PenRawToScreen" },
	{ kStr_SysTrapBase+627, "PenScreenToRaw" },
	{ kStr_SysTrapBase+628, "PenResetCalibration" },
	{ kStr_SysTrapBase+629, "PenSleep" },
	{ kStr_SysTrapBase+630, "PenWake" },
	{ kStr_SysTrapBase+631, "ResLoadForm" },
	{ kStr_SysTrapBase+632, "ResLoadMenu" },
	{ kStr_SysTrapBase+633, "FtrInit" },
	{ kStr_SysTrapBase+634, "FtrUnregister" },
	{ kStr_SysTrapBase+635, "FtrGet" },
	{ kStr_SysTrapBase+636, "FtrSet" },
	{ kStr_SysTrapBase+637, "FtrGetByIndex" },
	{ kStr_SysTrapBase+638, "GrfInit" },
	{ kStr_SysTrapBase+639, "GrfFree" },
	{ kStr_SysTrapBase+640, "GrfGetState" },
	{ kStr_SysTrapBase+641, "GrfSetState" },
	{ kStr_SysTrapBase+642, "GrfFlushPoints" },
	{ kStr_SysTrapBase+643, "GrfAddPoint" },
	{ kStr_SysTrapBase+644, "GrfInitState" },
	{ kStr_SysTrapBase+645, "GrfCleanState" },
	{ kStr_SysTrapBase+646, "GrfMatch" },
	{ kStr_SysTrapBase+647, "GrfGetMacro" },
	{ kStr_SysTrapBase+648, "GrfFilterPoints" },
	{ kStr_SysTrapBase+649, "GrfGetNumPoints" },
	{ kStr_SysTrapBase+650, "GrfGetPoint" },
	{ kStr_SysTrapBase+651, "GrfFindBranch" },
	{ kStr_SysTrapBase+652, "GrfMatchGlyph" },
	{ kStr_SysTrapBase+653, "GrfGetGlyphMapping" },
	{ kStr_SysTrapBase+654, "GrfGetMacroName" },
	{ kStr_SysTrapBase+655, "GrfDeleteMacro" },
	{ kStr_SysTrapBase+656, "GrfAddMacro" },
	{ kStr_SysTrapBase+657, "GrfGetAndExpandMacro" },
	{ kStr_SysTrapBase+658, "GrfProcessStroke" },
	{ kStr_SysTrapBase+659, "GrfFieldChange" },
	{ kStr_SysTrapBase+660, "GetCharSortValue" },
	{ kStr_SysTrapBase+661, "GetCharAttr" },
	{ kStr_SysTrapBase+662, "GetCharCaselessValue" },
	{ kStr_SysTrapBase+663, "PwdExists" },
	{ kStr_SysTrapBase+664, "PwdVerify" },
	{ kStr_SysTrapBase+665, "PwdSet" },
	{ kStr_SysTrapBase+666, "PwdRemove" },
	{ kStr_SysTrapBase+667, "GsiInitialize" },
	{ kStr_SysTrapBase+668, "GsiSetLocation" },
	{ kStr_SysTrapBase+669, "GsiEnable" },
	{ kStr_SysTrapBase+670, "GsiEnabled" },
	{ kStr_SysTrapBase+671, "GsiSetShiftState" },
	{ kStr_SysTrapBase+672, "KeyInit" },
	{ kStr_SysTrapBase+673, "KeyHandleInterrupt" },
	{ kStr_SysTrapBase+674, "KeyCurrentState" },
	{ kStr_SysTrapBase+675, "KeyResetDoubleTap" },
	{ kStr_SysTrapBase+676, "KeyRates" },
	{ kStr_SysTrapBase+677, "KeySleep" },
	{ kStr_SysTrapBase+678, "KeyWake" },
	{ kStr_SysTrapBase+679, "DlkControl" },
	{ kStr_SysTrapBase+680, "DlkStartServer" },
	{ kStr_SysTrapBase+681, "DlkGetSyncInfo" },
	{ kStr_SysTrapBase+682, "DlkSetLogEntry" },
	{ kStr_SysTrapBase+683, "IntlDispatch" },
	{ kStr_SysTrapBase+684, "SysLibLoad" },
	{ kStr_SysTrapBase+685, "SndPlaySmf" },
	{ kStr_SysTrapBase+686, "SndCreateMidiList" },
	{ kStr_SysTrapBase+687, "AbtShowAbout" },
	{ kStr_SysTrapBase+688, "MdmDial" },
	{ kStr_SysTrapBase+689, "MdmHangUp" },
	{ kStr_SysTrapBase+690, "DmSearchRecord" },
	{ kStr_SysTrapBase+691, "SysInsertionSort" },
	{ kStr_SysTrapBase+692, "DmInsertionSort" },
	{ kStr_SysTrapBase+693, "LstSetTopItem" },
	{ kStr_SysTrapBase+694, "SclSetScrollBar" },
	{ kStr_SysTrapBase+695, "SclDrawScrollBar" },
	{ kStr_SysTrapBase+696, "SclHandleEvent" },
	{ kStr_SysTrapBase+697, "SysMailboxCreate" },
	{ kStr_SysTrapBase+698, "SysMailboxDelete" },
	{ kStr_SysTrapBase+699, "SysMailboxFlush" },
	{ kStr_SysTrapBase+700, "SysMailboxSend" },
	{ kStr_SysTrapBase+701, "SysMailboxWait" },
	{ kStr_SysTrapBase+702, "SysTaskWait" },
	{ kStr_SysTrapBase+703, "SysTaskWake" },
	{ kStr_SysTrapBase+704, "SysTaskWaitClr" },
	{ kStr_SysTrapBase+705, "SysTaskSuspend" },
	{ kStr_SysTrapBase+706, "SysTaskResume" },
	{ kStr_SysTrapBase+707, "CategoryCreateList" },
	{ kStr_SysTrapBase+708, "CategoryFreeList" },
	{ kStr_SysTrapBase+709, "CategoryEditV20" },
	{ kStr_SysTrapBase+710, "CategorySelect" },
	{ kStr_SysTrapBase+711, "DmDeleteCategory" },
	{ kStr_SysTrapBase+712, "SysEvGroupCreate" },
	{ kStr_SysTrapBase+713, "SysEvGroupSignal" },
	{ kStr_SysTrapBase+714, "SysEvGroupRead" },
	{ kStr_SysTrapBase+715, "SysEvGroupWait" },
	{ kStr_SysTrapBase+716, "EvtEventAvail" },
	{ kStr_SysTrapBase+717, "EvtSysEventAvail" },
	{ kStr_SysTrapBase+718, "StrNCopy" },
	{ kStr_SysTrapBase+719, "KeySetMask" },
	{ kStr_SysTrapBase+720, "SelectDay" },
	{ kStr_SysTrapBase+721, "PrefGetPreference" },
	{ kStr_SysTrapBase+722, "PrefSetPreference" },
	{ kStr_SysTrapBase+723, "PrefGetAppPreferences" },
	{ kStr_SysTrapBase+724, "PrefSetAppPreferences" },
	{ kStr_SysTrapBase+725, "FrmPointInTitle" },
	{ kStr_SysTrapBase+726, "StrNCat" },
	{ kStr_SysTrapBase+727, "MemCmp" },
	{ kStr_SysTrapBase+728, "TblSetColumnEditIndicator" },
	{ kStr_SysTrapBase+729, "FntWordWrap" },
	{ kStr_SysTrapBase+730, "FldGetScrollValues" },
	{ kStr_SysTrapBase+731, "SysCreateDataBaseList" },
	{ kStr_SysTrapBase+732, "SysCreatePanelList" },
	{ kStr_SysTrapBase+733, "DlkDispatchRequest" },
	{ kStr_SysTrapBase+734, "StrPrintF" },
	{ kStr_SysTrapBase+735, "StrVPrintF" },
	{ kStr_SysTrapBase+736, "PrefOpenPreferenceDB" },
	{ kStr_SysTrapBase+737, "SysGraffitiReferenceDialog" },
	{ kStr_SysTrapBase+738, "SysKeyboardDialog" },
	{ kStr_SysTrapBase+739, "FntWordWrapReverseNLines" },
	{ kStr_SysTrapBase+740, "FntGetScrollValues" },
	{ kStr_SysTrapBase+741, "TblSetRowStaticHeight" },
	{ kStr_SysTrapBase+742, "TblHasScrollBar" },
	{ kStr_SysTrapBase+743, "SclGetScrollBar" },
	{ kStr_SysTrapBase+744, "FldGetNumberOfBlankLines" },
	{ kStr_SysTrapBase+745, "SysTicksPerSecond" },
	{ kStr_SysTrapBase+746, "HwrBacklightV33" },
	{ kStr_SysTrapBase+747, "DmDatabaseProtect" },
	{ kStr_SysTrapBase+748, "TblSetBounds" },
	{ kStr_SysTrapBase+749, "StrNCompare" },
	{ kStr_SysTrapBase+750, "StrNCaselessCompare" },
	{ kStr_SysTrapBase+751, "PhoneNumberLookup" },
	{ kStr_SysTrapBase+752, "FrmSetMenu" },
	{ kStr_SysTrapBase+753, "EncDigestMD5" },
	{ kStr_SysTrapBase+754, "DmFindSortPosition" },
	{ kStr_SysTrapBase+755, "SysBinarySearch" },
	{ kStr_SysTrapBase+756, "SysErrString" },
	{ kStr_SysTrapBase+757, "SysStringByIndex" },
	{ kStr_SysTrapBase+758, "EvtAddUniqueEventToQueue" },
	{ kStr_SysTrapBase+759, "StrLocalizeNumber" },
	{ kStr_SysTrapBase+760, "StrDelocalizeNumber" },
	{ kStr_SysTrapBase+761, "LocGetNumberSeparators" },
	{ kStr_SysTrapBase+762, "MenuSetActiveMenuRscID" },
	{ kStr_SysTrapBase+763, "LstScrollList" },
	{ kStr_SysTrapBase+764, "CategoryInitialize" },
	{ kStr_SysTrapBase+765, "EncDigestMD4" },
	{ kStr_SysTrapBase+766, "EncDES" },
	{ kStr_SysTrapBase+767, "LstGetVisibleItems" },
	{ kStr_SysTrapBase+768, "WinSetBounds" },
	{ kStr_SysTrapBase+769, "CategorySetName" },
	{ kStr_SysTrapBase+770, "FldSetInsertionPoint" },
	{ kStr_SysTrapBase+771, "FrmSetObjectBounds" },
	{ kStr_SysTrapBase+772, "WinSetColors" },
	{ kStr_SysTrapBase+773, "FlpDispatch" },
	{ kStr_SysTrapBase+774, "FlpEmDispatch" },
	{ kStr_SysTrapBase+775, "ExgInit" },
	{ kStr_SysTrapBase+776, "ExgConnect" },
	{ kStr_SysTrapBase+777, "ExgPut" },
	{ kStr_SysTrapBase+778, "ExgGet" },
	{ kStr_SysTrapBase+779, "ExgAccept" },
	{ kStr_SysTrapBase+780, "ExgDisconnect" },
	{ kStr_SysTrapBase+781, "ExgSend" },
	{ kStr_SysTrapBase+782, "ExgReceive" },
	{ kStr_SysTrapBase+783, "ExgRegisterData" },
	{ kStr_SysTrapBase+784, "ExgNotifyReceiveV35" },
	{ kStr_SysTrapBase+785, "SysReserved30Trap2" },
	{ kStr_SysTrapBase+786, "PrgStartDialogV31" },
	{ kStr_SysTrapBase+787, "PrgStopDialog" },
	{ kStr_SysTrapBase+788, "PrgUpdateDialog" },
	{ kStr_SysTrapBase+789, "PrgHandleEvent" },
	{ kStr_SysTrapBase+790, "ImcReadFieldNoSemicolon" },
	{ kStr_SysTrapBase+791, "ImcReadFieldQuotablePrintable" },
	{ kStr_SysTrapBase+792, "ImcReadPropertyParameter" },
	{ kStr_SysTrapBase+793, "ImcSkipAllPropertyParameters" },
	{ kStr_SysTrapBase+794, "ImcReadWhiteSpace" },
	{ kStr_SysTrapBase+795, "ImcWriteQuotedPrintable" },
	{ kStr_SysTrapBase+796, "ImcWriteNoSemicolon" },
	{ kStr_SysTrapBase+797, "ImcStringIsAscii" },
	{ kStr_SysTrapBase+798, "TblGetItemFont" },
	{ kStr_SysTrapBase+799, "TblSetItemFont" },
	{ kStr_SysTrapBase+800, "FontSelect" },
	{ kStr_SysTrapBase+801, "FntDefineFont" },
	{ kStr_SysTrapBase+802, "CategoryEdit" },
	{ kStr_SysTrapBase+803, "SysGetOSVersionString" },
	{ kStr_SysTrapBase+804, "SysBatteryInfo" },
	{ kStr_SysTrapBase+805, "SysUIBusy" },
	{ kStr_SysTrapBase+806, "WinValidateHandle" },
	{ kStr_SysTrapBase+807, "FrmValidatePtr" },
	{ kStr_SysTrapBase+808, "CtlValidatePointer" },
	{ kStr_SysTrapBase+809, "WinMoveWindowAddr" },
	{ kStr_SysTrapBase+810, "FrmAddSpaceForObject" },
	{ kStr_SysTrapBase+811, "FrmNewForm" },
	{ kStr_SysTrapBase+812, "CtlNewControl" },
	{ kStr_SysTrapBase+813, "FldNewField" },
	{ kStr_SysTrapBase+814, "LstNewList" },
	{ kStr_SysTrapBase+815, "FrmNewLabel" },
	{ kStr_SysTrapBase+816, "FrmNewBitmap" },
	{ kStr_SysTrapBase+817, "FrmNewGadget" },
	{ kStr_SysTrapBase+818, "FileOpen" },
	{ kStr_SysTrapBase+819, "FileClose" },
	{ kStr_SysTrapBase+820, "FileDelete" },
	{ kStr_SysTrapBase+821, "FileReadLow" },
	{ kStr_SysTrapBase+822, "FileWrite" },
	{ kStr_SysTrapBase+823, "FileSeek" },
	{ kStr_SysTrapBase+824, "FileTell" },
	{ kStr_SysTrapBase+825, "FileTruncate" },
	{ kStr_SysTrapBase+826, "FileControl" },
	{ kStr_SysTrapBase+827, "FrmActiveState" },
	{ kStr_SysTrapBase+828, "SysGetAppInfo" },
	{ kStr_SysTrapBase+829, "SysGetStackInfo" },
	{ kStr_SysTrapBase+830, "WinScreenMode" },
	{ kStr_SysTrapBase+831, "HwrLCDGetDepthV33" },
	{ kStr_SysTrapBase+832, "HwrGetROMToken" },
	{ kStr_SysTrapBase+833, "DbgControl" },
	{ kStr_SysTrapBase+834, "ExgDBRead" },
	{ kStr_SysTrapBase+835, "ExgDBWrite" },
	{ kStr_SysTrapBase+836, "HostControl" },
	{ kStr_SysTrapBase+837, "FrmRemoveObject" },
	{ kStr_SysTrapBase+838, "SysReserved30Trap1" },
	{ kStr_SysTrapBase+839, "ExpansionDispatch" },
	{ kStr_SysTrapBase+840, "FileSystemDispatch" },
	{ kStr_SysTrapBase+841, "OEMDispatch" },
	{ kStr_SysTrapBase+842, "HwrLCDContrastV33" },
	{ kStr_SysTrapBase+843, "SysLCDContrast" },
	{ kStr_SysTrapBase+844, "UIContrastAdjust" },
	{ kStr_SysTrapBase+845, "HwrDockStatus" },
	{ kStr_SysTrapBase+846, "FntWidthToOffset" },
	{ kStr_SysTrapBase+847, "SelectOneTime" },
	{ kStr_SysTrapBase+848, "WinDrawChar" },
	{ kStr_SysTrapBase+849, "WinDrawTruncChars" },
	{ kStr_SysTrapBase+850, "SysNotifyInit" },
	{ kStr_SysTrapBase+851, "SysNotifyRegister" },
	{ kStr_SysTrapBase+852, "SysNotifyUnregister" },
	{ kStr_SysTrapBase+853, "SysNotifyBroadcast" },
	{ kStr_SysTrapBase+854, "SysNotifyBroadcastDeferred" },
	{ kStr_SysTrapBase+855, "SysNotifyDatabaseAdded" },
	{ kStr_SysTrapBase+856, "SysNotifyDatabaseRemoved" },
	{ kStr_SysTrapBase+857, "SysWantEvent" },
	{ kStr_SysTrapBase+858, "FtrPtrNew" },
	{ kStr_SysTrapBase+859, "FtrPtrFree" },
	{ kStr_SysTrapBase+860, "FtrPtrResize" },
	{ kStr_SysTrapBase+861, "SysReserved31Trap1" },
	{ kStr_SysTrapBase+862, "HwrNVPrefSet" },
	{ kStr_SysTrapBase+863, "HwrNVPrefGet" },
	{ kStr_SysTrapBase+864, "FlashInit" },
	{ kStr_SysTrapBase+865, "FlashCompress" },
	{ kStr_SysTrapBase+866, "FlashErase" },
	{ kStr_SysTrapBase+867, "FlashProgram" },
	{ kStr_SysTrapBase+868, "AlmTimeChange" },
	{ kStr_SysTrapBase+869, "ErrAlertCustom" },
	{ kStr_SysTrapBase+870, "PrgStartDialog" },
	{ kStr_SysTrapBase+871, "SerialDispatch" },
	{ kStr_SysTrapBase+872, "HwrBattery" },
	{ kStr_SysTrapBase+873, "DmGetDatabaseLockState" },
	{ kStr_SysTrapBase+874, "CncGetProfileList" },
	{ kStr_SysTrapBase+875, "CncGetProfileInfo" },
	{ kStr_SysTrapBase+876, "CncAddProfile" },
	{ kStr_SysTrapBase+877, "CncDeleteProfile" },
	{ kStr_SysTrapBase+878, "SndPlaySmfResource" },
	{ kStr_SysTrapBase+879, "MemPtrDataStorage" },
	{ kStr_SysTrapBase+880, "ClipboardAppendItem" },
	{ kStr_SysTrapBase+881, "WiCmdV32" },
	{ kStr_SysTrapBase+882, "HwrDisplayAttributes" },
	{ kStr_SysTrapBase+883, "HwrDisplayDoze" },
	{ kStr_SysTrapBase+884, "HwrDisplayPalette" },
	{ kStr_SysTrapBase+885, "BltFindIndexes" },
	{ kStr_SysTrapBase+886, "BmpGetBits" },
	{ kStr_SysTrapBase+887, "BltCopyRectangle" },
	{ kStr_SysTrapBase+888, "BltDrawChars" },
	{ kStr_SysTrapBase+889, "BltLineRoutine" },
	{ kStr_SysTrapBase+890, "BltRectangleRoutine" },
	{ kStr_SysTrapBase+891, "ScrCompress" },
	{ kStr_SysTrapBase+892, "ScrDecompress" },
	{ kStr_SysTrapBase+893, "SysLCDBrightness" },
	{ kStr_SysTrapBase+894, "WinPaintChar" },
	{ kStr_SysTrapBase+895, "WinPaintChars" },
	{ kStr_SysTrapBase+896, "WinPaintBitmap" },
	{ kStr_SysTrapBase+897, "WinGetPixel" },
	{ kStr_SysTrapBase+898, "WinPaintPixel" },
	{ kStr_SysTrapBase+899, "WinDrawPixel" },
	{ kStr_SysTrapBase+900, "WinErasePixel" },
	{ kStr_SysTrapBase+901, "WinInvertPixel" },
	{ kStr_SysTrapBase+902, "WinPaintPixels" },
	{ kStr_SysTrapBase+903, "WinPaintLines" },
	{ kStr_SysTrapBase+904, "WinPaintLine" },
	{ kStr_SysTrapBase+905, "WinPaintRectangle" },
	{ kStr_SysTrapBase+906, "WinPaintRectangleFrame" },
	{ kStr_SysTrapBase+907, "WinPaintPolygon" },
	{ kStr_SysTrapBase+908, "WinDrawPolygon" },
	{ kStr_SysTrapBase+909, "WinErasePolygon" },
	{ kStr_SysTrapBase+910, "WinInvertPolygon" },
	{ kStr_SysTrapBase+911, "WinFillPolygon" },
	{ kStr_SysTrapBase+912, "WinPaintArc" },
	{ kStr_SysTrapBase+913, "WinDrawArc" },
	{ kStr_SysTrapBase+914, "WinEraseArc" },
	{ kStr_SysTrapBase+915, "WinInvertArc" },
	{ kStr_SysTrapBase+916, "WinFillArc" },
	{ kStr_SysTrapBase+917, "WinPushDrawState" },
	{ kStr_SysTrapBase+918, "WinPopDrawState" },
	{ kStr_SysTrapBase+919, "WinSetDrawMode" },
	{ kStr_SysTrapBase+920, "WinSetForeColor" },
	{ kStr_SysTrapBase+921, "WinSetBackColor" },
	{ kStr_SysTrapBase+922, "WinSetTextColor" },
	{ kStr_SysTrapBase+923, "WinGetPatternType" },
	{ kStr_SysTrapBase+924, "WinSetPatternType" },
	{ kStr_SysTrapBase+925, "WinPalette" },
	{ kStr_SysTrapBase+926, "WinRGBToIndex" },
	{ kStr_SysTrapBase+927, "WinIndexToRGB" },
	{ kStr_SysTrapBase+928, "WinScreenLock" },
	{ kStr_SysTrapBase+929, "WinScreenUnlock" },
	{ kStr_SysTrapBase+930, "WinGetBitmap" },
	{ kStr_SysTrapBase+931, "UIColorInit" },
	{ kStr_SysTrapBase+932, "UIColorGetTableEntryIndex" },
	{ kStr_SysTrapBase+933, "UIColorGetTableEntryRGB" },
	{ kStr_SysTrapBase+934, "UIColorSetTableEntry" },
	{ kStr_SysTrapBase+935, "UIColorPushTable" },
	{ kStr_SysTrapBase+936, "UIColorPopTable" },
	{ kStr_SysTrapBase+937, "CtlNewGraphicControl" },
	{ kStr_SysTrapBase+938, "TblGetItemPtr" },
	{ kStr_SysTrapBase+939, "UIBrightnessAdjust" },
	{ kStr_SysTrapBase+940, "UIPickColor" },
	{ kStr_SysTrapBase+941, "EvtSetAutoOffTimer" },
	{ kStr_SysTrapBase+942, "TsmDispatch" },
	{ kStr_SysTrapBase+943, "OmDispatch" },
	{ kStr_SysTrapBase+944, "DmOpenDBNoOverlay" },
	{ kStr_SysTrapBase+945, "DmOpenDBWithLocale" },
	{ kStr_SysTrapBase+946, "ResLoadConstant" },
	{ kStr_SysTrapBase+947, "HwrPreDebugInit" },
	{ kStr_SysTrapBase+948, "HwrResetNMI" },
	{ kStr_SysTrapBase+949, "HwrResetPWM" },
	{ kStr_SysTrapBase+950, "KeyBootKeys" },
	{ kStr_SysTrapBase+951, "DbgSerDrvOpen" },
	{ kStr_SysTrapBase+952, "DbgSerDrvClose" },
	{ kStr_SysTrapBase+953, "DbgSerDrvControl" },
	{ kStr_SysTrapBase+954, "DbgSerDrvStatus" },
	{ kStr_SysTrapBase+955, "DbgSerDrvWriteChar" },
	{ kStr_SysTrapBase+956, "DbgSerDrvReadChar" },
	{ kStr_SysTrapBase+957, "HwrPostDebugInit" },
	{ kStr_SysTrapBase+958, "HwrIdentifyFeatures" },
	{ kStr_SysTrapBase+959, "HwrModelSpecificInit" },
	{ kStr_SysTrapBase+960, "HwrModelInitStage2" },
	{ kStr_SysTrapBase+961, "HwrInterruptsInit" },
	{ kStr_SysTrapBase+962, "HwrSoundOn" },
	{ kStr_SysTrapBase+963, "HwrSoundOff" },
	{ kStr_SysTrapBase+964, "SysKernelClockTick" },
	{ kStr_SysTrapBase+965, "MenuEraseMenu" },
	{ kStr_SysTrapBase+966, "SelectTime" },
	{ kStr_SysTrapBase+967, "MenuCmdBarAddButton" },
	{ kStr_SysTrapBase+968, "MenuCmdBarGetButtonData" },
	{ kStr_SysTrapBase+969, "MenuCmdBarDisplay" },
	{ kStr_SysTrapBase+970, "HwrGetSilkscreenID" },
	{ kStr_SysTrapBase+971, "EvtGetSilkscreenAreaList" },
	{ kStr_SysTrapBase+972, "SysFatalAlertInit" },
	{ kStr_SysTrapBase+973, "DateTemplateToAscii" },
	{ kStr_SysTrapBase+974, "SecVerifyPW" },
	{ kStr_SysTrapBase+975, "SecSelectViewStatus" },
	{ kStr_SysTrapBase+976, "TblSetColumnMasked" },
	{ kStr_SysTrapBase+977, "TblSetRowMasked" },
	{ kStr_SysTrapBase+978, "TblRowMasked" },
	{ kStr_SysTrapBase+979, "FrmCustomResponseAlert" },
	{ kStr_SysTrapBase+980, "FrmNewGsi" },
	{ kStr_SysTrapBase+981, "MenuShowItem" },
	{ kStr_SysTrapBase+982, "MenuHideItem" },
	{ kStr_SysTrapBase+983, "MenuAddItem" },
	{ kStr_SysTrapBase+984, "FrmSetGadgetHandler" },
	{ kStr_SysTrapBase+985, "CtlSetGraphics" },
	{ kStr_SysTrapBase+986, "CtlGetSliderValues" },
	{ kStr_SysTrapBase+987, "CtlSetSliderValues" },
	{ kStr_SysTrapBase+988, "CtlNewSliderControl" },
	{ kStr_SysTrapBase+989, "BmpCreate" },
	{ kStr_SysTrapBase+990, "BmpDelete" },
	{ kStr_SysTrapBase+991, "BmpCompress" },
	{ kStr_SysTrapBase+992, "BmpGetColortable" },
	{ kStr_SysTrapBase+993, "BmpSize" },
	{ kStr_SysTrapBase+994, "BmpBitsSize" },
	{ kStr_SysTrapBase+995, "BmpColortableSize" },
	{ kStr_SysTrapBase+996, "WinCreateBitmapWindow" },
	{ kStr_SysTrapBase+997, "EvtSetNullEventTick" },
	{ kStr_SysTrapBase+998, "ExgDoDialog" },
	{ kStr_SysTrapBase+999, "SysUICleanup" },
	{ kStr_SysTrapBase+1000, "WinSetForeColorRGB" },
	{ kStr_SysTrapBase+1001, "WinSetBackColorRGB" },
	{ kStr_SysTrapBase+1002, "WinSetTextColorRGB" },
	{ kStr_SysTrapBase+1003, "WinGetPixelRGB" },
	{ kStr_SysTrapBase+1004, "SysReserved40Trap1" },
	{ kStr_SysTrapBase+1005, "SysReserved40Trap2" },
	{ kStr_SysTrapBase+1006, "SysReserved40Trap3" },
	{ kStr_SysTrapBase+1007, "SysReserved40Trap4" },
	{ kStr_SysTrapBase+1008, "CncMgrDispatch" },
	{ kStr_SysTrapBase+1009, "SysNotifyBroadcastFromInterrupt" },
	{ kStr_SysTrapBase+1010, "EvtWakeupWithoutNilEvent" },
	{ kStr_SysTrapBase+1011, "StrCompareAscii" },
	{ kStr_SysTrapBase+1012, "AccessorDispatch" },
	{ kStr_SysTrapBase+1013, "BltGetPixel" },
	{ kStr_SysTrapBase+1014, "BltPaintPixel" },
	{ kStr_SysTrapBase+1015, "ScrScreenInit" },
	{ kStr_SysTrapBase+1016, "ScrUpdateScreenBitmap" },
	{ kStr_SysTrapBase+1017, "ScrPalette" },
	{ kStr_SysTrapBase+1018, "ScrGetColortable" },
	{ kStr_SysTrapBase+1019, "ScrGetGrayPat" },
	{ kStr_SysTrapBase+1020, "ScrScreenLock" },
	{ kStr_SysTrapBase+1021, "ScrScreenUnlock" },
	{ kStr_SysTrapBase+1022, "FntPrvGetFontList" },
	{ kStr_SysTrapBase+1023, "ExgRegisterDatatype" },
	{ kStr_SysTrapBase+1024, "ExgNotifyReceive" },
	{ kStr_SysTrapBase+1025, "ExgNotifyGoto" },
	{ kStr_SysTrapBase+1026, "ExgRequest" },
	{ kStr_SysTrapBase+1027, "ExgSetDefaultApplication" },
	{ kStr_SysTrapBase+1028, "ExgGetDefaultApplication" },
	{ kStr_SysTrapBase+1029, "ExgGetTargetApplication" },
	{ kStr_SysTrapBase+1030, "ExgGetRegisteredApplications" },
	{ kStr_SysTrapBase+1031, "ExgGetRegisteredTypes" },
	{ kStr_SysTrapBase+1032, "ExgNotifyPreview" },
	{ kStr_SysTrapBase+1033, "ExgControl" },
	{ kStr_SysTrapBase+1034, "LmDispatch" },
	{ kStr_SysTrapBase+1035, "MemGetRomNVParams" },
	{ kStr_SysTrapBase+1036, "FntWCharWidth" },
	{ kStr_SysTrapBase+1037, "DmFindDatabaseWithTypeCreator" },
	{ kStr_SysTrapBase+1038, "SelectTimeZone" },
	{ kStr_SysTrapBase+1039, "TimeZoneToAscii" },
	{ kStr_SysTrapBase+1040, "StrNCompareAscii" },
	{ kStr_SysTrapBase+1041, "TimTimeZoneToUTC" },
	{ kStr_SysTrapBase+1042, "TimUTCToTimeZone" },
	{ kStr_SysTrapBase+1043, "PhoneNumberLookupCustom" },
	{ kStr_SysTrapBase+1044, "HwrDebugSelect" },
	{ kStr_SysTrapBase+1045, "BltRoundedRectangle" },
	{ kStr_SysTrapBase+1046, "BltRoundedRectangleFill" },
	{ kStr_SysTrapBase+1047, "WinPrvInitCanvas" },
	{ kStr_SysTrapBase+1048, "HwrCalcDynamicHeapSize" },
	{ kStr_SysTrapBase+1049, "HwrDebuggerEnter" },
	{ kStr_SysTrapBase+1050, "HwrDebuggerExit" },
	{ kStr_SysTrapBase+1051, "LstGetTopItem" },
	{ kStr_SysTrapBase+1052, "HwrModelInitStage3" },
	{ kStr_SysTrapBase+1053, "AttnIndicatorAllow" },
	{ kStr_SysTrapBase+1054, "AttnIndicatorAllowed" },
	{ kStr_SysTrapBase+1055, "AttnIndicatorEnable" },
	{ kStr_SysTrapBase+1056, "AttnIndicatorEnabled" },
	{ kStr_SysTrapBase+1057, "AttnIndicatorSetBlinkPattern" },
	{ kStr_SysTrapBase+1058, "AttnIndicatorGetBlinkPattern" },
	{ kStr_SysTrapBase+1059, "AttnIndicatorTicksTillNextBlink" },
	{ kStr_SysTrapBase+1060, "AttnIndicatorCheckBlink" },
	{ kStr_SysTrapBase+1061, "AttnInitialize" },
	{ kStr_SysTrapBase+1062, "AttnGetAttention" },
	{ kStr_SysTrapBase+1063, "AttnUpdate" },
	{ kStr_SysTrapBase+1064, "AttnForgetIt" },
	{ kStr_SysTrapBase+1065, "AttnGetCounts" },
	{ kStr_SysTrapBase+1066, "AttnListOpen" },
	{ kStr_SysTrapBase+1067, "AttnHandleEvent" },
	{ kStr_SysTrapBase+1068, "AttnEffectOfEvent" },
	{ kStr_SysTrapBase+1069, "AttnIterate" },
	{ kStr_SysTrapBase+1070, "AttnDoSpecialEffects" },
	{ kStr_SysTrapBase+1071, "AttnDoEmergencySpecialEffects" },
	{ kStr_SysTrapBase+1072, "AttnAllowClose" },
	{ kStr_SysTrapBase+1073, "AttnReopen" },
	{ kStr_SysTrapBase+1074, "AttnEnableNotification" },
	{ kStr_SysTrapBase+1075, "HwrLEDAttributes" },
	{ kStr_SysTrapBase+1076, "HwrVibrateAttributes" },
	{ kStr_SysTrapBase+1077, "SecGetPwdHint" },
	{ kStr_SysTrapBase+1078, "SecSetPwdHint" },
	{ kStr_SysTrapBase+1079, "HwrFlashWrite" },
	{ kStr_SysTrapBase+1080, "KeyboardStatusNew" },
	{ kStr_SysTrapBase+1081, "KeyboardStatusFree" },
	{ kStr_SysTrapBase+1082, "KbdSetLayout" },
	{ kStr_SysTrapBase+1083, "KbdGetLayout" },
	{ kStr_SysTrapBase+1084, "KbdSetPosition" },
	{ kStr_SysTrapBase+1085, "KbdGetPosition" },
	{ kStr_SysTrapBase+1086, "KbdSetShiftState" },
	{ kStr_SysTrapBase+1087, "KbdGetShiftState" },
	{ kStr_SysTrapBase+1088, "KbdDraw" },
	{ kStr_SysTrapBase+1089, "KbdErase" },
	{ kStr_SysTrapBase+1090, "KbdHandleEvent" },
	{ kStr_SysTrapBase+1091, "OEMDispatch2" },
	{ kStr_SysTrapBase+1092, "HwrCustom" },
	{ kStr_SysTrapBase+1093, "FrmGetActiveField" },
	{ kStr_SysTrapBase+1094, "SndPlaySmfIrregardless" },
	{ kStr_SysTrapBase+1095, "SndPlaySmfResourceIrregardless" },
	{ kStr_SysTrapBase+1096, "SndInterruptSmfIrregardless" },
	{ kStr_SysTrapBase+1097, "UdaMgrDispatch" },
	{ kStr_SysTrapBase+1098, "PalmPrivate1" },
	{ kStr_SysTrapBase+1099, "PalmPrivate2" },
	{ kStr_SysTrapBase+1100, "PalmPrivate3" },
	{ kStr_SysTrapBase+1101, "PalmPrivate4" },
	{ kStr_SysTrapBase+1102, "BmpGetDimensions" },
	{ kStr_SysTrapBase+1103, "BmpGetBitDepth" },
	{ kStr_SysTrapBase+1104, "BmpGetNextBitmap" },
	{ kStr_SysTrapBase+1105, "TblGetNumberOfColumns" },
	{ kStr_SysTrapBase+1106, "TblGetTopRow" },
	{ kStr_SysTrapBase+1107, "TblSetSelection" },
	{ kStr_SysTrapBase+1108, "FrmGetObjectIndexFromPtr" },
	{ kStr_SysTrapBase+1109, "BmpGetSizes" },
	{ kStr_SysTrapBase+1110, "WinGetBounds" },
	{ kStr_SysTrapBase+1111, "BltPaintPixels" },
	{ kStr_SysTrapBase+1112, "FldSetMaxVisibleLines" },

// --------------------------------------------------------------------------------
//	Template Parts -- Library function names
// --------------------------------------------------------------------------------

// --------------------
// Common Library functions
// --------------------

	{ kStr_LibTrapBase+0, "SysLibName" },
	{ kStr_LibTrapBase+1, "SysLibOpen" },
	{ kStr_LibTrapBase+2, "SysLibClose" },
	{ kStr_LibTrapBase+3, "SysLibSleep" },
	{ kStr_LibTrapBase+4, "SysLibWake" },

// --------------------
// HTAL Library
// --------------------

	{ kStr_HTALLibTrapBase+1, "HtalLibOpen" },
	{ kStr_HTALLibTrapBase+2, "HtalLibClose" },
	{ kStr_HTALLibTrapBase+3, "HtalLibSleep" },
	{ kStr_HTALLibTrapBase+4, "HtalLibWake" },
	{ kStr_HTALLibTrapBase+5, "HtalLibSetOption" },
	{ kStr_HTALLibTrapBase+6, "HtalLibGetOption" },
	{ kStr_HTALLibTrapBase+7, "HtalLibControl" },
	{ kStr_HTALLibTrapBase+8, "HtalLibConnectPhase1" },
	{ kStr_HTALLibTrapBase+9, "HtalLibDisconnect" },
	{ kStr_HTALLibTrapBase+10, "HtalLibGetCommand" },
	{ kStr_HTALLibTrapBase+11, "HtalLibSendReply" },
	{ kStr_HTALLibTrapBase+12, "HtalLibCancel" },
	{ kStr_HTALLibTrapBase+13, "HtalLibMaxBlockSize" },
	{ kStr_HTALLibTrapBase+14, "HtalLibVersion" },
	{ kStr_HTALLibTrapBase+15, "HtalLibAddSegmentSizes" },
	{ kStr_HTALLibTrapBase+16, "HtalLibConnectPhase2" },

// --------------------
// INet Library
// --------------------

	{ kStr_INetLibTrapBase+1, "INetLibOpen" },
	{ kStr_INetLibTrapBase+2, "INetLibClose" },
	{ kStr_INetLibTrapBase+3, "INetLibSleep" },
	{ kStr_INetLibTrapBase+4, "INetLibWake" },
	{ kStr_INetLibTrapBase+5, "INetLibSettingGet" },
	{ kStr_INetLibTrapBase+6, "INetLibSettingSet" },
	{ kStr_INetLibTrapBase+7, "INetLibGetEvent" },
	{ kStr_INetLibTrapBase+8, "INetLibURLOpen" },
	{ kStr_INetLibTrapBase+9, "INetLibSockRead" },
	{ kStr_INetLibTrapBase+10, "INetLibSockWrite" },
	{ kStr_INetLibTrapBase+11, "INetLibSockOpen" },
	{ kStr_INetLibTrapBase+12, "INetLibSockClose" },
	{ kStr_INetLibTrapBase+13, "INetLibSockStatus" },
	{ kStr_INetLibTrapBase+14, "INetLibSockSettingGet" },
	{ kStr_INetLibTrapBase+15, "INetLibSockSettingSet" },
	{ kStr_INetLibTrapBase+16, "INetLibSockConnect" },
	{ kStr_INetLibTrapBase+17, "INetLibURLCrack" },
	{ kStr_INetLibTrapBase+18, "INetLibURLsAdd" },
	{ kStr_INetLibTrapBase+19, "INetLibURLsCompare" },
	{ kStr_INetLibTrapBase+20, "INetLibURLGetInfo" },
	{ kStr_INetLibTrapBase+21, "INetLibSockHTTPReqCreate" },
	{ kStr_INetLibTrapBase+22, "INetLibSockHTTPAttrSet" },
	{ kStr_INetLibTrapBase+23, "INetLibSockHTTPReqSend" },
	{ kStr_INetLibTrapBase+24, "INetLibSockHTTPAttrGet" },
	{ kStr_INetLibTrapBase+25, "INetLibSockMailReqCreate" },
	{ kStr_INetLibTrapBase+26, "INetLibSockMailAttrSet" },
	{ kStr_INetLibTrapBase+27, "INetLibSockMailReqAdd" },
	{ kStr_INetLibTrapBase+28, "INetLibSockMailReqSend" },
	{ kStr_INetLibTrapBase+29, "INetLibSockMailAttrGet" },
	{ kStr_INetLibTrapBase+30, "inetLibTrapSockMailQueryProgress" },
	{ kStr_INetLibTrapBase+31, "INetLibCacheList" },
	{ kStr_INetLibTrapBase+32, "INetLibCacheGetObject" },
	{ kStr_INetLibTrapBase+33, "INetLibConfigMakeActive" },
	{ kStr_INetLibTrapBase+34, "INetLibConfigList" },
	{ kStr_INetLibTrapBase+35, "INetLibConfigIndexFromName" },
	{ kStr_INetLibTrapBase+36, "INetLibConfigDelete" },
	{ kStr_INetLibTrapBase+37, "INetLibConfigSaveAs" },
	{ kStr_INetLibTrapBase+38, "INetLibConfigRename" },
	{ kStr_INetLibTrapBase+39, "INetLibConfigAliasSet" },
	{ kStr_INetLibTrapBase+40, "INetLibConfigAliasGet" },

// --------------------
// IR Library
// --------------------

	{ kStr_IrLibTrapBase+1, "ExgLibOpen" },
	{ kStr_IrLibTrapBase+2, "ExgLibCLose" },
	{ kStr_IrLibTrapBase+3, "ExgLibSleep" },
	{ kStr_IrLibTrapBase+4, "ExgLibWake" },
	{ kStr_IrLibTrapBase+5, "ExgLibHandleEvent" },
	{ kStr_IrLibTrapBase+6, "ExgLibConnect" },
	{ kStr_IrLibTrapBase+7, "ExgLibAccept" },
	{ kStr_IrLibTrapBase+8, "ExgLibDisconnect" },
	{ kStr_IrLibTrapBase+9, "ExgLibPut" },
	{ kStr_IrLibTrapBase+10, "ExgLibGet" },
	{ kStr_IrLibTrapBase+11, "ExgLibSend" },
	{ kStr_IrLibTrapBase+12, "ExgLibReceive" },
	{ kStr_IrLibTrapBase+13, "ExgLibControl" },
	{ kStr_IrLibTrapBase+14, "ExgLibReserved1" },
	{ kStr_IrLibTrapBase+15, "IrBind" },
	{ kStr_IrLibTrapBase+16, "IrUnBind" },
	{ kStr_IrLibTrapBase+17, "IrDiscoverReq" },
	{ kStr_IrLibTrapBase+18, "IrConnectIrLap" },
	{ kStr_IrLibTrapBase+19, "IrDisconnectIrLap" },
	{ kStr_IrLibTrapBase+20, "IrConnectReq" },
	{ kStr_IrLibTrapBase+21, "IrConnectRsp" },
	{ kStr_IrLibTrapBase+22, "IrDataReq" },
	{ kStr_IrLibTrapBase+23, "IrLocalBusy" },
	{ kStr_IrLibTrapBase+24, "IrMaxTxSize" },
	{ kStr_IrLibTrapBase+25, "IrMaxRxSize" },
	{ kStr_IrLibTrapBase+26, "IrSetDeviceInfo" },
	{ kStr_IrLibTrapBase+27, "IrIsNoProgress" },
	{ kStr_IrLibTrapBase+28, "IrIsRemoteBusy" },
	{ kStr_IrLibTrapBase+29, "IrIsMediaBusy" },
	{ kStr_IrLibTrapBase+30, "IrIsIrLapConnected" },
	{ kStr_IrLibTrapBase+31, "IrTestReq" },
	{ kStr_IrLibTrapBase+32, "IrIAS_Add" },
	{ kStr_IrLibTrapBase+33, "IrIAS_Query" },
	{ kStr_IrLibTrapBase+34, "IrIAS_SetDeviceName" },
	{ kStr_IrLibTrapBase+35, "IrIAS_Next" },
	{ kStr_IrLibTrapBase+36, "IrIrOpen" },
	{ kStr_IrLibTrapBase+37, "IrHandleEvent" },
	{ kStr_IrLibTrapBase+38, "IrWaitForEvent" },

// --------------------
// Net Library
// --------------------

	{ kStr_NetLibTrapBase+1, "NetLibOpen" },
	{ kStr_NetLibTrapBase+2, "NetLibCLose" },
	{ kStr_NetLibTrapBase+3, "NetLibSleep" },
	{ kStr_NetLibTrapBase+4, "NetLibWake" },
	{ kStr_NetLibTrapBase+5, "NetLibAddrINToA" },
	{ kStr_NetLibTrapBase+6, "NetLibAddrAToIN" },
	{ kStr_NetLibTrapBase+7, "NetLibSocketOpen" },
	{ kStr_NetLibTrapBase+8, "NetLibSocketClose" },
	{ kStr_NetLibTrapBase+9, "NetLibSocketOptionSet" },
	{ kStr_NetLibTrapBase+10, "NetLibSocketOptionGet" },
	{ kStr_NetLibTrapBase+11, "NetLibSocketBind" },
	{ kStr_NetLibTrapBase+12, "NetLibSocketConnect" },
	{ kStr_NetLibTrapBase+13, "NetLibSocketListen" },
	{ kStr_NetLibTrapBase+14, "NetLibSocketAccept" },
	{ kStr_NetLibTrapBase+15, "NetLibSocketShutdown" },
	{ kStr_NetLibTrapBase+16, "NetLibSendPB" },
	{ kStr_NetLibTrapBase+17, "NetLibSend" },
	{ kStr_NetLibTrapBase+18, "NetLibReceivePB" },
	{ kStr_NetLibTrapBase+19, "NetLibReceive" },
	{ kStr_NetLibTrapBase+20, "NetLibDmReceive" },
	{ kStr_NetLibTrapBase+21, "NetLibSelect" },
	{ kStr_NetLibTrapBase+22, "*NetLibPrefsGet*" },
	{ kStr_NetLibTrapBase+23, "*NetLibPrefsSet*" },
	{ kStr_NetLibTrapBase+24, "*NetLibDrvrWake*" },
	{ kStr_NetLibTrapBase+25, "*NetLibInterfacePtr*" },
	{ kStr_NetLibTrapBase+26, "NetLibMaster" },
	{ kStr_NetLibTrapBase+27, "NetLibGetHostByName" },
	{ kStr_NetLibTrapBase+28, "NetLibSettingGet" },
	{ kStr_NetLibTrapBase+29, "NetLibSettingSet" },
	{ kStr_NetLibTrapBase+30, "NetLibIFAttach" },
	{ kStr_NetLibTrapBase+31, "NetLibIFDetach" },
	{ kStr_NetLibTrapBase+32, "NetLibIFGet" },
	{ kStr_NetLibTrapBase+33, "NetLibIFSettingGet" },
	{ kStr_NetLibTrapBase+34, "NetLibIFSettingSet" },
	{ kStr_NetLibTrapBase+35, "NetLibIFUp" },
	{ kStr_NetLibTrapBase+36, "NetLibIFDown" },
	{ kStr_NetLibTrapBase+37, "NetLibIFMediaUp" },
	{ kStr_NetLibTrapBase+38, "*NetLibScriptExecute*" },
	{ kStr_NetLibTrapBase+39, "NetLibGetHostByAddr" },
	{ kStr_NetLibTrapBase+40, "NetLibGetServByName" },
	{ kStr_NetLibTrapBase+41, "NetLibGetHostByAddr" },
	{ kStr_NetLibTrapBase+42, "NetLibFinishCloseWait" },
	{ kStr_NetLibTrapBase+43, "NetLibGetMailExchangeByName" },
	{ kStr_NetLibTrapBase+44, "*NetLibPrefsAppend*" },
	{ kStr_NetLibTrapBase+45, "*NetLibIFMediaDown*" },
	{ kStr_NetLibTrapBase+46, "NetLibOpenCount" },
	{ kStr_NetLibTrapBase+47, "NetLibTracePrintF" },
	{ kStr_NetLibTrapBase+48, "NetLibTracePutS" },
	{ kStr_NetLibTrapBase+49, "NetLibOpenIfCloseWait" },
	{ kStr_NetLibTrapBase+50, "NetLibHandlePowerOff" },
	{ kStr_NetLibTrapBase+51, "NetLibConnectionRefresh" },
	{ kStr_NetLibTrapBase+52, "NetLibBitMove" },
	{ kStr_NetLibTrapBase+53, "NetLibBitPutFixed" },
	{ kStr_NetLibTrapBase+54, "NetLibBitGetFixed" },
	{ kStr_NetLibTrapBase+55, "NetLibBitPutUIntV" },
	{ kStr_NetLibTrapBase+56, "NetLibBitGetUIntV" },
	{ kStr_NetLibTrapBase+57, "NetLibBitPutIntV" },
	{ kStr_NetLibTrapBase+58, "NetLibBitGetIntV" },
	{ kStr_NetLibTrapBase+59, "NetLibOpenConfig" },
	{ kStr_NetLibTrapBase+60, "NetLibConfigMakeActive" },
	{ kStr_NetLibTrapBase+61, "NetLibConfigList" },
	{ kStr_NetLibTrapBase+62, "NetLibConfigIndexFromName" },
	{ kStr_NetLibTrapBase+63, "NetLibConfigDelete" },
	{ kStr_NetLibTrapBase+64, "NetLibConfigSaveAs" },
	{ kStr_NetLibTrapBase+65, "NetLibConfigRename" },
	{ kStr_NetLibTrapBase+66, "NetLibConfigAliasSet" },
	{ kStr_NetLibTrapBase+67, "NetLibConfigAliasGet" },

// --------------------
// NetPlugIn Library
// --------------------

	{ kStr_NPILibTrapBase+1, "NPILibOpen" },
	{ kStr_NPILibTrapBase+2, "NPILibClose" },
	{ kStr_NPILibTrapBase+3, "NPILibSleep" },
	{ kStr_NPILibTrapBase+4, "NPILibWake" },
	{ kStr_NPILibTrapBase+5, "NPILibInfo" },
	{ kStr_NPILibTrapBase+6, "NPILibSocketOpen" },
	{ kStr_NPILibTrapBase+7, "NPILibSocketClose" },
	{ kStr_NPILibTrapBase+8, "NPILibSocketOptionSet" },
	{ kStr_NPILibTrapBase+9, "NPILibSocketOptionGet" },
	{ kStr_NPILibTrapBase+10, "NPILibSocketBind" },
	{ kStr_NPILibTrapBase+11, "NPILibSocketConnect" },
	{ kStr_NPILibTrapBase+12, "NPILibSocketListen" },
	{ kStr_NPILibTrapBase+13, "NPILibSocketAccept" },
	{ kStr_NPILibTrapBase+14, "NPILibSocketShutdown" },
	{ kStr_NPILibTrapBase+15, "NPILibSocketAddr" },
	{ kStr_NPILibTrapBase+16, "NPILibSocketNativeRefnum" },
	{ kStr_NPILibTrapBase+17, "NPILibSocketReady" },
	{ kStr_NPILibTrapBase+18, "NPILibSocketReceivePB" },
	{ kStr_NPILibTrapBase+19, "NPILibSocketSendPB" },

// --------------------
// Rail Library
// --------------------

	{ kStr_RailLibTrapBase+1, "RailLibOpen" },
	{ kStr_RailLibTrapBase+2, "RailLibClose" },
	{ kStr_RailLibTrapBase+3, "RailLibSleep" },
	{ kStr_RailLibTrapBase+4, "RailLibWake" },

// --------------------
// Security Library
// --------------------

	{ kStr_SecLibTrapBase+1, "SecLibOpen" },
	{ kStr_SecLibTrapBase+2, "SecLibClose" },
	{ kStr_SecLibTrapBase+3, "SecLibSleep" },
	{ kStr_SecLibTrapBase+4, "SecLibWake" },
	{ kStr_SecLibTrapBase+5, "SecLibGetContextSize" },
	{ kStr_SecLibTrapBase+6, "SecLibResetSeqNum" },
	{ kStr_SecLibTrapBase+7, "SecLibGetSignedPublicKey" },
	{ kStr_SecLibTrapBase+8, "SecLibProcessSignedKey" },
	{ kStr_SecLibTrapBase+9, "SecLibEncryptBegin" },
	{ kStr_SecLibTrapBase+10, "SecLibEncrypt" },
	{ kStr_SecLibTrapBase+11, "SecLibEncryptEnd" },
	{ kStr_SecLibTrapBase+12, "SecLibDecryptBegin" },
	{ kStr_SecLibTrapBase+13, "SecLibDecrypt" },
	{ kStr_SecLibTrapBase+14, "SecLibDecryptEnd" },
	{ kStr_SecLibTrapBase+15, "SecLibDebug" },
	{ kStr_SecLibTrapBase+16, "SecRamEncrypt" },
	{ kStr_SecLibTrapBase+17, "SecRamDecrypt" },
	{ kStr_SecLibTrapBase+18, "SecLibSetKeyPath" },

// --------------------
// Serial Library
// --------------------

	{ kStr_SerLibTrapBase+1, "SerLibOpen" },
	{ kStr_SerLibTrapBase+2, "SerLibClose" },
	{ kStr_SerLibTrapBase+3, "SerLibSleep" },
	{ kStr_SerLibTrapBase+4, "SerLibWake" },
	{ kStr_SerLibTrapBase+5, "SerGetSettings" },
	{ kStr_SerLibTrapBase+6, "SerSetSettings" },
	{ kStr_SerLibTrapBase+7, "SerGetStatus" },
	{ kStr_SerLibTrapBase+8, "SerClearErr" },
	{ kStr_SerLibTrapBase+9, "SerSend10" },
	{ kStr_SerLibTrapBase+10, "SerSendWait" },
	{ kStr_SerLibTrapBase+11, "SerSendCheck" },
	{ kStr_SerLibTrapBase+12, "SerSendFlush" },
	{ kStr_SerLibTrapBase+13, "SerReceive10" },
	{ kStr_SerLibTrapBase+14, "SerReceiveWait" },
	{ kStr_SerLibTrapBase+15, "SerReceiveCheck" },
	{ kStr_SerLibTrapBase+16, "SerReceiveFlush" },
	{ kStr_SerLibTrapBase+17, "SerSetReceiveBuffer" },
	{ kStr_SerLibTrapBase+18, "SerReceiveWindowOpen" },
	{ kStr_SerLibTrapBase+19, "SerReceiveWindowClose" },
	{ kStr_SerLibTrapBase+20, "SerSetWakeupHandler" },
	{ kStr_SerLibTrapBase+21, "SerPrimeWakeupHandler" },
	{ kStr_SerLibTrapBase+22, "SerControl" },
	{ kStr_SerLibTrapBase+23, "SerSend" },
	{ kStr_SerLibTrapBase+24, "SerReceive" },

// --------------------
// Web Library
// --------------------

	{ kStr_WebLibTrapBase+1, "WebLibOpen" },
	{ kStr_WebLibTrapBase+2, "WebLibClose" },
	{ kStr_WebLibTrapBase+3, "WebLibSleep" },
	{ kStr_WebLibTrapBase+4, "WebLibWake" },
	{ kStr_WebLibTrapBase+5, "WebLibSettingGet" },
	{ kStr_WebLibTrapBase+6, "WebLibSettingSet" },
	{ kStr_WebLibTrapBase+7, "WebLibFormHandleEvent" },
	{ kStr_WebLibTrapBase+8, "WebLibHandleEvent" },
	{ kStr_WebLibTrapBase+9, "WebLibRender" },
	{ kStr_WebLibTrapBase+10, "WebLibRenderCache" },
	{ kStr_WebLibTrapBase+11, "WebLibRenderCancel" },
	{ kStr_WebLibTrapBase+12, "WebLibCopyToClipboard" },
	{ kStr_WebLibTrapBase+13, "WebLibGetScrollData" },
	{ kStr_WebLibTrapBase+14, "WebLibScroll" },
	{ kStr_WebLibTrapBase+15, "WebLibCMLToSimpleText" },
	{ kStr_WebLibTrapBase+16, "WebLibSimpleTextToCML" },
	{ kStr_WebLibTrapBase+17, "WebLibSelectAll" },
	{ kStr_WebLibTrapBase+18, "WebLibRedrawForm" },
	{ kStr_WebLibTrapBase+19, "WebLibRenderComplete" },
	{ kStr_WebLibTrapBase+20, "WebLibRenderData" },

// --------------------------------------------------------------------------------
//	Template Parts -- Error descriptions
// --------------------------------------------------------------------------------

// NOTE: the following is commented with C++ comments instead of C comments
// because the included MPW script contains a */ that prematurely closes
// the comment.
//
//	The following strings were generated as follows.  First, the following
//	lines were selected in the MPW Shell and executed:
//
//		Set root "Phantom:Palm:Projects:Palm:Viewer:dev:4.0:primary:Incs:"
//		for f in `files -f -s -r "{root}"`
//			continue if ("{f}" =~ /CMServer/)		# duplicate cmp error codes with CMClient.h
//			continue if ("{f}" =~ /DLClient/)		# duplicate dlk error codes with DLServer.h
//			continue if ("{f}" =~ /PadServer/)	# duplicate pad error codes with PadWS.h
//			continue if ("{f}" =~ /UDAMgr/)		# udaErrControl not formatted nicely
//			search -q -ns /#defineŶ(ErrorClassŶ|/ "{f}"
//		end
//
//	Next, the output was selected and pasted into a new MPW window. Then
//	the following lines were selected in the MPW Shell and executed:
//
//		# Put everthing into ID/ENGLISH format
//		find 
//		replace -c  /#define[ t]+([ t]+)1Ŷ(([a-z0-9]+)2[ t]*|[ t]*([x0-9a-f]+)3)()4/ "ID=kStr_PalmOSErrorBase+2+3nENGLISH=14n"
//
//		# Convert any trailing comments (C++ version)
//		find 
//		replace -c  /[ t]*//[ t]*/ " -- "
//
//		# Convert any trialing comments (C version)
//		find 
//		replace -c  /[ t]*/*[ t]()1[ t]*// " -- 1"
//
//		# Remove any trialing periods in comments
//		find 
//		replace -c  /./ ""

	{ kStr_PalmOSErrorBase+hwrErrorClass+1, "hwrErrHwrCustomNotImplemented" },
	{ kStr_PalmOSErrorBase+hwrErrorClass+2, "hwrErrCreatorNotSupported" },
	{ kStr_PalmOSErrorBase+hwrErrorClass+3, "hwrErrSelectorNotSupported" },
	{ kStr_PalmOSErrorBase+hwrErrorClass+4, "hwrErrParamTooSmall" },
	{ kStr_PalmOSErrorBase+almErrorClass+1, "almErrMemory -- ran out of memory" },
	{ kStr_PalmOSErrorBase+almErrorClass+2, "almErrFull -- alarm table is full" },
	{ kStr_PalmOSErrorBase+cncErrorClass+1, "cncErrAddProfileFailed -- Add profile attempt failed" },
	{ kStr_PalmOSErrorBase+cncErrorClass+2, "cncErrProfileListFull -- Add attempt failed because the" },
	{ kStr_PalmOSErrorBase+cncErrorClass+3, "cncErrGetProfileFailed -- Get profile attempt failed" },
	{ kStr_PalmOSErrorBase+cncErrorClass+4, "cncErrConDBNotFound -- Connection database not found" },
	{ kStr_PalmOSErrorBase+cncErrorClass+5, "cncErrGetProfileListFailed -- Could not get profile list" },
	{ kStr_PalmOSErrorBase+cncErrorClass+6, "cncErrProfileReadOnly -- The profile can not be altered" },
	{ kStr_PalmOSErrorBase+cncErrorClass+7, "cncErrProfileNotFound -- The profile could not be found" },
	{ kStr_PalmOSErrorBase+dmErrorClass+1, "dmErrMemError" },
	{ kStr_PalmOSErrorBase+dmErrorClass+2, "dmErrIndexOutOfRange" },
	{ kStr_PalmOSErrorBase+dmErrorClass+3, "dmErrInvalidParam" },
	{ kStr_PalmOSErrorBase+dmErrorClass+4, "dmErrReadOnly" },
	{ kStr_PalmOSErrorBase+dmErrorClass+5, "dmErrDatabaseOpen" },
	{ kStr_PalmOSErrorBase+dmErrorClass+6, "dmErrCantOpen" },
	{ kStr_PalmOSErrorBase+dmErrorClass+7, "dmErrCantFind" },
	{ kStr_PalmOSErrorBase+dmErrorClass+8, "dmErrRecordInWrongCard" },
	{ kStr_PalmOSErrorBase+dmErrorClass+9, "dmErrCorruptDatabase" },
	{ kStr_PalmOSErrorBase+dmErrorClass+10, "dmErrRecordDeleted" },
	{ kStr_PalmOSErrorBase+dmErrorClass+11, "dmErrRecordArchived" },
	{ kStr_PalmOSErrorBase+dmErrorClass+12, "dmErrNotRecordDB" },
	{ kStr_PalmOSErrorBase+dmErrorClass+13, "dmErrNotResourceDB" },
	{ kStr_PalmOSErrorBase+dmErrorClass+14, "dmErrROMBased" },
	{ kStr_PalmOSErrorBase+dmErrorClass+15, "dmErrRecordBusy" },
	{ kStr_PalmOSErrorBase+dmErrorClass+16, "dmErrResourceNotFound" },
	{ kStr_PalmOSErrorBase+dmErrorClass+17, "dmErrNoOpenDatabase" },
	{ kStr_PalmOSErrorBase+dmErrorClass+18, "dmErrInvalidCategory" },
	{ kStr_PalmOSErrorBase+dmErrorClass+19, "dmErrNotValidRecord" },
	{ kStr_PalmOSErrorBase+dmErrorClass+20, "dmErrWriteOutOfBounds" },
	{ kStr_PalmOSErrorBase+dmErrorClass+21, "dmErrSeekFailed" },
	{ kStr_PalmOSErrorBase+dmErrorClass+22, "dmErrAlreadyOpenForWrites" },
	{ kStr_PalmOSErrorBase+dmErrorClass+23, "dmErrOpenedByAnotherTask" },
	{ kStr_PalmOSErrorBase+dmErrorClass+24, "dmErrUniqueIDNotFound" },
	{ kStr_PalmOSErrorBase+dmErrorClass+25, "dmErrAlreadyExists" },
	{ kStr_PalmOSErrorBase+dmErrorClass+26, "dmErrInvalidDatabaseName" },
	{ kStr_PalmOSErrorBase+dmErrorClass+27, "dmErrDatabaseProtected" },
	{ kStr_PalmOSErrorBase+dmErrorClass+28, "dmErrDatabaseNotProtected" },
	{ kStr_PalmOSErrorBase+dlkErrorClass+1, "dlkErrParam -- invalid parameter" },
	{ kStr_PalmOSErrorBase+dlkErrorClass+2, "dlkErrMemory -- memory allocation error" },
	{ kStr_PalmOSErrorBase+dlkErrorClass+3, "dlkErrNoSession -- could not establish a session	" },
	{ kStr_PalmOSErrorBase+dlkErrorClass+4, "dlkErrSizeErr -- reply length was too big" },
	{ kStr_PalmOSErrorBase+dlkErrorClass+5, "dlkErrLostConnection -- lost connection" },
	{ kStr_PalmOSErrorBase+dlkErrorClass+6, "dlkErrInterrupted -- sync was interrupted (see sync state)" },
	{ kStr_PalmOSErrorBase+dlkErrorClass+7, "dlkErrUserCan -- cancelled by user" },
	{ kStr_PalmOSErrorBase+dlkErrorClass+8, "dlkErrIncompatibleProducts -- incompatible desktop version" },
	{ kStr_PalmOSErrorBase+dlkErrorClass+9, "dlkErrNPOD -- New Password, Old Desktop" },
	{ kStr_PalmOSErrorBase+exgErrorClass+1, "exgMemError" },
	{ kStr_PalmOSErrorBase+exgErrorClass+2, "exgErrStackInit -- stack could not initialize" },
	{ kStr_PalmOSErrorBase+exgErrorClass+3, "exgErrUserCancel" },
	{ kStr_PalmOSErrorBase+exgErrorClass+4, "exgErrNoReceiver -- receiver device not found" },
	{ kStr_PalmOSErrorBase+exgErrorClass+5, "exgErrNoKnownTarget -- can't find a target app" },
	{ kStr_PalmOSErrorBase+exgErrorClass+6, "exgErrTargetMissing -- target app is known but missing" },
	{ kStr_PalmOSErrorBase+exgErrorClass+7, "exgErrNotAllowed -- operation not allowed" },
	{ kStr_PalmOSErrorBase+exgErrorClass+8, "exgErrBadData -- internal data was not valid" },
	{ kStr_PalmOSErrorBase+exgErrorClass+9, "exgErrAppError -- generic application error" },
	{ kStr_PalmOSErrorBase+exgErrorClass+10, "exgErrUnknown -- unknown general error" },
	{ kStr_PalmOSErrorBase+exgErrorClass+11, "exgErrDeviceFull -- device is full" },
	{ kStr_PalmOSErrorBase+exgErrorClass+12, "exgErrDisconnected -- link disconnected" },
	{ kStr_PalmOSErrorBase+exgErrorClass+13, "exgErrNotFound -- requested object not found" },
	{ kStr_PalmOSErrorBase+exgErrorClass+14, "exgErrBadParam -- bad parameter to call" },
	{ kStr_PalmOSErrorBase+exgErrorClass+15, "exgErrNotSupported -- operation not supported by this library" },
	{ kStr_PalmOSErrorBase+exgErrorClass+16, "exgErrDeviceBusy -- device is busy" },
	{ kStr_PalmOSErrorBase+exgErrorClass+17, "exgErrBadLibrary -- bad or missing ExgLibrary" },
	{ kStr_PalmOSErrorBase+exgErrorClass+18, "exgErrNotEnoughPower -- Device has not enough power to perform the requested operation" },
	{ kStr_PalmOSErrorBase+ftrErrorClass+1, "ftrErrInvalidParam" },
	{ kStr_PalmOSErrorBase+ftrErrorClass+2, "ftrErrNoSuchFeature" },
	{ kStr_PalmOSErrorBase+ftrErrorClass+3, "ftrErrAlreadyExists" },
	{ kStr_PalmOSErrorBase+ftrErrorClass+4, "ftrErrROMBased" },
	{ kStr_PalmOSErrorBase+ftrErrorClass+5, "ftrErrInternalErr" },
	{ kStr_PalmOSErrorBase+fileErrorClass+1, "fileErrMemError -- out of memory error" },
	{ kStr_PalmOSErrorBase+fileErrorClass+2, "fileErrInvalidParam -- invalid parameter value passed" },
	{ kStr_PalmOSErrorBase+fileErrorClass+3, "fileErrCorruptFile -- the file is corrupted/invalid/not a stream file" },
	{ kStr_PalmOSErrorBase+fileErrorClass+4, "fileErrNotFound -- couldn't find the file" },
	{ kStr_PalmOSErrorBase+fileErrorClass+5, "fileErrTypeCreatorMismatch -- file's type and creator didn't match those expected" },
	{ kStr_PalmOSErrorBase+fileErrorClass+6, "fileErrReplaceError -- couldn't replace an existing file" },
	{ kStr_PalmOSErrorBase+fileErrorClass+7, "fileErrCreateError -- couldn't create a new file" },
	{ kStr_PalmOSErrorBase+fileErrorClass+8, "fileErrOpenError -- generic open error" },
	{ kStr_PalmOSErrorBase+fileErrorClass+9, "fileErrInUse -- file couldn't be opened or deleted because it is in use" },
	{ kStr_PalmOSErrorBase+fileErrorClass+10, "fileErrReadOnly -- couldn't open in write mode because db is read-only" },
	{ kStr_PalmOSErrorBase+fileErrorClass+11, "fileErrInvalidDescriptor -- invalid file descriptor (FileHandle)" },
	{ kStr_PalmOSErrorBase+fileErrorClass+12, "fileErrCloseError -- error closing the database" },
	{ kStr_PalmOSErrorBase+fileErrorClass+13, "fileErrOutOfBounds -- attempted operation went out of bounds of the file" },
	{ kStr_PalmOSErrorBase+fileErrorClass+14, "fileErrPermissionDenied -- couldn't write to a file open for read-only access" },
	{ kStr_PalmOSErrorBase+fileErrorClass+15, "fileErrIOError -- general I/O error" },
	{ kStr_PalmOSErrorBase+fileErrorClass+16, "fileErrEOF -- end-of-file error" },
	{ kStr_PalmOSErrorBase+fileErrorClass+17, "fileErrNotStream -- attempted to open a file that is not a stream" },
	{ kStr_PalmOSErrorBase+flpErrorClass+1, "flpErrOutOfRange" },
	{ kStr_PalmOSErrorBase+grfErrorClass+1, "grfErrBadParam" },
	{ kStr_PalmOSErrorBase+grfErrorClass+2, "grfErrPointBufferFull" },
	{ kStr_PalmOSErrorBase+grfErrorClass+3, "grfErrNoGlyphTable" },
	{ kStr_PalmOSErrorBase+grfErrorClass+4, "grfErrNoDictionary" },
	{ kStr_PalmOSErrorBase+grfErrorClass+5, "grfErrNoMapping" },
	{ kStr_PalmOSErrorBase+grfErrorClass+6, "grfErrMacroNotFound" },
	{ kStr_PalmOSErrorBase+grfErrorClass+7, "grfErrDepthTooDeep" },
	{ kStr_PalmOSErrorBase+grfErrorClass+8, "grfErrMacroPtrTooSmall" },
	{ kStr_PalmOSErrorBase+grfErrorClass+9, "grfErrNoMacros" },
	{ kStr_PalmOSErrorBase+grfErrorClass+129, "grfErrMacroIncomplete -- (grfWarningOffset+1)" },
	{ kStr_PalmOSErrorBase+grfErrorClass+130, "grfErrBranchNotFound -- (grfWarningOffset+2)" },
	{ kStr_PalmOSErrorBase+grfErrorClass+16, "grfErrGenericHWRErrBase" },
	{ kStr_PalmOSErrorBase+intlErrorClass+1, "intlErrInvalidSelector" },
	{ kStr_PalmOSErrorBase+lmErrorClass+1, "lmErrUnknownLocale" },
	{ kStr_PalmOSErrorBase+lmErrorClass+2, "lmErrBadLocaleIndex" },
	{ kStr_PalmOSErrorBase+lmErrorClass+3, "lmErrBadLocaleSettingChoice" },
	{ kStr_PalmOSErrorBase+lmErrorClass+4, "lmErrSettingDataOverflow" },
	{ kStr_PalmOSErrorBase+memErrorClass+1, "memErrChunkLocked" },
	{ kStr_PalmOSErrorBase+memErrorClass+2, "memErrNotEnoughSpace" },
	{ kStr_PalmOSErrorBase+memErrorClass+3, "memErrInvalidParam -- invalid param or requested size is too big" },
	{ kStr_PalmOSErrorBase+memErrorClass+4, "memErrChunkNotLocked" },
	{ kStr_PalmOSErrorBase+memErrorClass+5, "memErrCardNotPresent" },
	{ kStr_PalmOSErrorBase+memErrorClass+6, "memErrNoCardHeader" },
	{ kStr_PalmOSErrorBase+memErrorClass+7, "memErrInvalidStoreHeader" },
	{ kStr_PalmOSErrorBase+memErrorClass+8, "memErrRAMOnlyCard" },
	{ kStr_PalmOSErrorBase+memErrorClass+9, "memErrWriteProtect" },
	{ kStr_PalmOSErrorBase+memErrorClass+10, "memErrNoRAMOnCard" },
	{ kStr_PalmOSErrorBase+memErrorClass+11, "memErrNoStore" },
	{ kStr_PalmOSErrorBase+memErrorClass+12, "memErrROMOnlyCard" },
	{ kStr_PalmOSErrorBase+mdmErrorClass+1, "mdmErrNoTone -- no dial tone" },
	{ kStr_PalmOSErrorBase+mdmErrorClass+2, "mdmErrNoDCD -- no carrier / timeout" },
	{ kStr_PalmOSErrorBase+mdmErrorClass+3, "mdmErrBusy -- busy signal heard" },
	{ kStr_PalmOSErrorBase+mdmErrorClass+4, "mdmErrUserCan -- cancelled by user" },
	{ kStr_PalmOSErrorBase+mdmErrorClass+5, "mdmErrCmdError -- command error" },
	{ kStr_PalmOSErrorBase+mdmErrorClass+6, "mdmErrNoModem -- no modem detected" },
	{ kStr_PalmOSErrorBase+mdmErrorClass+7, "mdmErrMemory -- not enough memory" },
	{ kStr_PalmOSErrorBase+mdmErrorClass+8, "mdmErrPrefs -- modem preferences have not been" },
	{ kStr_PalmOSErrorBase+mdmErrorClass+9, "mdmErrDial -- dial command error - most likely the dial" },
	{ kStr_PalmOSErrorBase+mdmErrorClass+10, "mdmErrNoPhoneNum -- No phone number and not \"Direct Connect\"" },
	{ kStr_PalmOSErrorBase+netErrorClass+1, "netErrAlreadyOpen" },
	{ kStr_PalmOSErrorBase+netErrorClass+2, "netErrNotOpen" },
	{ kStr_PalmOSErrorBase+netErrorClass+3, "netErrStillOpen" },
	{ kStr_PalmOSErrorBase+netErrorClass+4, "netErrParamErr" },
	{ kStr_PalmOSErrorBase+netErrorClass+5, "netErrNoMoreSockets" },
	{ kStr_PalmOSErrorBase+netErrorClass+6, "netErrOutOfResources" },
	{ kStr_PalmOSErrorBase+netErrorClass+7, "netErrOutOfMemory -- Might be because free heap space is <32K probably because handheld's RAM <2MB" },
	{ kStr_PalmOSErrorBase+netErrorClass+8, "netErrSocketNotOpen" },
	{ kStr_PalmOSErrorBase+netErrorClass+9, "netErrSocketBusy -- EINPROGRESS" },
	{ kStr_PalmOSErrorBase+netErrorClass+10, "netErrMessageTooBig" },
	{ kStr_PalmOSErrorBase+netErrorClass+11, "netErrSocketNotConnected" },
	{ kStr_PalmOSErrorBase+netErrorClass+12, "netErrNoInterfaces -- ENETUNREACH" },
	{ kStr_PalmOSErrorBase+netErrorClass+13, "netErrBufTooSmall" },
	{ kStr_PalmOSErrorBase+netErrorClass+14, "netErrUnimplemented" },
	{ kStr_PalmOSErrorBase+netErrorClass+15, "netErrPortInUse -- EADDRINUSE" },
	{ kStr_PalmOSErrorBase+netErrorClass+16, "netErrQuietTimeNotElapsed -- EADDRINUSE" },
	{ kStr_PalmOSErrorBase+netErrorClass+17, "netErrInternal" },
	{ kStr_PalmOSErrorBase+netErrorClass+18, "netErrTimeout -- ETIMEDOUT" },
	{ kStr_PalmOSErrorBase+netErrorClass+19, "netErrSocketAlreadyConnected -- EISCONN" },
	{ kStr_PalmOSErrorBase+netErrorClass+20, "netErrSocketClosedByRemote" },
	{ kStr_PalmOSErrorBase+netErrorClass+21, "netErrOutOfCmdBlocks" },
	{ kStr_PalmOSErrorBase+netErrorClass+22, "netErrWrongSocketType" },
	{ kStr_PalmOSErrorBase+netErrorClass+23, "netErrSocketNotListening" },
	{ kStr_PalmOSErrorBase+netErrorClass+24, "netErrUnknownSetting" },
	{ kStr_PalmOSErrorBase+netErrorClass+25, "netErrInvalidSettingSize" },
	{ kStr_PalmOSErrorBase+netErrorClass+26, "netErrPrefNotFound" },
	{ kStr_PalmOSErrorBase+netErrorClass+27, "netErrInvalidInterface" },
	{ kStr_PalmOSErrorBase+netErrorClass+28, "netErrInterfaceNotFound" },
	{ kStr_PalmOSErrorBase+netErrorClass+29, "netErrTooManyInterfaces" },
	{ kStr_PalmOSErrorBase+netErrorClass+30, "netErrBufWrongSize" },
	{ kStr_PalmOSErrorBase+netErrorClass+31, "netErrUserCancel" },
	{ kStr_PalmOSErrorBase+netErrorClass+32, "netErrBadScript" },
	{ kStr_PalmOSErrorBase+netErrorClass+33, "netErrNoSocket" },
	{ kStr_PalmOSErrorBase+netErrorClass+34, "netErrSocketRcvBufFull" },
	{ kStr_PalmOSErrorBase+netErrorClass+35, "netErrNoPendingConnect" },
	{ kStr_PalmOSErrorBase+netErrorClass+36, "netErrUnexpectedCmd" },
	{ kStr_PalmOSErrorBase+netErrorClass+37, "netErrNoTCB" },
	{ kStr_PalmOSErrorBase+netErrorClass+38, "netErrNilRemoteWindowSize" },
	{ kStr_PalmOSErrorBase+netErrorClass+39, "netErrNoTimerProc" },
	{ kStr_PalmOSErrorBase+netErrorClass+40, "netErrSocketInputShutdown -- EOF to sockets API" },
	{ kStr_PalmOSErrorBase+netErrorClass+41, "netErrCmdBlockNotCheckedOut		 " },
	{ kStr_PalmOSErrorBase+netErrorClass+42, "netErrCmdNotDone		 " },
	{ kStr_PalmOSErrorBase+netErrorClass+43, "netErrUnknownProtocol		 " },
	{ kStr_PalmOSErrorBase+netErrorClass+44, "netErrUnknownService		 " },
	{ kStr_PalmOSErrorBase+netErrorClass+45, "netErrUnreachableDest	" },
	{ kStr_PalmOSErrorBase+netErrorClass+46, "netErrReadOnlySetting	 " },
	{ kStr_PalmOSErrorBase+netErrorClass+47, "netErrWouldBlock -- EWOULDBLOCK" },
	{ kStr_PalmOSErrorBase+netErrorClass+48, "netErrAlreadyInProgress -- EALREADY" },
	{ kStr_PalmOSErrorBase+netErrorClass+49, "netErrPPPTimeout" },
	{ kStr_PalmOSErrorBase+netErrorClass+50, "netErrPPPBroughtDown" },
	{ kStr_PalmOSErrorBase+netErrorClass+51, "netErrAuthFailure" },
	{ kStr_PalmOSErrorBase+netErrorClass+52, "netErrPPPAddressRefused" },
	{ kStr_PalmOSErrorBase+netErrorClass+53, "netErrDNSNameTooLong" },
	{ kStr_PalmOSErrorBase+netErrorClass+54, "netErrDNSBadName" },
	{ kStr_PalmOSErrorBase+netErrorClass+55, "netErrDNSBadArgs" },
	{ kStr_PalmOSErrorBase+netErrorClass+56, "netErrDNSLabelTooLong" },
	{ kStr_PalmOSErrorBase+netErrorClass+57, "netErrDNSAllocationFailure" },
	{ kStr_PalmOSErrorBase+netErrorClass+58, "netErrDNSTimeout" },
	{ kStr_PalmOSErrorBase+netErrorClass+59, "netErrDNSUnreachable" },
	{ kStr_PalmOSErrorBase+netErrorClass+60, "netErrDNSFormat" },
	{ kStr_PalmOSErrorBase+netErrorClass+61, "netErrDNSServerFailure" },
	{ kStr_PalmOSErrorBase+netErrorClass+62, "netErrDNSNonexistantName" },
	{ kStr_PalmOSErrorBase+netErrorClass+63, "netErrDNSNIY" },
	{ kStr_PalmOSErrorBase+netErrorClass+64, "netErrDNSRefused" },
	{ kStr_PalmOSErrorBase+netErrorClass+65, "netErrDNSImpossible" },
	{ kStr_PalmOSErrorBase+netErrorClass+66, "netErrDNSNoRRS" },
	{ kStr_PalmOSErrorBase+netErrorClass+67, "netErrDNSAborted" },
	{ kStr_PalmOSErrorBase+netErrorClass+68, "netErrDNSBadProtocol" },
	{ kStr_PalmOSErrorBase+netErrorClass+69, "netErrDNSTruncated" },
	{ kStr_PalmOSErrorBase+netErrorClass+70, "netErrDNSNoRecursion" },
	{ kStr_PalmOSErrorBase+netErrorClass+71, "netErrDNSIrrelevant" },
	{ kStr_PalmOSErrorBase+netErrorClass+72, "netErrDNSNotInLocalCache" },
	{ kStr_PalmOSErrorBase+netErrorClass+73, "netErrDNSNoPort" },
	{ kStr_PalmOSErrorBase+netErrorClass+74, "netErrIPCantFragment" },
	{ kStr_PalmOSErrorBase+netErrorClass+75, "netErrIPNoRoute" },
	{ kStr_PalmOSErrorBase+netErrorClass+76, "netErrIPNoSrc" },
	{ kStr_PalmOSErrorBase+netErrorClass+77, "netErrIPNoDst" },
	{ kStr_PalmOSErrorBase+netErrorClass+78, "netErrIPktOverflow" },
	{ kStr_PalmOSErrorBase+netErrorClass+79, "netErrTooManyTCPConnections" },
	{ kStr_PalmOSErrorBase+netErrorClass+80, "netErrNoDNSServers" },
	{ kStr_PalmOSErrorBase+netErrorClass+81, "netErrInterfaceDown" },
	{ kStr_PalmOSErrorBase+netErrorClass+82, "netErrNoChannel -- The datalink layer cannot acquire a channel " },
	{ kStr_PalmOSErrorBase+netErrorClass+83, "netErrDieState -- Mobitex network has issued a DIE command" },
	{ kStr_PalmOSErrorBase+netErrorClass+84, "netErrReturnedInMail -- The addressed of the transmitted packet was not available, and the message was placed in the network's mailbox" },
	{ kStr_PalmOSErrorBase+netErrorClass+85, "netErrReturnedNoTransfer -- This message cannot be transferred or put in the network mailbox" },
	{ kStr_PalmOSErrorBase+netErrorClass+86, "netErrReturnedIllegal -- The message could not be switched to the network" },
	{ kStr_PalmOSErrorBase+netErrorClass+87, "netErrReturnedCongest -- Line, radio channels, or network nodes are congested" },
	{ kStr_PalmOSErrorBase+netErrorClass+88, "netErrReturnedError -- Technical error in the network" },
	{ kStr_PalmOSErrorBase+netErrorClass+89, "netErrReturnedBusy -- The B-party is busy" },
	{ kStr_PalmOSErrorBase+netErrorClass+90, "netErrGMANState -- The modem has not registered with the network" },
	{ kStr_PalmOSErrorBase+netErrorClass+91, "netErrQuitOnTxFail -- Couldn't get packet through, shutdown" },
	{ kStr_PalmOSErrorBase+netErrorClass+92, "netErrFlexListFull -- raw IF error message: see Mobitex spec" },
	{ kStr_PalmOSErrorBase+netErrorClass+93, "netErrSenderMAN -- ditto" },
	{ kStr_PalmOSErrorBase+netErrorClass+94, "netErrIllegalType -- ditto" },
	{ kStr_PalmOSErrorBase+netErrorClass+95, "netErrIllegalState -- ditto" },
	{ kStr_PalmOSErrorBase+netErrorClass+96, "netErrIllegalFlags -- ditto" },
	{ kStr_PalmOSErrorBase+netErrorClass+97, "netErrIllegalSendlist -- ditto" },
	{ kStr_PalmOSErrorBase+netErrorClass+98, "netErrIllegalMPAKLength -- ditto" },
	{ kStr_PalmOSErrorBase+netErrorClass+99, "netErrIllegalAddressee -- ditto" },
	{ kStr_PalmOSErrorBase+netErrorClass+100, "netErrIllegalPacketClass -- ditto" },
	{ kStr_PalmOSErrorBase+netErrorClass+101, "netErrBufferLength -- any " },
	{ kStr_PalmOSErrorBase+netErrorClass+102, "netErrNiCdLowBattery -- any " },
	{ kStr_PalmOSErrorBase+netErrorClass+103, "netErrRFinterfaceFatal -- any" },
	{ kStr_PalmOSErrorBase+netErrorClass+104, "netErrIllegalLogout -- raw IF error message" },
	{ kStr_PalmOSErrorBase+netErrorClass+105, "netErrAAARadioLoad -- 7/20/98 JB.  If there is insufficient AAA" },
	{ kStr_PalmOSErrorBase+netErrorClass+106, "netErrAntennaDown" },
	{ kStr_PalmOSErrorBase+netErrorClass+107, "netErrNiCdCharging -- just for charging" },
	{ kStr_PalmOSErrorBase+netErrorClass+108, "netErrAntennaWentDown" },
	{ kStr_PalmOSErrorBase+netErrorClass+109, "netErrNotActivated -- The unit has not been FULLY activated.  George and Morty completed" },
	{ kStr_PalmOSErrorBase+netErrorClass+110, "netErrRadioTemp -- Radio's temp is too high for FCC compliant TX" },
	{ kStr_PalmOSErrorBase+netErrorClass+111, "netErrNiCdChargeError -- Charging stopped due to NiCd charging characteristic" },
	{ kStr_PalmOSErrorBase+netErrorClass+112, "netErrNiCdSag -- the computed sag or actual sag indicates a NiCd with diminished capacity" },
	{ kStr_PalmOSErrorBase+netErrorClass+113, "netErrNiCdChargeSuspend -- Charging has been suspended due to low AAA batteries" },
	{ kStr_PalmOSErrorBase+netErrorClass+115, "netErrConfigNotFound" },
	{ kStr_PalmOSErrorBase+netErrorClass+116, "netErrConfigCantDelete" },
	{ kStr_PalmOSErrorBase+netErrorClass+117, "netErrConfigTooMany" },
	{ kStr_PalmOSErrorBase+netErrorClass+118, "netErrConfigBadName" },
	{ kStr_PalmOSErrorBase+netErrorClass+119, "netErrConfigNotAlias" },
	{ kStr_PalmOSErrorBase+netErrorClass+120, "netErrConfigCantPointToAlias" },
	{ kStr_PalmOSErrorBase+netErrorClass+121, "netErrConfigEmpty" },
	{ kStr_PalmOSErrorBase+netErrorClass+122, "netErrAlreadyOpenWithOtherConfig" },
	{ kStr_PalmOSErrorBase+netErrorClass+123, "netErrConfigAliasErr" },
	{ kStr_PalmOSErrorBase+netErrorClass+124, "netErrNoMultiPktAddr" },
	{ kStr_PalmOSErrorBase+netErrorClass+125, "netErrOutOfPackets " },
	{ kStr_PalmOSErrorBase+netErrorClass+126, "netErrMultiPktAddrReset" },
	{ kStr_PalmOSErrorBase+netErrorClass+127, "netErrStaleMultiPktAddr" },
	{ kStr_PalmOSErrorBase+netErrorClass+128, "netErrScptPluginMissing" },
	{ kStr_PalmOSErrorBase+netErrorClass+129, "netErrScptPluginLaunchFail" },
	{ kStr_PalmOSErrorBase+netErrorClass+130, "netErrScptPluginCmdFail" },
	{ kStr_PalmOSErrorBase+netErrorClass+131, "netErrScptPluginInvalidCmd" },
	{ kStr_PalmOSErrorBase+netErrorClass+132, "netErrTelMissingComponent" },
	{ kStr_PalmOSErrorBase+netErrorClass+133, "netErrTelErrorNotHandled" },
	{ kStr_PalmOSErrorBase+omErrorClass+1, "omErrBaseRequiresOverlay" },
	{ kStr_PalmOSErrorBase+omErrorClass+2, "omErrUnknownLocale" },
	{ kStr_PalmOSErrorBase+omErrorClass+3, "omErrBadOverlayDBName" },
	{ kStr_PalmOSErrorBase+omErrorClass+4, "omErrInvalidLocaleIndex	" },
	{ kStr_PalmOSErrorBase+omErrorClass+5, "omErrInvalidLocale" },
	{ kStr_PalmOSErrorBase+omErrorClass+6, "omErrInvalidSystemOverlay" },
	{ kStr_PalmOSErrorBase+omErrorClass+7, "omErrNoNextSystemLocale" },
	{ kStr_PalmOSErrorBase+penErrorClass+1, "penErrBadParam" },
	{ kStr_PalmOSErrorBase+penErrorClass+2, "penErrIgnorePoint" },
	{ kStr_PalmOSErrorBase+slkErrorClass+1, "slkErrChecksum" },
	{ kStr_PalmOSErrorBase+slkErrorClass+2, "slkErrFormat" },
	{ kStr_PalmOSErrorBase+slkErrorClass+3, "slkErrBuffer" },
	{ kStr_PalmOSErrorBase+slkErrorClass+4, "slkErrTimeOut" },
	{ kStr_PalmOSErrorBase+slkErrorClass+5, "slkErrHandle" },
	{ kStr_PalmOSErrorBase+slkErrorClass+6, "slkErrBodyLimit" },
	{ kStr_PalmOSErrorBase+slkErrorClass+7, "slkErrTransId" },
	{ kStr_PalmOSErrorBase+slkErrorClass+8, "slkErrResponse" },
	{ kStr_PalmOSErrorBase+slkErrorClass+9, "slkErrNoDefaultProc" },
	{ kStr_PalmOSErrorBase+slkErrorClass+10, "slkErrWrongPacketType" },
	{ kStr_PalmOSErrorBase+slkErrorClass+11, "slkErrBadParam" },
	{ kStr_PalmOSErrorBase+slkErrorClass+12, "slkErrAlreadyOpen" },
	{ kStr_PalmOSErrorBase+slkErrorClass+13, "slkErrOutOfSockets" },
	{ kStr_PalmOSErrorBase+slkErrorClass+14, "slkErrSocketNotOpen" },
	{ kStr_PalmOSErrorBase+slkErrorClass+15, "slkErrWrongDestSocket" },
	{ kStr_PalmOSErrorBase+slkErrorClass+16, "slkErrWrongPktType" },
	{ kStr_PalmOSErrorBase+slkErrorClass+17, "slkErrBusy -- called while sending a packet" },
	{ kStr_PalmOSErrorBase+slkErrorClass+18, "slkErrNotOpen" },
	{ kStr_PalmOSErrorBase+serErrorClass+1, "serErrBadParam" },
	{ kStr_PalmOSErrorBase+serErrorClass+2, "serErrBadPort" },
	{ kStr_PalmOSErrorBase+serErrorClass+3, "serErrNoMem" },
	{ kStr_PalmOSErrorBase+serErrorClass+4, "serErrBadConnID" },
	{ kStr_PalmOSErrorBase+serErrorClass+5, "serErrTimeOut" },
	{ kStr_PalmOSErrorBase+serErrorClass+6, "serErrLineErr" },
	{ kStr_PalmOSErrorBase+serErrorClass+7, "serErrAlreadyOpen" },
	{ kStr_PalmOSErrorBase+serErrorClass+8, "serErrStillOpen" },
	{ kStr_PalmOSErrorBase+serErrorClass+9, "serErrNotOpen" },
	{ kStr_PalmOSErrorBase+serErrorClass+10, "serErrNotSupported -- functionality not supported" },
	{ kStr_PalmOSErrorBase+serErrorClass+11, "serErrNoDevicesAvail -- No serial devices were loaded or are available" },
	{ kStr_PalmOSErrorBase+serErrorClass+12, "serErrConfigurationFailed" },
	{ kStr_PalmOSErrorBase+sndErrorClass+1, "sndErrBadParam" },
	{ kStr_PalmOSErrorBase+sndErrorClass+2, "sndErrBadChannel" },
	{ kStr_PalmOSErrorBase+sndErrorClass+3, "sndErrMemory" },
	{ kStr_PalmOSErrorBase+sndErrorClass+4, "sndErrOpen" },
	{ kStr_PalmOSErrorBase+sndErrorClass+5, "sndErrQFull" },
	{ kStr_PalmOSErrorBase+sndErrorClass+6, "sndErrQEmpty -- internal" },
	{ kStr_PalmOSErrorBase+sndErrorClass+7, "sndErrFormat -- unsupported data format" },
	{ kStr_PalmOSErrorBase+sndErrorClass+8, "sndErrBadStream -- invalid data stream" },
	{ kStr_PalmOSErrorBase+sndErrorClass+9, "sndErrInterrupted -- play was interrupted" },
	{ kStr_PalmOSErrorBase+evtErrorClass+1, "evtErrParamErr" },
	{ kStr_PalmOSErrorBase+evtErrorClass+2, "evtErrQueueFull" },
	{ kStr_PalmOSErrorBase+evtErrorClass+3, "evtErrQueueEmpty" },
	{ kStr_PalmOSErrorBase+sysErrorClass+1, "sysErrTimeout" },
	{ kStr_PalmOSErrorBase+sysErrorClass+2, "sysErrParamErr" },
	{ kStr_PalmOSErrorBase+sysErrorClass+3, "sysErrNoFreeResource" },
	{ kStr_PalmOSErrorBase+sysErrorClass+4, "sysErrNoFreeRAM" },
	{ kStr_PalmOSErrorBase+sysErrorClass+5, "sysErrNotAllowed" },
	{ kStr_PalmOSErrorBase+sysErrorClass+6, "sysErrSemInUse" },
	{ kStr_PalmOSErrorBase+sysErrorClass+7, "sysErrInvalidID" },
	{ kStr_PalmOSErrorBase+sysErrorClass+8, "sysErrOutOfOwnerIDs" },
	{ kStr_PalmOSErrorBase+sysErrorClass+9, "sysErrNoFreeLibSlots" },
	{ kStr_PalmOSErrorBase+sysErrorClass+10, "sysErrLibNotFound" },
	{ kStr_PalmOSErrorBase+sysErrorClass+11, "sysErrDelayWakened -- SysTaskDelay wakened by SysTaskWake before delay completed" },
	{ kStr_PalmOSErrorBase+sysErrorClass+12, "sysErrRomIncompatible" },
	{ kStr_PalmOSErrorBase+sysErrorClass+13, "sysErrBufTooSmall" },
	{ kStr_PalmOSErrorBase+sysErrorClass+14, "sysErrPrefNotFound" },
	{ kStr_PalmOSErrorBase+sysErrorClass+16, "sysNotifyErrEntryNotFound -- could not find registration entry in the list" },
	{ kStr_PalmOSErrorBase+sysErrorClass+17, "sysNotifyErrDuplicateEntry -- identical entry already exists" },
	{ kStr_PalmOSErrorBase+sysErrorClass+19, "sysNotifyErrBroadcastBusy -- a broadcast is already in progress - try again later" },
	{ kStr_PalmOSErrorBase+sysErrorClass+20, "sysNotifyErrBroadcastCancelled -- a handler cancelled the broadcast" },
	{ kStr_PalmOSErrorBase+sysErrorClass+21, "sysErrMbId" },
	{ kStr_PalmOSErrorBase+sysErrorClass+22, "sysErrMbNone	" },
	{ kStr_PalmOSErrorBase+sysErrorClass+23, "sysErrMbBusy" },
	{ kStr_PalmOSErrorBase+sysErrorClass+24, "sysErrMbFull" },
	{ kStr_PalmOSErrorBase+sysErrorClass+25, "sysErrMbDepth" },
	{ kStr_PalmOSErrorBase+sysErrorClass+26, "sysErrMbEnv" },
	{ kStr_PalmOSErrorBase+sysErrorClass+27, "sysNotifyErrQueueFull -- deferred queue is full" },
	{ kStr_PalmOSErrorBase+sysErrorClass+28, "sysNotifyErrQueueEmpty -- deferred queue is empty" },
	{ kStr_PalmOSErrorBase+sysErrorClass+29, "sysNotifyErrNoStackSpace -- not enough stack space for a broadcast" },
	{ kStr_PalmOSErrorBase+sysErrorClass+30, "sysErrNotInitialized -- manager is not initialized" },
	{ kStr_PalmOSErrorBase+sysErrorClass+31, "sysErrNotAsleep -- Task woken by SysTaskWake was not asleep, 1 wake pending" },
	{ kStr_PalmOSErrorBase+sysErrorClass+32, "sysErrNotAsleepN -- Task woken by SysTaskWake was not asleep, >1 wake pending" },
	{ kStr_PalmOSErrorBase+pwrErrorClass+0, "pwrErrNone" },
	{ kStr_PalmOSErrorBase+pwrErrorClass+1, "pwrErrBacklight" },
	{ kStr_PalmOSErrorBase+pwrErrorClass+2, "pwrErrRadio" },
	{ kStr_PalmOSErrorBase+pwrErrorClass+3, "pwrErrBeam" },
	{ kStr_PalmOSErrorBase+pwrErrorClass+4, "pwrErrGeneric" },
	{ kStr_PalmOSErrorBase+txtErrorClass+1, "txtErrUknownTranslitOp" },
	{ kStr_PalmOSErrorBase+txtErrorClass+2, "txtErrTranslitOverrun" },
	{ kStr_PalmOSErrorBase+txtErrorClass+3, "txtErrTranslitOverflow" },
	{ kStr_PalmOSErrorBase+txtErrorClass+4, "txtErrConvertOverflow" },
	{ kStr_PalmOSErrorBase+txtErrorClass+5, "txtErrConvertUnderflow" },
	{ kStr_PalmOSErrorBase+txtErrorClass+6, "txtErrUnknownEncoding" },
	{ kStr_PalmOSErrorBase+txtErrorClass+7, "txtErrNoCharMapping" },
	{ kStr_PalmOSErrorBase+txtErrorClass+8, "txtErrTranslitUnderflow" },
	{ kStr_PalmOSErrorBase+timErrorClass+1, "timErrMemory" },
	{ kStr_PalmOSErrorBase+winErrorClass+1, "winErrPalette" },
	{ kStr_PalmOSErrorBase+attnErrorClass+1, "attnErrMemory -- ran out of memory" },
	{ kStr_PalmOSErrorBase+menuErrorClass+1, "menuErrNoMenu" },
	{ kStr_PalmOSErrorBase+menuErrorClass+2, "menuErrNotFound" },
	{ kStr_PalmOSErrorBase+menuErrorClass+3, "menuErrSameId" },
	{ kStr_PalmOSErrorBase+menuErrorClass+4, "menuErrTooManyItems" },
	{ kStr_PalmOSErrorBase+menuErrorClass+5, "menuErrOutOfMemory" },
	{ kStr_PalmOSErrorBase+expErrorClass+1, "expErrUnsupportedOperation -- unsupported or undefined opcode and/or creator" },
	{ kStr_PalmOSErrorBase+expErrorClass+2, "expErrNotEnoughPower -- the required power is not available" },
	{ kStr_PalmOSErrorBase+expErrorClass+3, "expErrCardNotPresent -- no card is present" },
	{ kStr_PalmOSErrorBase+expErrorClass+4, "expErrInvalidSlotRefNum -- slot reference number is bad" },
	{ kStr_PalmOSErrorBase+expErrorClass+5, "expErrSlotDeallocated -- slot reference number is within valid range, but has been deallocated" },
	{ kStr_PalmOSErrorBase+expErrorClass+6, "expErrCardNoSectorReadWrite -- the card does not support the " },
	{ kStr_PalmOSErrorBase+expErrorClass+7, "expErrCardReadOnly -- the card does support R/W API" },
	{ kStr_PalmOSErrorBase+expErrorClass+8, "expErrCardBadSector -- the card does support R/W API" },
	{ kStr_PalmOSErrorBase+expErrorClass+9, "expErrCardProtectedSector -- The card does support R/W API" },
	{ kStr_PalmOSErrorBase+expErrorClass+10, "expErrNotOpen -- slot driver library has not been opened" },
	{ kStr_PalmOSErrorBase+expErrorClass+11, "expErrStillOpen -- slot driver library is still open - maybe it was opened > once" },
	{ kStr_PalmOSErrorBase+expErrorClass+12, "expErrUnimplemented -- Call is unimplemented" },
	{ kStr_PalmOSErrorBase+expErrorClass+13, "expErrEnumerationEmpty -- No values remaining to enumerate" },
	{ kStr_PalmOSErrorBase+expErrorClass+14, "expErrIncompatibleAPIVer -- The API version of this slot driver is not supported by this version of ExpansionMgr" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+1, "vfsErrBufferOverflow -- passed in buffer is too small" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+2, "vfsErrFileGeneric -- Generic file error" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+3, "vfsErrFileBadRef -- the fileref is invalid (has been closed, or was not obtained from VFSFileOpen())" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+4, "vfsErrFileStillOpen -- returned from FSFileDelete if the file is still open" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+5, "vfsErrFilePermissionDenied -- The file is read only" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+6, "vfsErrFileAlreadyExists -- a file of this name exists already in this location" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+7, "vfsErrFileEOF -- file pointer is at end of file" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+8, "vfsErrFileNotFound -- file was not found at the path specified" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+9, "vfsErrVolumeBadRef -- the volume refnum is invalid" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+10, "vfsErrVolumeStillMounted -- returned from FSVolumeFormat if the volume is still mounted" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+11, "vfsErrNoFileSystem -- no installed filesystem supports this operation" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+12, "vfsErrBadData -- operation could not be completed because of invalid data (i.e., import DB from .PRC file)" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+13, "vfsErrDirNotEmpty -- can't delete a non-empty directory" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+14, "vfsErrBadName -- invalid filename, or path, or volume label or something.." },
	{ kStr_PalmOSErrorBase+vfsErrorClass+15, "vfsErrVolumeFull -- not enough space left on volume" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+16, "vfsErrUnimplemented -- this call is not implemented" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+17, "vfsErrNotADirectory -- This operation requires a directory" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+18, "vfsErrIsADirectory -- This operation requires a regular file, not a directory" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+19, "vfsErrDirectoryNotFound -- Returned from VFSFileCreate when the path leading up to the new file does not exist" },
	{ kStr_PalmOSErrorBase+vfsErrorClass+20, "vfsErrNameShortened -- A volume name or filename was automatically shortened to conform to filesystem spec" },
	{ kStr_PalmOSErrorBase+inetErrorClass+1, "inetErrTooManyClients -- Too many clients already" },
	{ kStr_PalmOSErrorBase+inetErrorClass+2, "inetErrHandleInvalid -- Invalid inetH or sockH" },
	{ kStr_PalmOSErrorBase+inetErrorClass+3, "inetErrParamsInvalid -- " },
	{ kStr_PalmOSErrorBase+inetErrorClass+4, "inetErrURLVersionInvalid -- " },
	{ kStr_PalmOSErrorBase+inetErrorClass+5, "inetErrURLBufTooSmall -- " },
	{ kStr_PalmOSErrorBase+inetErrorClass+6, "inetErrURLInvalid -- " },
	{ kStr_PalmOSErrorBase+inetErrorClass+7, "inetErrTooManySockets -- " },
	{ kStr_PalmOSErrorBase+inetErrorClass+8, "inetErrNoRequestCreated" },
	{ kStr_PalmOSErrorBase+inetErrorClass+9, "inetErrNotConnected" },
	{ kStr_PalmOSErrorBase+inetErrorClass+10, "inetErrInvalidRequest" },
	{ kStr_PalmOSErrorBase+inetErrorClass+11, "inetErrNeedTime" },
	{ kStr_PalmOSErrorBase+inetErrorClass+12, "inetErrHostnameInvalid" },
	{ kStr_PalmOSErrorBase+inetErrorClass+13, "inetErrInvalidPort" },
	{ kStr_PalmOSErrorBase+inetErrorClass+14, "inetErrInvalidHostAddr" },
	{ kStr_PalmOSErrorBase+inetErrorClass+15, "inetErrNilBuffer" },
	{ kStr_PalmOSErrorBase+inetErrorClass+16, "inetErrConnectTimeout" },
	{ kStr_PalmOSErrorBase+inetErrorClass+17, "inetErrResolveTimeout" },
	{ kStr_PalmOSErrorBase+inetErrorClass+18, "inetErrSendReqTimeout" },
	{ kStr_PalmOSErrorBase+inetErrorClass+19, "inetErrReadTimeout" },
	{ kStr_PalmOSErrorBase+inetErrorClass+20, "inetErrBufTooSmall" },
	{ kStr_PalmOSErrorBase+inetErrorClass+21, "inetErrSchemeNotSupported" },
	{ kStr_PalmOSErrorBase+inetErrorClass+22, "inetErrInvalidResponse" },
	{ kStr_PalmOSErrorBase+inetErrorClass+25, "inetErrSettingTooLarge" },
	{ kStr_PalmOSErrorBase+inetErrorClass+26, "inetErrSettingSizeInvalid" },
	{ kStr_PalmOSErrorBase+inetErrorClass+27, "inetErrRequestTooLong" },
	{ kStr_PalmOSErrorBase+inetErrorClass+28, "inetErrSettingNotImplemented" },
	{ kStr_PalmOSErrorBase+inetErrorClass+29, "inetErrConfigNotFound" },
	{ kStr_PalmOSErrorBase+inetErrorClass+30, "inetErrConfigCantDelete" },
	{ kStr_PalmOSErrorBase+inetErrorClass+31, "inetErrConfigTooMany" },
	{ kStr_PalmOSErrorBase+inetErrorClass+32, "inetErrConfigBadName" },
	{ kStr_PalmOSErrorBase+inetErrorClass+33, "inetErrConfigNotAlias" },
	{ kStr_PalmOSErrorBase+inetErrorClass+34, "inetErrConfigCantPointToAlias" },
	{ kStr_PalmOSErrorBase+inetErrorClass+35, "inetErrConfigEmpty" },
	{ kStr_PalmOSErrorBase+inetErrorClass+37, "inetErrConfigAliasErr" },
	{ kStr_PalmOSErrorBase+inetErrorClass+38, "inetErrNoWirelessInterface" },
	{ kStr_PalmOSErrorBase+inetErrorClass+39, "inetErrEncryptionNotAvail" },
	{ kStr_PalmOSErrorBase+inetErrorClass+40, "inetErrNeedRetryEncSeqNum" },
	{ kStr_PalmOSErrorBase+inetErrorClass+41, "inetErrNeedRetryEncPublicKey" },
	{ kStr_PalmOSErrorBase+inetErrorClass+42, "inetErrResponseTooShort" },
	{ kStr_PalmOSErrorBase+inetErrorClass+43, "inetErrMobitexIllegalOKHost" },
	{ kStr_PalmOSErrorBase+inetErrorClass+44, "inetErrMobitexIllegalBadHost" },
	{ kStr_PalmOSErrorBase+inetErrorClass+45, "inetErrHTTPBadRequest" },
	{ kStr_PalmOSErrorBase+inetErrorClass+46, "inetErrHTTPUnauthorized" },
	{ kStr_PalmOSErrorBase+inetErrorClass+47, "inetErrHTTPForbidden" },
	{ kStr_PalmOSErrorBase+inetErrorClass+48, "inetErrHTTPNotFound" },
	{ kStr_PalmOSErrorBase+inetErrorClass+49, "inetErrHTTPMethodNotAllowed" },
	{ kStr_PalmOSErrorBase+inetErrorClass+50, "inetErrHTTPNotAcceptable" },
	{ kStr_PalmOSErrorBase+inetErrorClass+51, "inetErrHTTPProxyAuthRequired" },
	{ kStr_PalmOSErrorBase+inetErrorClass+52, "inetErrHTTPRequestTimeout" },
	{ kStr_PalmOSErrorBase+inetErrorClass+53, "inetErrHTTPConflict" },
	{ kStr_PalmOSErrorBase+inetErrorClass+54, "inetErrHTTPGone" },
	{ kStr_PalmOSErrorBase+inetErrorClass+55, "inetErrHTTPLengthRequired" },
	{ kStr_PalmOSErrorBase+inetErrorClass+56, "inetErrHTTPPreconditionFailed" },
	{ kStr_PalmOSErrorBase+inetErrorClass+57, "inetErrHTTPRequestTooLarge" },
	{ kStr_PalmOSErrorBase+inetErrorClass+58, "inetErrHTTPRequestURITooLong" },
	{ kStr_PalmOSErrorBase+inetErrorClass+59, "inetErrHTTPUnsupportedType" },
	{ kStr_PalmOSErrorBase+inetErrorClass+60, "inetErrHTTPServerError" },
	{ kStr_PalmOSErrorBase+inetErrorClass+61, "inetErrCTPServerError" },
	{ kStr_PalmOSErrorBase+inetErrorClass+62, "inetErrTypeNotCached" },
	{ kStr_PalmOSErrorBase+inetErrorClass+63, "inetErrCacheInvalid" },
	{ kStr_PalmOSErrorBase+inetErrorClass+64, "inetErrURLDispatched" },
	{ kStr_PalmOSErrorBase+inetErrorClass+65, "inetErrDatabaseNotFound" },
	{ kStr_PalmOSErrorBase+inetErrorClass+66, "inetErrCTPMalformedRequest" },
	{ kStr_PalmOSErrorBase+inetErrorClass+67, "inetErrCTPUnknownCommand" },
	{ kStr_PalmOSErrorBase+inetErrorClass+68, "inetErrCTPTruncated" },
	{ kStr_PalmOSErrorBase+inetErrorClass+69, "inetErrCTPUnknownError" },
	{ kStr_PalmOSErrorBase+inetErrorClass+70, "inetErrCTPProxyError" },
	{ kStr_PalmOSErrorBase+inetErrorClass+71, "inetErrCTPSocketErr" },
	{ kStr_PalmOSErrorBase+inetErrorClass+72, "inetErrCTPInvalidURL" },
	{ kStr_PalmOSErrorBase+inetErrorClass+73, "inetErrCTPReferringPageOutOfDate" },
	{ kStr_PalmOSErrorBase+inetErrorClass+74, "inetErrCTPBadRequest" },
	{ kStr_PalmOSErrorBase+inetErrorClass+75, "inetErrUNUSED" },
	{ kStr_PalmOSErrorBase+inetErrorClass+76, "inetErrCTPMailServerDown" },
	{ kStr_PalmOSErrorBase+inetErrorClass+77, "inetErrCTPHostNotFound" },
	{ kStr_PalmOSErrorBase+inetErrorClass+78, "inetErrCTPContentInvalidTag" },
	{ kStr_PalmOSErrorBase+inetErrorClass+79, "inetErrCTPContentInternal" },
	{ kStr_PalmOSErrorBase+inetErrorClass+80, "inetErrCTPContentDataEnd" },
	{ kStr_PalmOSErrorBase+inetErrorClass+81, "inetErrCTPContentResourceTooBig" },
	{ kStr_PalmOSErrorBase+inetErrorClass+82, "inetErrCTPContentNoNoFrames" },
	{ kStr_PalmOSErrorBase+inetErrorClass+83, "inetErrCTPContentUnsupportedContent" },
	{ kStr_PalmOSErrorBase+inetErrorClass+84, "inetErrCTPContentUnsupportedEncoding" },
	{ kStr_PalmOSErrorBase+inetErrorClass+85, "inetErrCTPContentBadForm" },
	{ kStr_PalmOSErrorBase+inetErrorClass+86, "inetErrCTPContentBadFormMissingAction" },
	{ kStr_PalmOSErrorBase+inetErrorClass+87, "inetErrCTPContentBadFormMissingMethod" },
	{ kStr_PalmOSErrorBase+inetErrorClass+88, "inetErrCTPContentNoSourceData" },
	{ kStr_PalmOSErrorBase+inetErrorClass+89, "inetErrCTPContentBadImage" },
	{ kStr_PalmOSErrorBase+inetErrorClass+90, "inetErrCTPContentImageTooLarge" },
	{ kStr_PalmOSErrorBase+inetErrorClass+91, "inetErrMobitexErrorHandled" },
	{ kStr_PalmOSErrorBase+inetErrorClass+92, "inetErrProxyDownBadHost" },
	{ kStr_PalmOSErrorBase+inetErrorClass+93, "inetErrHostConnectionLost" },
	{ kStr_PalmOSErrorBase+inetErrorClass+94, "inetErrLinkNotFound" },
	{ kStr_PalmOSErrorBase+inetErrorClass+95, "inetErrCacheInvalidSort" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0x00, "lz77ErrNonFatalFirstErr" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0x01, "lz77ErrNonFatalInputBufferIncomplete" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0x02, "lz77ErrNonFatalOutputBufferFull" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0x7F, "lz77ErrNonFatalLastErr" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0x80, "lz77ErrFatalUnfinishedInputBuffer" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0x81, "lz77ErrFatalInputBufferIncomplete" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0x82, "lz77ErrFatalInputBufferInvalid" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0x83, "lz77ErrFatalMemAllocation" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0x84, "lz77ErrFatalHandleInvalid" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0x85, "lz77ErrFatalCantChangeToCompress" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0x86, "lz77ErrFatalUnknownVersion" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0x87, "lz77ErrFatalOutputBufferTooSmall" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0x88, "lz77ErrFatalInvalidArgument" },
	{ kStr_PalmOSErrorBase+lz77ErrorClass+0xFF, "lz77ErrFatalLastErr" },
	{ kStr_PalmOSErrorBase+pdiErrorClass+1, "pdiErrRead" },
	{ kStr_PalmOSErrorBase+pdiErrorClass+2, "pdiErrWrite" },
	{ kStr_PalmOSErrorBase+pdiErrorClass+3, "pdiErrNoPropertyName" },
	{ kStr_PalmOSErrorBase+pdiErrorClass+4, "pdiErrNoPropertyValue" },
	{ kStr_PalmOSErrorBase+pdiErrorClass+5, "pdiErrMoreChars" },
	{ kStr_PalmOSErrorBase+pdiErrorClass+6, "pdiErrNoMoreFields" },
	{ kStr_PalmOSErrorBase+pdiErrorClass+7, "pdiErrOpenFailed" },
	{ kStr_PalmOSErrorBase+pdiErrorClass+8, "pdiErrCloseFailed" },
	{ kStr_PalmOSErrorBase+smsErrorClass+0x01, "kSmsErrMaxSizeExceeded -- Message exceeds maximum size supported by network" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x01, "telErrMsgAllocation -- couldn't allocate message	" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x02, "telErrUnknown -- unknown Tel internal error	" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x03, "telErrMemAllocation -- memory allocation error" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x04, "telErrResultTimeOut -- time-out was reached" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x05, "telErrResultUserCancel -- user cancelled action" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x06, "telErrResultBusyResource -- resource is busy" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x07, "telErrInvalidAppId -- don't know that application" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x08, "telErrTooManyApps -- applications table is full" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x09, "telErrSecurity -- access to ME has not been granted" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x0A, "telErrBufferSize -- buffer used to retrieve data is too small" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x0B, "telErrFeatureNotSupported -- the feature is not supported by phone/network" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x0C, "telErrPhoneComm -- the communication link with the phone is down" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x0D, "telErrPhoneReply -- the phone reply syntax is incorrect, check the phone driver!" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x0E, "telErrCommandFailed -- the phone couldn't achieve the associated command, check the phone driver! " },
	{ kStr_PalmOSErrorBase+telErrorClass+0x0F, "telErrSpcLineIsBusy -- spc call failure events, error field values" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x10, "telErrPhoneCodeRequired -- phone code required" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x11, "telErrNoSIMInserted -- no SIM inserted" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x12, "telErrPINRequired -- PIN is required" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x13, "telErrPUKRequired -- PUK is required" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x14, "telErrSIMFailure -- the SIM is not working properly" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x15, "telErrSIMBusy -- the SIM couldn't reply" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x16, "telErrSIMWrong -- the SIM is not accepted by the phone" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x17, "telErrPassword -- incorrect password" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x18, "telErrPIN2Required -- PIN2 is required" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x19, "telErrPUK2Required -- PUK2 is required" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x1A, "telErrPhoneMemAllocation -- phone memory is full" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x1B, "telErrInvalidIndex -- invalid index when accessing a storage" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x1C, "telErrEntryNotFound -- entry not found" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x1D, "telErrPhoneMemFailure -- the phone encountered a memory error" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x1E, "telErrInvalidString -- bad character in text string" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x1F, "telErrInvalidDial -- bad character in dial string" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x20, "telErrNoNetwork -- no network available" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x21, "telErrNetworkTimeOut -- the network didn't reply within 'normal' time delay" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x22, "telErrInvalidParameter -- bad parameter passed to an API" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x23, "telErrValidityPeriod -- the specified short message validity period is invalid" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x24, "telErrCodingScheme -- the specified short message coding scheme is invalid" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x25, "telErrPhoneNumber -- the specified short message smsc or destination phone number is invalid" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x26, "telErrValueStale -- information couldn't be retrieved, a copy of last retrieved value was returned" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x27, "telErrTTaskNotRunning -- the Telephony Task is not running" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x28, "telErrPhoneToSIMPINRequired -- Phone 2 SIM PIN is required" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x29, "telErrSpecificDrvNotFound -- the specified driver was not found" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x2A, "telErrGenericDrvNotFound -- the generic driver was not found" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x2B, "telErrNoSpecificDrv -- no specific driver was specified" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x2C, "telErrSpcLineIsReleased -- the call has been released" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x2D, "telErrSpcCallError -- the call has encountered an error" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x2E, "telErrNotInstalled -- the shared lib couldn't be installed" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x2F, "telErrVersion -- the shared lib version doesn't match the application one" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x30, "telErrSettings -- bad telephony settings: Phone Panel Prefs doesn't exist or Telephony Profile not (correctly) set" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x31, "telErrUnavailableValue -- the asked value can't be retrieved at that time (i.e.: TelSpcGetCallerNumber and no active line)" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x32, "telErrLimitedCompatibility -- the current driver is partially compatible with the connected phone" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x33, "telErrProfileConflict -- the currently used profile conflicts with the requested profile" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x34, "telErrLibStillInUse -- the shared lib is currently being used by another app, don't unload it!" },
	{ kStr_PalmOSErrorBase+telErrorClass+0x35, "telErrTTaskNotFound -- couldn't find the specified (by phone driver) telephony task" },

	{ 0, NULL }
};

static void _ResStrTableInit (void)
{
	for (const struct item* it = _ResStrTable; it->value != NULL; it++)
	{
		_ResStrMap[it->key] = it->value;
	}
}


const char* _ResGetString(int idx);
const char* _ResGetString(int idx)
{
	static int inited;
	if (!inited)
	{
		inited = 1;
		_ResStrTableInit();
	}

	return _ResStrMap[idx];
}
