/* -*- mode: C++; tab-width: 4 -*- */
/* ===================================================================== *\
	Copyright (c) 2000-2001 Palm, Inc. or its subsidiaries.
	All rights reserved.

	This file is part of the Palm OS Emulator.

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
\* ===================================================================== */

#include "EmCommon.h"
#include "EmRegsUSB_ISP1161.h"


// Given a register (specified by its field name), return its address
// in emulated space.

#undef addressof
#define addressof(reg)				\
	(this->GetAddressStart () + fRegs.offsetof_##reg ())


// Macro to help the installation of handlers for a register.

#undef INSTALL_HANDLER
#define INSTALL_HANDLER(read, write, reg)			\
	this->SetHandler (	(ReadFunction) &EmRegsUSB_ISP1161::read,		\
						(WriteFunction) &EmRegsUSB_ISP1161::write,		\
						addressof (reg),			\
						fRegs.reg.GetSize ())


// ---------------------------------------------------------------------------
//		 EmRegsUSB_ISP1161::EmRegsUSB_ISP1161
// ---------------------------------------------------------------------------

EmRegsUSB_ISP1161::EmRegsUSB_ISP1161 (emuptr baseAddr) :
	fBaseAddr (baseAddr)
{
}


// ---------------------------------------------------------------------------
//		 EmRegsUSB_ISP1161::~EmRegsUSB_ISP1161
// ---------------------------------------------------------------------------

EmRegsUSB_ISP1161::~EmRegsUSB_ISP1161 (void)
{
}


// ---------------------------------------------------------------------------
//		 EmRegsUSB_ISP1161::Initialize
// ---------------------------------------------------------------------------

void EmRegsUSB_ISP1161::Initialize (void)
{
	EmRegs::Initialize ();
}


// ---------------------------------------------------------------------------
//		 EmRegsUSB_ISP1161::Reset
// ---------------------------------------------------------------------------

void EmRegsUSB_ISP1161::Reset (Bool hardwareReset)
{
	EmRegs::Reset (hardwareReset);

	if (hardwareReset)
	{
		memset (fRegs.GetPtr (), 0, fRegs.GetSize ());
	}
}


// ---------------------------------------------------------------------------
//		 EmRegsUSB_ISP1161::Save
// ---------------------------------------------------------------------------

void EmRegsUSB_ISP1161::Save (SessionFile& f)
{
	EmRegs::Save (f);
}


// ---------------------------------------------------------------------------
//		 EmRegsUSB_ISP1161::Load
// ---------------------------------------------------------------------------

void EmRegsUSB_ISP1161::Load (SessionFile& f)
{
	EmRegs::Load (f);
}


// ---------------------------------------------------------------------------
//		 EmRegsUSB_ISP1161::Dispose
// ---------------------------------------------------------------------------

void EmRegsUSB_ISP1161::Dispose (void)
{
	EmRegs::Dispose ();
}


// ---------------------------------------------------------------------------
//		 EmRegsUSB_ISP1161::SetSubBankHandlers
// ---------------------------------------------------------------------------

void EmRegsUSB_ISP1161::SetSubBankHandlers (void)
{
	// Install base handlers.

	EmRegs::SetSubBankHandlers ();

	// Now add standard/specialized handers for the defined registers.
#if 1
	INSTALL_HANDLER (StdReadBE,			StdWriteBE,				data1);
	INSTALL_HANDLER (StdReadBE,			StdWriteBE,				data2);
	INSTALL_HANDLER (StdReadBE,			StdWriteBE,				data3);
	INSTALL_HANDLER (StdReadBE,			StdWriteBE,				data4);
#endif
}


// ---------------------------------------------------------------------------
//		 EmRegsUSB_ISP1161::GetRealAddress
// ---------------------------------------------------------------------------

uint8* EmRegsUSB_ISP1161::GetRealAddress (emuptr address)
{
	return (uint8*) fRegs.GetPtr () + address - this->GetAddressStart ();
}


// ---------------------------------------------------------------------------
//		 EmRegsUSB_ISP1161::GetAddressStart
// ---------------------------------------------------------------------------

emuptr EmRegsUSB_ISP1161::GetAddressStart (void)
{
	return fBaseAddr;
}


// ---------------------------------------------------------------------------
//		 EmRegsUSB_ISP1161::GetAddressRange
// ---------------------------------------------------------------------------

uint32 EmRegsUSB_ISP1161::GetAddressRange (void)
{
	return fRegs.GetSize ();
}
