/* -*- mode: C++; tab-width: 4 -*- */
/* ===================================================================== *\
	Copyright (c) 2001 Palm, Inc. or its subsidiaries.
	All rights reserved.

	This file is part of the Palm OS Emulator.

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
\* ===================================================================== */

#include "EmCommon.h"

#include "EmRegsVZAlphaSmart.h"
#include "EmRegsVZPrv.h"

#include "EmSession.h"			// GetDevice
#include "EmHAL.h"				// EmHAL::GetROMSize
#include "EmBankROM.h"			// EmBankROM::GetMemoryStart

#include "EmDevice.h"			// HardwareID
#include "EmSPISlaveADS784x.h"	// EmSPISlaveADS784x

#define PRINTF	if (1) ; else LogAppendMsg

#define	hwrVZPortKSTReset					0x04			 // Reset line to ST.					(aka IRQ2) 



// ---------------------------------------------------------------------------
//		 EmRegsVZAlphaSmart::EmRegsVZAlphaSmart
// ---------------------------------------------------------------------------

EmRegsVZAlphaSmart::EmRegsVZAlphaSmart (void) :
	EmRegsVZ ()
	
{
	gSession->SetIgnoreRAMCheck(true);

	fSPISlaveADC = new EmSPISlaveADS784x (kChannelSet2);
		
	fSPISlaveSTMicro = new EmSPISlaveSTMicro;


}


// ---------------------------------------------------------------------------
//		 EmRegsVZAlphaSmart::~EmRegsVZAlphaSmart
// ---------------------------------------------------------------------------

EmRegsVZAlphaSmart::~EmRegsVZAlphaSmart (void)
{
	gSession->SetIgnoreRAMCheck(false);

	delete fSPISlaveADC;
	delete fSPISlaveSTMicro;


}


// ---------------------------------------------------------------------------
//		 EmRegsVZAlphaSmart::GetLCDScreenOn
// ---------------------------------------------------------------------------

Bool EmRegsVZAlphaSmart::GetLCDScreenOn (void)
{
	return (READ_REGISTER (portKData) & hwrAlphaSmartPortKLCDEnableOn) != 0;
}


// ---------------------------------------------------------------------------
//		 EmRegsVZAlphaSmart::GetLCDBacklightOn
// ---------------------------------------------------------------------------

Bool EmRegsVZAlphaSmart::GetLCDBacklightOn (void)
{

	return (READ_REGISTER (portKData) & hwrAlphaSmartPortKBacklightOff) != 0;
}


// ---------------------------------------------------------------------------
//		 EmRegsVZVisorPlatinum::GetIRPortOn
// ---------------------------------------------------------------------------

Bool EmRegsVZAlphaSmart::GetIRPortOn (int /*uartNum*/)
{
	uint16	uControl = READ_REGISTER (uControl);
	uint16	uMisc = READ_REGISTER (uMisc);

	return (uControl & hwrEZ328UControlUARTEnable) != 0 &&
			(uMisc & hwrEZ328UMiscIRDAEn) != 0;
}

// ---------------------------------------------------------------------------
//		 EmRegsVZAlphaSmart::GetSerialPortOn
// ---------------------------------------------------------------------------

Bool EmRegsVZAlphaSmart::GetSerialPortOn (int /*portNum*/)
{
	uint16	uControl = READ_REGISTER (uControl);
	return (uControl & hwrEZ328UControlUARTEnable) != 0;
}


// ---------------------------------------------------------------------------
//		 EmRegsVZ::CycleSlowly
// ---------------------------------------------------------------------------
// Handles periodic events that need to occur when the processor cycles (like
// updating timer registers).  This function is called in two places from
// Emulator::Execute.  Interestingly, the loop runs 3% FASTER if this function
// is in its own separate function instead of being inline.

void EmRegsVZAlphaSmart::CycleSlowly (Bool sleeping)
{
	UNUSED_PARAM(sleeping)



	EmAssert (gSession);


	// See if there's anything new ("Put the data on the bus")

	EmRegsVZ::UpdateUARTState (false, 0);
	EmRegsVZ::UpdateUARTState (false, 1);

	// Check to see if the RTC alarm is ready to go off.  First see
	// if the RTC is enabled, and that the alarm event isn't already
	// registered (the latter check is just an optimization).

	if ((READ_REGISTER (rtcIntEnable) & hwrVZ328RTCIntEnableAlarm) != 0 &&
		(READ_REGISTER (rtcIntStatus) & hwrVZ328RTCIntStatusAlarm) == 0)
	{
		uint32	rtcAlarm = READ_REGISTER (rtcAlarm);

		long	almHour	 = (rtcAlarm & hwrVZ328RTCAlarmHoursMask) >> hwrVZ328RTCAlarmHoursOffset;
		long	almMin	 = (rtcAlarm & hwrVZ328RTCAlarmMinutesMask) >> hwrVZ328RTCAlarmMinutesOffset;
		long	almSec	 = (rtcAlarm & hwrVZ328RTCAlarmSecondsMask) >> hwrVZ328RTCAlarmSecondsOffset;
		long	almInSeconds = (almHour * 60 * 60) + (almMin * 60) + almSec;

		long	nowHour;
		long	nowMin;
		long	nowSec;
		::GetHostTime (&nowHour, &nowMin, &nowSec);
		long	nowInSeconds = (nowHour * 60 * 60) + (nowMin * 60) + nowSec;

		if (almInSeconds <= nowInSeconds)
		{
			WRITE_REGISTER (rtcIntStatus, READ_REGISTER (rtcIntStatus) | hwrVZ328RTCIntStatusAlarm);
			EmRegsVZ::UpdateRTCInterrupts ();
		}
	}

	uint16 intPendingHigh = READ_REGISTER (intPendingHi);
	bool irq1State	= (intPendingHigh & hwrVZ328IntHiIRQ1 ? true : false);
	bool IRQ1Assert = fSPISlaveSTMicro->IRQ1Assert();
	if (irq1State ^ IRQ1Assert)	// should int be asserted and now off or the other way around
	{
		if (IRQ1Assert)
		{
			WRITE_REGISTER (intPendingHi, intPendingHigh | hwrVZ328IntHiIRQ1);
		}
		else
		{
			WRITE_REGISTER (intPendingHi, intPendingHigh & ~hwrVZ328IntHiIRQ1);
		}

		EmRegsVZ::UpdateInterrupts ();
	}


}


// ---------------------------------------------------------------------------
//		 EmRegsVZAlphaSmart::GetPortInputValue
// ---------------------------------------------------------------------------
#define	hwrVZPortDBadBatt					0x80	 // Bad Battery interrupt (aka IRQ6) 
#define	hwrVZPortDSTIrq						0x10	 // Interrupt request from ST. (aka IRQ1) 

uint8 EmRegsVZAlphaSmart::GetPortInputValue (int port)
{
	uint8	result;

	switch(port)
	{
		case 'D':
			result = 0;
			break;
		case 'E':
			result = 0;
			break;
		case 'G':
			result = 0;
			break;
			
		case 'K':	
				// the st micro reset bit needs to be added in.
				// the bit actually gets set in portKDirWrite()				
			result = EmRegsVZ::GetPortInputValue (port);
			result |= READ_REGISTER (portKData) & hwrVZPortKSTReset;

			break;
	
		default:
			result = EmRegsVZ::GetPortInputValue (port);			
			break;
	}

	
	return result;
}


// ---------------------------------------------------------------------------
//		 EmRegsVZAlphaSmart::GetPortInternalValue
// ---------------------------------------------------------------------------

uint8 EmRegsVZAlphaSmart::GetPortInternalValue (int port)
{

	uint8	result;

	switch(port)
	{
		case 'D':
			result = hwrVZPortDBadBatt;
			break;
		case 'G':
			result = EmRegsVZ::GetPortInternalValue (port);
			result |= hwrAlphaSmartPortGPowerFailIrqOff;
			break;
	
		default:
			result = EmRegsVZ::GetPortInternalValue (port);
			break;
	}

	return result;
}



// ---------------------------------------------------------------------------
//		 EmRegsVZAlphaSmart::GetSPISlave
// ---------------------------------------------------------------------------

EmSPISlave* EmRegsVZAlphaSmart::GetSPISlave (void)
{
	if ((READ_REGISTER (portEData) & hwrAlphaSmartPortSTSelect) == 0)
	{
		// trying to access ST Micro
		return (EmSPISlave*)fSPISlaveSTMicro;
	}
	else	// must be for Burr Brown
	{
		return fSPISlaveADC;
	
	}

	return NULL;
}

// ---------------------------------------------------------------------------
//		 EmRegsVZ::UpdatePortDInterrupts
// ---------------------------------------------------------------------------
// Determine what interrupts need to be generated based on the current
// settings in portDData and fPortDEdge.

void EmRegsVZAlphaSmart::UpdatePortDInterrupts (void)
{
	// Update INT0-INT3 of the Interrupt-Pending register (bits 8-11 of the low word).

	// First, get those bits and clear them out.

	uint16	intPendingLo	= READ_REGISTER (intPendingLo) & ~hwrVZ328IntLoAllKeys;
	uint16	intPendingHigh	= READ_REGISTER (intPendingHi);


	// Initialize the variable to hold the new interrupt settings.

	uint8	newBits			= 0;


	// Get some other values we're going to need:

	uint8	portDDir		= READ_REGISTER (portDDir);	// Interrupt on inputs only (when pin is low)
	uint8	portDData		= EmHAL::GetPortInputValue ('D');
	uint8	portDPolarity	= READ_REGISTER (portDPolarity);
	uint8	portDIntReqEn	= READ_REGISTER (portDIntReqEn);
	uint8	portDKbdIntEn	= READ_REGISTER (portDKbdIntEn);
	uint8	portDIntEdge	= READ_REGISTER (portDIntEdge);
	uint8	portDSelect		= READ_REGISTER (portDSelect);

	// We have a line-level interrupt if:
	//
	//	- line-level interrupts are requested
	//	- the GPIO bit matches the polarity bit

	newBits |= ~portDIntEdge & portDData & portDPolarity;
	newBits |= ~portDIntEdge & ~portDData & ~portDPolarity;


	// We have an edge interrupt if:
	//
	//	- edge interrupts are requested
	//	- an edge has been recorded
	//
	// Note that we should distinguish between rising and falling edges.
	// For historical reasons, that's not done, and the Palm OS doesn't
	// look for them, so it's OK for now.
	//
	// Edge interrupts on INT[3:0] should not wake up a sleeping device.

	uint16	pllControl	= READ_REGISTER (pllControl);

	if ((pllControl & hwrVZ328PLLControlDisable) && !(gSession->GetDevice ().EdgeHack ()))
	{
		newBits |= portDIntEdge & fPortDEdge & portDPolarity & 0xF0;
		newBits |= portDIntEdge & 0 & ~portDPolarity & 0xF0;
	}
	else
	{
		newBits |= portDIntEdge & fPortDEdge & portDPolarity;
		newBits |= portDIntEdge & 0 & ~portDPolarity;
	}


	// Only have interrupts if they're enabled and the pin is configured for input.

	newBits &= portDIntReqEn & ~portDDir;

	PRINTF ("EmRegsVZ::UpdatePortDInterrupts: Dir  Data Pol  Req  Edg  PDE  bits");
	PRINTF ("EmRegsVZ::UpdatePortDInterrupts: 0x%02lX 0x%02lX 0x%02lX 0x%02lX 0x%02lX 0x%02lX 0x%02lX",
		(uint32) portDDir, (uint32) portDData, (uint32) portDPolarity, (uint32) portDIntReqEn, (uint32) portDIntEdge,
		(uint32) fPortDEdge, (uint32) newBits);


	// Determine if the KB interrupt needs to be asserted.  It is if:
	//
	//	A Port D Data bit is on.
	//	The bit is configured for input (?)
	//	The bit is configured to be OR'd into the interrupt.

	if (!gSession->GetDevice ().EdgeHack ())
	{
		uint8	KB = portDData & ~portDDir & portDKbdIntEn;	
		//uint8	KB = ~portDData & ~portDDir & portDKbdIntEn;	// jdn way

		if (KB)
			intPendingLo |= hwrVZ328IntLoKbd;
		else
			intPendingLo &= ~hwrVZ328IntLoKbd;
	}


	// Respond to the new interrupt state.

	EmRegsVZ::UpdateInterrupts ();
}

// ---------------------------------------------------------------------------
//		 EmRegsVZAlphaSmart::GetKeyInfo
// ---------------------------------------------------------------------------

void EmRegsVZAlphaSmart::GetKeyInfo (int* numRows, int* numCols,
								uint16* keyMap, Bool* rows)
{
	*numRows = 8;
	*numCols = 16;

		// jdn
	rows[0]	= 0;
	rows[1]	= 0;
	rows[2]	= 0;

}


// ---------------------------------------------------------------------------
//		 EmRegsVZAlphaSmart::GetKeyBits
// ---------------------------------------------------------------------------

uint8 EmRegsVZAlphaSmart::GetKeyBits (void)
{
	// "Keys" (that is, buttons) are read from the Port D Data register.
	// There are 7 or 8 keys that can be pressed, but only 4 bits are
	// available in the Port D Data register for reporting pressed keys.
	// Therefore, the keys are organized into a matrix, one row or which
	// can be requested and reported at a time.  This function determines
	// what row is being requested, and sets the appropriate Port D Data
	// bits for the keys are are currently pressed.

	return 0;
}

// ---------------------------------------------------------------------------
//		 EmRegsVZAlphaSmart::SetSubBankHandlers
// ---------------------------------------------------------------------------

void EmRegsVZAlphaSmart::SetSubBankHandlers(void)
{

	EmRegsVZ::SetSubBankHandlers();

	
 	this->SetHandler((ReadFunction)&EmRegsVZ::StdRead,
                         (WriteFunction)&EmRegsVZAlphaSmart::spiMasterControlWrite,
	                 addressof(spiMasterControl),
	                 sizeof(UInt16));


 	this->SetHandler((ReadFunction)&EmRegsVZ::StdRead,
					(WriteFunction)&EmRegsVZAlphaSmart::portKDirWrite,
					addressof(portKDir),
					sizeof(UInt8));

}

// ---------------------------------------------------------------------------
//		 EmRegsVZAlphaSmart::spiMasterControlWrite
// ---------------------------------------------------------------------------

void EmRegsVZAlphaSmart::spiMasterControlWrite (emuptr address, int size, uint32 value)
{

	// Do a standard update of the register.

	EmRegsVZ::StdWrite (address, size, value);

	// Get the current value.

	uint16	spiMasterData		= READ_REGISTER (spiMasterData);
	uint16	spiMasterControl	= READ_REGISTER (spiMasterControl);

	// Check to see if data exchange and enable are enabled.

	#define BIT_MASK (hwrVZ328SPIMControlExchange | hwrVZ328SPIMControlEnable)
	if ((spiMasterControl & BIT_MASK) == BIT_MASK)
	{
		// If the SPI is hooked up to something, talk with it.

		EmSPISlave*	spiSlave = this->GetSPISlave ();
		if (spiSlave)
		{
			// Write out the old data, read in the new data.

			uint16	newData = spiSlave->DoExchange (spiMasterControl, spiMasterData);

			// Shift in the new data.

			uint16	numBits = (spiMasterControl & hwrVZ328SPIMControlBitsMask) + 1;

			uint16	oldBitsMask = ~0 << numBits;
			uint16	newBitsMask = ~oldBitsMask;

			spiMasterData = /*((spiMasterData << numBits) & oldBitsMask) | */
				(newData & newBitsMask);

			WRITE_REGISTER (spiMasterData, spiMasterData);
		}

		// Assert the interrupt and clear the exchange bit.

		spiMasterControl |= hwrVZ328SPIMControlIntStatus;
		spiMasterControl &= ~hwrVZ328SPIMControlExchange;

		WRITE_REGISTER (spiMasterControl, spiMasterControl);

		// If hwrVZ328SPIMControlIntEnable is set, trigger an interrupt.

		if ((spiMasterControl & hwrVZ328SPIMControlIntEnable) != 0)
		{
			uint16	intPendingLo	= READ_REGISTER (intPendingLo);
			intPendingLo |= hwrVZ328IntLoSPIM;
			WRITE_REGISTER (intPendingLo, intPendingLo);
			this->UpdateInterrupts ();
		}

			// need to do this for the ST Micro part
		uint16 intPendingHigh = READ_REGISTER (intPendingHi);
		bool irq1State	= (intPendingHigh & hwrVZ328IntHiIRQ1 ? true : false);
		bool IRQ1Assert = fSPISlaveSTMicro->IRQ1Assert();
		if (irq1State ^ IRQ1Assert)	// should int be asserted and now off or the other way around
		{
			if (IRQ1Assert)
			{
				WRITE_REGISTER (intPendingHi, intPendingHigh | hwrVZ328IntHiIRQ1);
			}
			else
			{
				WRITE_REGISTER (intPendingHi, intPendingHigh & ~hwrVZ328IntHiIRQ1);
			}

			EmRegsVZ::UpdateInterrupts ();
		}

	}
}



// ---------------------------------------------------------------------------
//		 EmRegsVZAlphaSmart::spiMasterControlWrite
// ---------------------------------------------------------------------------

void EmRegsVZAlphaSmart::portKDirWrite (emuptr address, int size, uint32 value)
{

	// Do a standard update of the register.

	EmRegsVZ::StdWrite (address, size, value);


	uint8	kDataValue		= READ_REGISTER (portKData);

		// is the rom code trying to do a reset of the st micro (spi device)
	if ((value & hwrVZPortKSTReset) && ((kDataValue & hwrVZPortKSTReset) == 0))
	{
		WRITE_REGISTER (portKData, READ_REGISTER (portKData) | hwrVZPortKSTReset);
		fSPISlaveSTMicro->SetResetMode();
	}


}

