/* -*- mode: C++; tab-width: 4 -*- */
/* ===================================================================== *\
	Copyright (c) 2001 Palm, Inc. or its subsidiaries.
	All rights reserved.

	This file is part of the Palm OS Emulator.

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
\* ===================================================================== */

#ifndef EmRegsVZAlphaSmart_h
#define EmRegsVZAlphaSmart_h

#include "EmRegsVZ.h"
#include "EmSession.h"			// GetDevice
#include "EmSPISlaveSTMicro.h"	// ST Micro part


#define ASPopupName			"AlphaSmart Dana"
#define ASSkinName			"DanaDevice"
#define ASCompanyID			'asmt'
#define ASHalID				'Dana'


/************************************************************************
 * Port B Bit settings
 ************************************************************************/
#define hwrAlphaSmartPortBLCDVccOff		0x08	// (L) LCD Vcc
#define hwrAlphaSmartPortBLCDAdjOn		0x40	// (H) LCD Contrast Voltage


/************************************************************************
 * Port C Bit settings
 ************************************************************************/
#define hwrAlphaSmartPortCLCDEnableOn	0x80 	// (H) LCD Enable


/************************************************************************
 * Port D Bit settings
 ************************************************************************/
#define hwrAlphaSmartPortDKbdCol0On		0x01 	// (H) Keyboard Column 0
#define hwrAlphaSmartPortDKbdCol1On		0x02 	// (H) Keyboard Column 1
#define hwrAlphaSmartPortDKbdCol2On		0x04 	// (H) Keyboard Column 2

#define hwrAlphaSmartPortDKbdRow2		0x08 	// (H) Keyboard Row 2

#define hwrAlphaSmartPortDSTMicroIrq		0x10 	// (L) Dock1 interrupt
#define hwrAlphaSmartPortDSlotIrqOff		0x20 	// (L) Slot Interrupt
#define hwrAlphaSmartPortDUsbIrqOff		0x40 	// (L) USB Interrupt
#define hwrAlphaSmartPortDCardInstIrqOff	0x80 	// (L) Card Installed Interrupt

#define hwrAlphaSmartPortDKeyBits		0x07 	// (H) All Keyboard Columns



/************************************************************************
 * Port E Bit settings
 ************************************************************************/
#define hwrAlphaSmartPortESerialTxD		0x20	// ( ) Serial transmit line
#define hwrAlphaSmartPortESlotResetOff	0x40 	// (L) Slot reset
#define hwrAlphaSmartPortEDock2Off		0x80 	// (L) Dock2 input
#define hwrAlphaSmartPortSTSelect		0x08 	// (L) ST Micro select


/************************************************************************
 * Port F Bit settings
 ************************************************************************/
#define hwrAlphaSmartPortFContrast		0x01	// ( ) LCD Contrast PWM output
#define hwrAlphaSmartPortFIREnableOff	0x04	// (L) Shutdown IR
#define hwrAlphaSmartPortFUsbCsOff		0x80	// (L) USB chip select


/************************************************************************
 * Port G Bit settings
 ************************************************************************/
//#define hwrAlphaSmartPortGBacklightOff	0x10	// (L) Backlight on/off
//#define hwrAlphaSmartPortGBacklightOff	0x01	// (L) Backlight on/off
#define hwrAlphaSmartPortGUSBSuspend		0x02	// (X) USB Suspend bit - Output low for active
												//                     - Input for suspend
#define hwrAlphaSmartPortGPowerFailIrqOff 0x04	// (L) Power Fail IRQ
#define hwrAlphaSmartPortGKbdRow0 		0x08	// (H) Keyboard Row 0
#define hwrAlphaSmartPortGKbdRow1 		0x10	// (H) Keyboard Row 1
#define hwrAlphaSmartPortGAdcCsOff		0x20	// (L) A/D Select


/************************************************************************
 * Port K Bit settings
 ************************************************************************/
#define hwrAlphaSmartPortKBacklightOff	0x10	// (L) Backlight on/off
#define hwrAlphaSmartPortKLCDEnableOn	0x80 	// (H) LCD Enable



//const int		kAlphaSmartNumButtonRows = 8;
//const int		kAlphaSmartNumButtonCols = 16;


class EmRegsVZAlphaSmart : public EmRegsVZ
{
	public:
		EmRegsVZAlphaSmart ();
		~EmRegsVZAlphaSmart ();

		virtual Bool			GetLCDScreenOn			(void);
		virtual Bool			GetLCDBacklightOn		(void);
		virtual Bool			GetSerialPortOn			(int portNum);
		virtual Bool			GetIRPortOn				(int uartNum);

		virtual uint8			GetPortInputValue		(int);
		virtual uint8			GetPortInternalValue	(int);
		virtual void			GetKeyInfo				(int* numRows, int* numCols,
														 uint16* keyMap, Bool* rows);
		virtual void			CycleSlowly				(Bool sleeping);
		uint8					GetKeyBits (void);
		uint8					GetColumnNumber (uint16 writeLatch);
		void					UpdatePortDInterrupts (void);

		void 			    	SetSubBankHandlers      (void);
		void					portKDirWrite (emuptr address, int size, uint32 value);	

	protected:
		virtual EmSPISlave*		GetSPISlave				(void);

	private:
		virtual void			spiMasterControlWrite (emuptr address, int size, uint32 value);
		
		
		
		EmSPISlave*				fSPISlaveADC;
		EmSPISlaveSTMicro*		fSPISlaveSTMicro;
};

#endif	/* EmRegsVZAlphaSmart_h */
